/*!========================================================================
 * Iconset: Octicons
 * Versions: 2.1.2
 * https://octicons.github.com/
 * CDN: https://cdnjs.cloudflare.com/ajax/libs/octicons/4.x.x/font/octicons.min.css
 * CDN: https://cdnjs.cloudflare.com/ajax/libs/octicons/3.x.x/octicons.min.css
 * ======================================================================== */

;(function($){

    var data = {
        iconClass: 'octicon',
        iconClassFix: 'octicon-',
        icons: [],
        allVersions: [
            {
                version: '2.0.0',
                icons: [
                    '',
                    'alert',
                    'alignment-align',
                    'alignment-aligned-to',
                    'alignment-unalign',
                    'arrow-down',
                    'arrow-left',
                    'arrow-right',
                    'arrow-small-down',
                    'arrow-small-left',
                    'arrow-small-right',
                    'arrow-small-up',
                    'arrow-up',
                    'beer',
                    'book',
                    'bookmark',
                    'briefcase',
                    'broadcast',
                    'browser',
                    'bug',
                    'calendar',
                    'check',
                    'checklist',
                    'chevron-down',
                    'chevron-left',
                    'chevron-right',
                    'chevron-up',
                    'circle-slash',
                    'circuit-board',
                    'clippy',
                    'clock',
                    'cloud-download',
                    'cloud-upload',
                    'code',
                    'color-mode',
                    'comment',
                    'comment-discussion',
                    'credit-card',
                    'dash',
                    'dashboard',
                    'database',
                    'device-camera',
                    'device-camera-video',
                    'device-desktop',
                    'device-mobile',
                    'diff',
                    'diff-added',
                    'diff-ignored',
                    'diff-modified',
                    'diff-removed',
                    'diff-renamed',
                    'ellipsis',
                    'eye',
                    'file-binary',
                    'file-code',
                    'file-directory',
                    'file-media',
                    'file-pdf',
                    'file-submodule',
                    'file-symlink-directory',
                    'file-symlink-file',
                    'file-text',
                    'file-zip',
                    'flame',
                    'fold',
                    'gear',
                    'gift',
                    'gist',
                    'gist-secret',
                    'git-branch',
                    'git-commit',
                    'git-compare',
                    'git-merge',
                    'git-pull-request',
                    'globe',
                    'graph',
                    'heart',
                    'history',
                    'home',
                    'horizontal-rule',
                    'hourglass',
                    'hubot',
                    'inbox',
                    'info',
                    'issue-closed',
                    'issue-opened',
                    'issue-reopened',
                    'jersey',
                    'jump-down',
                    'jump-left',
                    'jump-right',
                    'jump-up',
                    'key',
                    'keyboard',
                    'law',
                    'light-bulb',
                    'link',
                    'link-external',
                    'list-ordered',
                    'list-unordered',
                    'location',
                    'lock',
                    'mail',
                    'mail-read',
                    'mail-reply',
                    'mark-github',
                    'markdown',
                    'megaphone',
                    'mention',
                    'microscope',
                    'milestone',
                    'mirror',
                    'mortar-board',
                    'move-down',
                    'move-left',
                    'move-right',
                    'move-up',
                    'mute',
                    'no-newline',
                    'octoface',
                    'organization',
                    'package',
                    'paintcan',
                    'pencil',
                    'person',
                    'pin',
                    'playback-fast-forward',
                    'playback-pause',
                    'playback-play',
                    'playback-rewind',
                    'plug',
                    'plus',
                    'podium',
                    'primitive-dot',
                    'primitive-square',
                    'pulse',
                    'puzzle',
                    'question',
                    'quote',
                    'radio-tower',
                    'repo',
                    'repo-clone',
                    'repo-force-push',
                    'repo-forked',
                    'repo-pull',
                    'repo-push',
                    'rocket',
                    'rss',
                    'ruby',
                    'screen-full',
                    'screen-normal',
                    'search',
                    'server',
                    'settings',
                    'sign-in',
                    'sign-out',
                    'split',
                    'squirrel',
                    'star',
                    'steps',
                    'stop',
                    'sync',
                    'tag',
                    'telescope',
                    'terminal',
                    'three-bars',
                    'tools',
                    'trashcan',
                    'triangle-down',
                    'triangle-left',
                    'triangle-right',
                    'triangle-up',
                    'unfold',
                    'unmute',
                    'versions',
                    'x',
                    'zap'
                ]
            },
            {
                version: '2.0.1',
                icons: [
                    '',
                    'alert',
                    'alignment-align',
                    'alignment-aligned-to',
                    'alignment-unalign',
                    'arrow-down',
                    'arrow-left',
                    'arrow-right',
                    'arrow-small-down',
                    'arrow-small-left',
                    'arrow-small-right',
                    'arrow-small-up',
                    'arrow-up',
                    'beer',
                    'book',
                    'bookmark',
                    'briefcase',
                    'broadcast',
                    'browser',
                    'bug',
                    'calendar',
                    'check',
                    'checklist',
                    'chevron-down',
                    'chevron-left',
                    'chevron-right',
                    'chevron-up',
                    'circle-slash',
                    'circuit-board',
                    'clippy',
                    'clock',
                    'cloud-download',
                    'cloud-upload',
                    'code',
                    'color-mode',
                    'comment-add',
                    'comment',
                    'comment-discussion',
                    'credit-card',
                    'dash',
                    'dashboard',
                    'database',
                    'device-camera',
                    'device-camera-video',
                    'device-desktop',
                    'device-mobile',
                    'diff',
                    'diff-added',
                    'diff-ignored',
                    'diff-modified',
                    'diff-removed',
                    'diff-renamed',
                    'ellipsis',
                    'eye-unwatch',
                    'eye-watch',
                    'eye',
                    'file-binary',
                    'file-code',
                    'file-directory',
                    'file-media',
                    'file-pdf',
                    'file-submodule',
                    'file-symlink-directory',
                    'file-symlink-file',
                    'file-text',
                    'file-zip',
                    'flame',
                    'fold',
                    'gear',
                    'gift',
                    'gist',
                    'gist-secret',
                    'git-branch-create',
                    'git-branch-delete',
                    'git-branch',
                    'git-commit',
                    'git-compare',
                    'git-merge',
                    'git-pull-request-abandoned',
                    'git-pull-request',
                    'globe',
                    'graph',
                    'heart',
                    'history',
                    'home',
                    'horizontal-rule',
                    'hourglass',
                    'hubot',
                    'inbox',
                    'info',
                    'issue-closed',
                    'issue-opened',
                    'issue-reopened',
                    'jersey',
                    'jump-down',
                    'jump-left',
                    'jump-right',
                    'jump-up',
                    'key',
                    'keyboard',
                    'law',
                    'light-bulb',
                    'link',
                    'link-external',
                    'list-ordered',
                    'list-unordered',
                    'location',
                    'gist-private',
                    'git-fork-private',
                    'lock',
                    'mirror-private',
                    'logo-github',
                    'mail',
                    'mail-read',
                    'mail-reply',
                    'mark-github',
                    'markdown',
                    'megaphone',
                    'mention',
                    'microscope',
                    'milestone',
                    'mirror-public',
                    'mirror',
                    'mortar-board',
                    'move-down',
                    'move-left',
                    'move-right',
                    'move-up',
                    'mute',
                    'no-newline',
                    'octoface',
                    'organization',
                    'package',
                    'paintcan',
                    'pencil',
                    'person-add',
                    'person-follow',
                    'person',
                    'pin',
                    'playback-fast-forward',
                    'playback-pause',
                    'playback-play',
                    'playback-rewind',
                    'plug',
                    'file-add',
                    'file-directory-create',
                    'gist-new',
                    'plus',
                    'repo-create',
                    'podium',
                    'primitive-dot',
                    'primitive-square',
                    'pulse',
                    'puzzle',
                    'question',
                    'quote',
                    'radio-tower',
                    'repo-delete',
                    'repo',
                    'repo-clone',
                    'repo-force-push',
                    'gist-fork',
                    'repo-forked',
                    'repo-pull',
                    'repo-push',
                    'rocket',
                    'rss',
                    'ruby',
                    'screen-full',
                    'screen-normal',
                    'search-save',
                    'search',
                    'server',
                    'settings',
                    'log-in',
                    'sign-in',
                    'log-out',
                    'sign-out',
                    'split',
                    'squirrel',
                    'star-add',
                    'star-delete',
                    'star',
                    'steps',
                    'stop',
                    'repo-sync',
                    'sync',
                    'tag-add',
                    'tag-remove',
                    'tag',
                    'telescope',
                    'terminal',
                    'three-bars',
                    'tools',
                    'trashcan',
                    'triangle-down',
                    'triangle-left',
                    'triangle-right',
                    'triangle-up',
                    'unfold',
                    'unmute',
                    'versions',
                    'remove-close',
                    'x',
                    'zap'
                ]
            },
            {
                version: '2.0.2',
                icons: [
                    '',
                    'alert',
                    'alignment-align',
                    'alignment-aligned-to',
                    'alignment-unalign',
                    'arrow-down',
                    'arrow-left',
                    'arrow-right',
                    'arrow-small-down',
                    'arrow-small-left',
                    'arrow-small-right',
                    'arrow-small-up',
                    'arrow-up',
                    'beer',
                    'book',
                    'bookmark',
                    'briefcase',
                    'broadcast',
                    'browser',
                    'bug',
                    'calendar',
                    'check',
                    'checklist',
                    'chevron-down',
                    'chevron-left',
                    'chevron-right',
                    'chevron-up',
                    'circle-slash',
                    'circuit-board',
                    'clippy',
                    'clock',
                    'cloud-download',
                    'cloud-upload',
                    'code',
                    'color-mode',
                    'comment-add',
                    'comment',
                    'comment-discussion',
                    'credit-card',
                    'dash',
                    'dashboard',
                    'database',
                    'device-camera',
                    'device-camera-video',
                    'device-desktop',
                    'device-mobile',
                    'diff',
                    'diff-added',
                    'diff-ignored',
                    'diff-modified',
                    'diff-removed',
                    'diff-renamed',
                    'ellipsis',
                    'eye-unwatch',
                    'eye-watch',
                    'eye',
                    'file-binary',
                    'file-code',
                    'file-directory',
                    'file-media',
                    'file-pdf',
                    'file-submodule',
                    'file-symlink-directory',
                    'file-symlink-file',
                    'file-text',
                    'file-zip',
                    'flame',
                    'fold',
                    'gear',
                    'gift',
                    'gist',
                    'gist-secret',
                    'git-branch-create',
                    'git-branch-delete',
                    'git-branch',
                    'git-commit',
                    'git-compare',
                    'git-merge',
                    'git-pull-request-abandoned',
                    'git-pull-request',
                    'globe',
                    'graph',
                    'heart',
                    'history',
                    'home',
                    'horizontal-rule',
                    'hourglass',
                    'hubot',
                    'inbox',
                    'info',
                    'issue-closed',
                    'issue-opened',
                    'issue-reopened',
                    'jersey',
                    'jump-down',
                    'jump-left',
                    'jump-right',
                    'jump-up',
                    'key',
                    'keyboard',
                    'law',
                    'light-bulb',
                    'link',
                    'link-external',
                    'list-ordered',
                    'list-unordered',
                    'location',
                    'gist-private',
                    'git-fork-private',
                    'lock',
                    'mirror-private',
                    'logo-github',
                    'mail',
                    'mail-read',
                    'mail-reply',
                    'mark-github',
                    'markdown',
                    'megaphone',
                    'mention',
                    'microscope',
                    'milestone',
                    'mirror-public',
                    'mirror',
                    'mortar-board',
                    'move-down',
                    'move-left',
                    'move-right',
                    'move-up',
                    'mute',
                    'no-newline',
                    'octoface',
                    'organization',
                    'package',
                    'paintcan',
                    'pencil',
                    'person-add',
                    'person-follow',
                    'person',
                    'pin',
                    'playback-fast-forward',
                    'playback-pause',
                    'playback-play',
                    'playback-rewind',
                    'plug',
                    'file-add',
                    'file-directory-create',
                    'gist-new',
                    'plus',
                    'repo-create',
                    'podium',
                    'primitive-dot',
                    'primitive-square',
                    'pulse',
                    'puzzle',
                    'question',
                    'quote',
                    'radio-tower',
                    'repo-delete',
                    'repo',
                    'repo-clone',
                    'repo-force-push',
                    'gist-fork',
                    'repo-forked',
                    'repo-pull',
                    'repo-push',
                    'rocket',
                    'rss',
                    'ruby',
                    'screen-full',
                    'screen-normal',
                    'search-save',
                    'search',
                    'server',
                    'settings',
                    'log-in',
                    'sign-in',
                    'log-out',
                    'sign-out',
                    'split',
                    'squirrel',
                    'star-add',
                    'star-delete',
                    'star',
                    'steps',
                    'stop',
                    'repo-sync',
                    'sync',
                    'tag-add',
                    'tag-remove',
                    'tag',
                    'telescope',
                    'terminal',
                    'three-bars',
                    'tools',
                    'trashcan',
                    'triangle-down',
                    'triangle-left',
                    'triangle-right',
                    'triangle-up',
                    'unfold',
                    'unmute',
                    'versions',
                    'remove-close',
                    'x',
                    'zap'
                ]
            },
            {
                version: '2.1.0',
                icons: [
                    '',
                    'alert',
                    'alignment-align',
                    'alignment-aligned-to',
                    'alignment-unalign',
                    'arrow-down',
                    'arrow-left',
                    'arrow-right',
                    'arrow-small-down',
                    'arrow-small-left',
                    'arrow-small-right',
                    'arrow-small-up',
                    'arrow-up',
                    'beer',
                    'book',
                    'bookmark',
                    'briefcase',
                    'broadcast',
                    'browser',
                    'bug',
                    'calendar',
                    'check',
                    'checklist',
                    'chevron-down',
                    'chevron-left',
                    'chevron-right',
                    'chevron-up',
                    'circle-slash',
                    'circuit-board',
                    'clippy',
                    'clock',
                    'cloud-download',
                    'cloud-upload',
                    'code',
                    'color-mode',
                    'comment-add',
                    'comment',
                    'comment-discussion',
                    'credit-card',
                    'dash',
                    'dashboard',
                    'database',
                    'device-camera',
                    'device-camera-video',
                    'device-desktop',
                    'device-mobile',
                    'diff',
                    'diff-added',
                    'diff-ignored',
                    'diff-modified',
                    'diff-removed',
                    'diff-renamed',
                    'ellipsis',
                    'eye-unwatch',
                    'eye-watch',
                    'eye',
                    'file-binary',
                    'file-code',
                    'file-directory',
                    'file-media',
                    'file-pdf',
                    'file-submodule',
                    'file-symlink-directory',
                    'file-symlink-file',
                    'file-text',
                    'file-zip',
                    'flame',
                    'fold',
                    'gear',
                    'gift',
                    'gist',
                    'gist-secret',
                    'git-branch-create',
                    'git-branch-delete',
                    'git-branch',
                    'git-commit',
                    'git-compare',
                    'git-merge',
                    'git-pull-request-abandoned',
                    'git-pull-request',
                    'globe',
                    'graph',
                    'heart',
                    'history',
                    'home',
                    'horizontal-rule',
                    'hourglass',
                    'hubot',
                    'inbox',
                    'info',
                    'issue-closed',
                    'issue-opened',
                    'issue-reopened',
                    'jersey',
                    'jump-down',
                    'jump-left',
                    'jump-right',
                    'jump-up',
                    'key',
                    'keyboard',
                    'law',
                    'light-bulb',
                    'link',
                    'link-external',
                    'list-ordered',
                    'list-unordered',
                    'location',
                    'gist-private',
                    'git-fork-private',
                    'lock',
                    'mirror-private',
                    'logo-github',
                    'mail',
                    'mail-read',
                    'mail-reply',
                    'mark-github',
                    'markdown',
                    'megaphone',
                    'mention',
                    'microscope',
                    'milestone',
                    'mirror-public',
                    'mirror',
                    'mortar-board',
                    'move-down',
                    'move-left',
                    'move-right',
                    'move-up',
                    'mute',
                    'no-newline',
                    'octoface',
                    'organization',
                    'package',
                    'paintcan',
                    'pencil',
                    'person-add',
                    'person-follow',
                    'person',
                    'pin',
                    'playback-fast-forward',
                    'playback-pause',
                    'playback-play',
                    'playback-rewind',
                    'plug',
                    'file-add',
                    'file-directory-create',
                    'gist-new',
                    'plus',
                    'repo-create',
                    'podium',
                    'primitive-dot',
                    'primitive-square',
                    'pulse',
                    'puzzle',
                    'question',
                    'quote',
                    'radio-tower',
                    'repo-delete',
                    'repo',
                    'repo-clone',
                    'repo-force-push',
                    'gist-fork',
                    'repo-forked',
                    'repo-pull',
                    'repo-push',
                    'rocket',
                    'rss',
                    'ruby',
                    'screen-full',
                    'screen-normal',
                    'search-save',
                    'search',
                    'server',
                    'settings',
                    'log-in',
                    'sign-in',
                    'log-out',
                    'sign-out',
                    'split',
                    'squirrel',
                    'star-add',
                    'star-delete',
                    'star',
                    'steps',
                    'stop',
                    'repo-sync',
                    'sync',
                    'tag-add',
                    'tag-remove',
                    'tag',
                    'telescope',
                    'terminal',
                    'three-bars',
                    'tools',
                    'trashcan',
                    'triangle-down',
                    'triangle-left',
                    'triangle-right',
                    'triangle-up',
                    'unfold',
                    'unmute',
                    'versions',
                    'remove-close',
                    'x',
                    'zap'
                ]
            },
            {
                version: '2.1.1',
                icons: [
                    '',
                    'alert',
                    'alignment-align',
                    'alignment-aligned-to',
                    'alignment-unalign',
                    'arrow-down',
                    'arrow-left',
                    'arrow-right',
                    'arrow-small-down',
                    'arrow-small-left',
                    'arrow-small-right',
                    'arrow-small-up',
                    'arrow-up',
                    'beer',
                    'book',
                    'bookmark',
                    'briefcase',
                    'broadcast',
                    'browser',
                    'bug',
                    'calendar',
                    'check',
                    'checklist',
                    'chevron-down',
                    'chevron-left',
                    'chevron-right',
                    'chevron-up',
                    'circle-slash',
                    'circuit-board',
                    'clippy',
                    'clock',
                    'cloud-download',
                    'cloud-upload',
                    'code',
                    'color-mode',
                    'comment-add',
                    'comment',
                    'comment-discussion',
                    'credit-card',
                    'dash',
                    'dashboard',
                    'database',
                    'device-camera',
                    'device-camera-video',
                    'device-desktop',
                    'device-mobile',
                    'diff',
                    'diff-added',
                    'diff-ignored',
                    'diff-modified',
                    'diff-removed',
                    'diff-renamed',
                    'ellipsis',
                    'eye-unwatch',
                    'eye-watch',
                    'eye',
                    'file-binary',
                    'file-code',
                    'file-directory',
                    'file-media',
                    'file-pdf',
                    'file-submodule',
                    'file-symlink-directory',
                    'file-symlink-file',
                    'file-text',
                    'file-zip',
                    'flame',
                    'fold',
                    'gear',
                    'gift',
                    'gist',
                    'gist-secret',
                    'git-branch-create',
                    'git-branch-delete',
                    'git-branch',
                    'git-commit',
                    'git-compare',
                    'git-merge',
                    'git-pull-request-abandoned',
                    'git-pull-request',
                    'globe',
                    'graph',
                    'heart',
                    'history',
                    'home',
                    'horizontal-rule',
                    'hourglass',
                    'hubot',
                    'inbox',
                    'info',
                    'issue-closed',
                    'issue-opened',
                    'issue-reopened',
                    'jersey',
                    'jump-down',
                    'jump-left',
                    'jump-right',
                    'jump-up',
                    'key',
                    'keyboard',
                    'law',
                    'light-bulb',
                    'link',
                    'link-external',
                    'list-ordered',
                    'list-unordered',
                    'location',
                    'gist-private',
                    'git-fork-private',
                    'lock',
                    'mirror-private',
                    'logo-github',
                    'mail',
                    'mail-read',
                    'mail-reply',
                    'mark-github',
                    'markdown',
                    'megaphone',
                    'mention',
                    'microscope',
                    'milestone',
                    'mirror-public',
                    'mirror',
                    'mortar-board',
                    'move-down',
                    'move-left',
                    'move-right',
                    'move-up',
                    'mute',
                    'no-newline',
                    'octoface',
                    'organization',
                    'package',
                    'paintcan',
                    'pencil',
                    'person-add',
                    'person-follow',
                    'person',
                    'pin',
                    'playback-fast-forward',
                    'playback-pause',
                    'playback-play',
                    'playback-rewind',
                    'plug',
                    'file-add',
                    'file-directory-create',
                    'gist-new',
                    'plus',
                    'repo-create',
                    'podium',
                    'primitive-dot',
                    'primitive-square',
                    'pulse',
                    'puzzle',
                    'question',
                    'quote',
                    'radio-tower',
                    'repo-delete',
                    'repo',
                    'repo-clone',
                    'repo-force-push',
                    'gist-fork',
                    'repo-forked',
                    'repo-pull',
                    'repo-push',
                    'rocket',
                    'rss',
                    'ruby',
                    'screen-full',
                    'screen-normal',
                    'search-save',
                    'search',
                    'server',
                    'settings',
                    'log-in',
                    'sign-in',
                    'log-out',
                    'sign-out',
                    'split',
                    'squirrel',
                    'star-add',
                    'star-delete',
                    'star',
                    'steps',
                    'stop',
                    'repo-sync',
                    'sync',
                    'tag-add',
                    'tag-remove',
                    'tag',
                    'telescope',
                    'terminal',
                    'three-bars',
                    'tools',
                    'trashcan',
                    'triangle-down',
                    'triangle-left',
                    'triangle-right',
                    'triangle-up',
                    'unfold',
                    'unmute',
                    'versions',
                    'remove-close',
                    'x',
                    'zap'
                ]
            },
            {
                version: '2.1.2',
                icons: [
                    '',
                    'alert',
                    'arrow-down',
                    'arrow-left',
                    'arrow-right',
                    'arrow-small-down',
                    'arrow-small-left',
                    'arrow-small-right',
                    'arrow-small-up',
                    'arrow-up',
                    'book',
                    'bookmark',
                    'briefcase',
                    'broadcast',
                    'browser',
                    'bug',
                    'calendar',
                    'check',
                    'checklist',
                    'chevron-down',
                    'chevron-left',
                    'chevron-right',
                    'chevron-up',
                    'circle-slash',
                    'circuit-board',
                    'clippy',
                    'clock',
                    'cloud-download',
                    'cloud-upload',
                    'code',
                    'comment',
                    'comment-add',
                    'comment-discussion',
                    'credit-card',
                    'dash',
                    'dashboard',
                    'database',
                    'device-camera',
                    'device-camera-video',
                    'device-desktop',
                    'device-mobile',
                    'diff',
                    'diff-added',
                    'diff-ignored',
                    'diff-modified',
                    'diff-removed',
                    'diff-renamed',
                    'ellipsis',
                    'eye',
                    'eye-unwatch',
                    'eye-watch',
                    'file-add',
                    'file-binary',
                    'file-code',
                    'file-directory',
                    'file-directory-create',
                    'file-media',
                    'file-pdf',
                    'file-submodule',
                    'file-symlink-directory',
                    'file-symlink-file',
                    'file-text',
                    'file-zip',
                    'flame',
                    'fold',
                    'gear',
                    'gift',
                    'gist',
                    'gist-fork',
                    'gist-new',
                    'gist-private',
                    'gist-secret',
                    'git-branch',
                    'git-branch-create',
                    'git-branch-delete',
                    'git-commit',
                    'git-compare',
                    'git-fork-private',
                    'git-merge',
                    'git-pull-request',
                    'git-pull-request-abandoned',
                    'globe',
                    'graph',
                    'heart',
                    'history',
                    'home',
                    'horizontal-rule',
                    'hubot',
                    'inbox',
                    'info',
                    'issue-closed',
                    'issue-opened',
                    'issue-reopened',
                    'jersey',
                    'key',
                    'keyboard',
                    'law',
                    'light-bulb',
                    'link',
                    'link-external',
                    'list-ordered',
                    'list-unordered',
                    'location',
                    'lock',
                    'log-in',
                    'logo-github',
                    'log-out',
                    'mail',
                    'mail-read',
                    'mail-reply',
                    'markdown',
                    'mark-github',
                    'megaphone',
                    'mention',
                    'microscope',
                    'milestone',
                    'mirror',
                    'mirror-private',
                    'mirror-public',
                    'mortar-board',
                    'mute',
                    'no-newline',
                    'octoface',
                    'organization',
                    'package',
                    'paintcan',
                    'pencil',
                    'person',
                    'person-add',
                    'person-follow',
                    'pin',
                    'plug',
                    'plus',
                    'primitive-dot',
                    'primitive-square',
                    'pulse',
                    'question',
                    'quote',
                    'radio-tower',
                    'remove-close',
                    'repo',
                    'repo-clone',
                    'repo-create',
                    'repo-delete',
                    'repo-force-push',
                    'repo-forked',
                    'repo-pull',
                    'repo-push',
                    'repo-sync',
                    'rocket',
                    'rss',
                    'ruby',
                    'search',
                    'search-save',
                    'server',
                    'settings',
                    'sign-in',
                    'sign-out',
                    'squirrel',
                    'star',
                    'star-add',
                    'star-delete',
                    'stop',
                    'sync',
                    'tag',
                    'tag-add',
                    'tag-remove',
                    'telescope',
                    'terminal',
                    'three-bars',
                    'tools',
                    'trashcan',
                    'triangle-down',
                    'triangle-left',
                    'triangle-right',
                    'triangle-up',
                    'unfold',
                    'unmute',
                    'versions',
                    'x',
                    'zap'
                ]
            },
            {
                version: '2.2.0',
                icons: [
                    '',
                    'alert',
                    'arrow-down',
                    'arrow-left',
                    'arrow-right',
                    'arrow-small-down',
                    'arrow-small-left',
                    'arrow-small-right',
                    'arrow-small-up',
                    'arrow-up',
                    'book',
                    'bookmark',
                    'briefcase',
                    'broadcast',
                    'browser',
                    'bug',
                    'calendar',
                    'check',
                    'checklist',
                    'chevron-down',
                    'chevron-left',
                    'chevron-right',
                    'chevron-up',
                    'circle-slash',
                    'circuit-board',
                    'clippy',
                    'clock',
                    'cloud-download',
                    'cloud-upload',
                    'code',
                    'comment',
                    'comment-add',
                    'comment-discussion',
                    'credit-card',
                    'dash',
                    'dashboard',
                    'database',
                    'device-camera',
                    'device-camera-video',
                    'device-desktop',
                    'device-mobile',
                    'diff',
                    'diff-added',
                    'diff-ignored',
                    'diff-modified',
                    'diff-removed',
                    'diff-renamed',
                    'ellipsis',
                    'eye',
                    'eye-unwatch',
                    'eye-watch',
                    'file-add',
                    'file-binary',
                    'file-code',
                    'file-directory',
                    'file-directory-create',
                    'file-media',
                    'file-pdf',
                    'file-submodule',
                    'file-symlink-directory',
                    'file-symlink-file',
                    'file-text',
                    'file-zip',
                    'flame',
                    'fold',
                    'gear',
                    'gift',
                    'gist',
                    'gist-fork',
                    'gist-new',
                    'gist-private',
                    'gist-secret',
                    'git-branch',
                    'git-branch-create',
                    'git-branch-delete',
                    'git-commit',
                    'git-compare',
                    'git-fork-private',
                    'git-merge',
                    'git-pull-request',
                    'git-pull-request-abandoned',
                    'globe',
                    'graph',
                    'heart',
                    'history',
                    'home',
                    'horizontal-rule',
                    'hubot',
                    'inbox',
                    'info',
                    'issue-closed',
                    'issue-opened',
                    'issue-reopened',
                    'jersey',
                    'key',
                    'keyboard',
                    'law',
                    'light-bulb',
                    'link',
                    'link-external',
                    'list-ordered',
                    'list-unordered',
                    'location',
                    'lock',
                    'log-in',
                    'logo-github',
                    'log-out',
                    'mail',
                    'mail-read',
                    'mail-reply',
                    'markdown',
                    'mark-github',
                    'megaphone',
                    'mention',
                    'microscope',
                    'milestone',
                    'mirror',
                    'mirror-private',
                    'mirror-public',
                    'mortar-board',
                    'mute',
                    'no-newline',
                    'octoface',
                    'organization',
                    'package',
                    'paintcan',
                    'pencil',
                    'person',
                    'person-add',
                    'person-follow',
                    'pin',
                    'plug',
                    'plus',
                    'primitive-dot',
                    'primitive-square',
                    'pulse',
                    'question',
                    'quote',
                    'radio-tower',
                    'remove-close',
                    'repo',
                    'repo-clone',
                    'repo-create',
                    'repo-delete',
                    'repo-force-push',
                    'repo-forked',
                    'repo-pull',
                    'repo-push',
                    'repo-sync',
                    'rocket',
                    'rss',
                    'ruby',
                    'search',
                    'search-save',
                    'server',
                    'settings',
                    'sign-in',
                    'sign-out',
                    'squirrel',
                    'star',
                    'star-add',
                    'star-delete',
                    'stop',
                    'sync',
                    'tag',
                    'tag-add',
                    'tag-remove',
                    'telescope',
                    'terminal',
                    'three-bars',
                    'thumbsdown',
                    'thumbsup',
                    'tools',
                    'trashcan',
                    'triangle-down',
                    'triangle-left',
                    'triangle-right',
                    'triangle-up',
                    'unfold',
                    'unmute',
                    'versions',
                    'x',
                    'zap'
                ]
            },
            {
                version: '2.2.1',
                icons: [
                    '',
                    'alert',
                    'arrow-down',
                    'arrow-left',
                    'arrow-right',
                    'arrow-small-down',
                    'arrow-small-left',
                    'arrow-small-right',
                    'arrow-small-up',
                    'arrow-up',
                    'book',
                    'bookmark',
                    'briefcase',
                    'broadcast',
                    'browser',
                    'bug',
                    'calendar',
                    'check',
                    'checklist',
                    'chevron-down',
                    'chevron-left',
                    'chevron-right',
                    'chevron-up',
                    'circle-slash',
                    'circuit-board',
                    'clippy',
                    'clock',
                    'cloud-download',
                    'cloud-upload',
                    'code',
                    'comment',
                    'comment-add',
                    'comment-discussion',
                    'credit-card',
                    'dash',
                    'dashboard',
                    'database',
                    'device-camera',
                    'device-camera-video',
                    'device-desktop',
                    'device-mobile',
                    'diff',
                    'diff-added',
                    'diff-ignored',
                    'diff-modified',
                    'diff-removed',
                    'diff-renamed',
                    'ellipsis',
                    'eye',
                    'eye-unwatch',
                    'eye-watch',
                    'file-add',
                    'file-binary',
                    'file-code',
                    'file-directory',
                    'file-directory-create',
                    'file-media',
                    'file-pdf',
                    'file-submodule',
                    'file-symlink-directory',
                    'file-symlink-file',
                    'file-text',
                    'file-zip',
                    'flame',
                    'fold',
                    'gear',
                    'gift',
                    'gist',
                    'gist-fork',
                    'gist-new',
                    'gist-private',
                    'gist-secret',
                    'git-branch',
                    'git-branch-create',
                    'git-branch-delete',
                    'git-commit',
                    'git-compare',
                    'git-fork-private',
                    'git-merge',
                    'git-pull-request',
                    'git-pull-request-abandoned',
                    'globe',
                    'graph',
                    'heart',
                    'history',
                    'home',
                    'horizontal-rule',
                    'hubot',
                    'inbox',
                    'info',
                    'issue-closed',
                    'issue-opened',
                    'issue-reopened',
                    'jersey',
                    'key',
                    'keyboard',
                    'law',
                    'light-bulb',
                    'link',
                    'link-external',
                    'list-ordered',
                    'list-unordered',
                    'location',
                    'lock',
                    'log-in',
                    'logo-github',
                    'log-out',
                    'mail',
                    'mail-read',
                    'mail-reply',
                    'markdown',
                    'mark-github',
                    'megaphone',
                    'mention',
                    'microscope',
                    'milestone',
                    'mirror',
                    'mirror-private',
                    'mirror-public',
                    'mortar-board',
                    'mute',
                    'no-newline',
                    'octoface',
                    'organization',
                    'package',
                    'paintcan',
                    'pencil',
                    'person',
                    'person-add',
                    'person-follow',
                    'pin',
                    'plug',
                    'plus',
                    'primitive-dot',
                    'primitive-square',
                    'pulse',
                    'question',
                    'quote',
                    'radio-tower',
                    'remove-close',
                    'repo',
                    'repo-clone',
                    'repo-create',
                    'repo-delete',
                    'repo-force-push',
                    'repo-forked',
                    'repo-pull',
                    'repo-push',
                    'repo-sync',
                    'rocket',
                    'rss',
                    'ruby',
                    'search',
                    'search-save',
                    'server',
                    'settings',
                    'sign-in',
                    'sign-out',
                    'squirrel',
                    'star',
                    'star-add',
                    'star-delete',
                    'stop',
                    'sync',
                    'tag',
                    'tag-add',
                    'tag-remove',
                    'telescope',
                    'terminal',
                    'three-bars',
                    'thumbsdown',
                    'thumbsup',
                    'tools',
                    'trashcan',
                    'triangle-down',
                    'triangle-left',
                    'triangle-right',
                    'triangle-up',
                    'unfold',
                    'unmute',
                    'versions',
                    'x',
                    'zap'
                ]
            },
            {
                version: '2.2.2',
                icons: [
                    '',
                    'alert',
                    'arrow-down',
                    'arrow-left',
                    'arrow-right',
                    'arrow-small-down',
                    'arrow-small-left',
                    'arrow-small-right',
                    'arrow-small-up',
                    'arrow-up',
                    'book',
                    'bookmark',
                    'briefcase',
                    'broadcast',
                    'browser',
                    'bug',
                    'calendar',
                    'check',
                    'checklist',
                    'chevron-down',
                    'chevron-left',
                    'chevron-right',
                    'chevron-up',
                    'circle-slash',
                    'circuit-board',
                    'clippy',
                    'clock',
                    'cloud-download',
                    'cloud-upload',
                    'code',
                    'comment',
                    'comment-add',
                    'comment-discussion',
                    'credit-card',
                    'dash',
                    'dashboard',
                    'database',
                    'device-camera',
                    'device-camera-video',
                    'device-desktop',
                    'device-mobile',
                    'diff',
                    'diff-added',
                    'diff-ignored',
                    'diff-modified',
                    'diff-removed',
                    'diff-renamed',
                    'ellipsis',
                    'eye',
                    'eye-unwatch',
                    'eye-watch',
                    'file-add',
                    'file-binary',
                    'file-code',
                    'file-directory',
                    'file-directory-create',
                    'file-media',
                    'file-pdf',
                    'file-submodule',
                    'file-symlink-directory',
                    'file-symlink-file',
                    'file-text',
                    'file-zip',
                    'flame',
                    'fold',
                    'gear',
                    'gift',
                    'gist',
                    'gist-fork',
                    'gist-new',
                    'gist-private',
                    'gist-secret',
                    'git-branch',
                    'git-branch-create',
                    'git-branch-delete',
                    'git-commit',
                    'git-compare',
                    'git-fork-private',
                    'git-merge',
                    'git-pull-request',
                    'git-pull-request-abandoned',
                    'globe',
                    'graph',
                    'heart',
                    'history',
                    'home',
                    'horizontal-rule',
                    'hubot',
                    'inbox',
                    'info',
                    'issue-closed',
                    'issue-opened',
                    'issue-reopened',
                    'jersey',
                    'key',
                    'keyboard',
                    'law',
                    'light-bulb',
                    'link',
                    'link-external',
                    'list-ordered',
                    'list-unordered',
                    'location',
                    'lock',
                    'log-in',
                    'logo-github',
                    'log-out',
                    'mail',
                    'mail-read',
                    'mail-reply',
                    'markdown',
                    'mark-github',
                    'megaphone',
                    'mention',
                    'microscope',
                    'milestone',
                    'mirror',
                    'mirror-private',
                    'mirror-public',
                    'mortar-board',
                    'mute',
                    'no-newline',
                    'octoface',
                    'organization',
                    'package',
                    'paintcan',
                    'pencil',
                    'person',
                    'person-add',
                    'person-follow',
                    'pin',
                    'plug',
                    'plus',
                    'primitive-dot',
                    'primitive-square',
                    'pulse',
                    'question',
                    'quote',
                    'radio-tower',
                    'remove-close',
                    'repo',
                    'repo-clone',
                    'repo-create',
                    'repo-delete',
                    'repo-force-push',
                    'repo-forked',
                    'repo-pull',
                    'repo-push',
                    'repo-sync',
                    'rocket',
                    'rss',
                    'ruby',
                    'search',
                    'search-save',
                    'server',
                    'settings',
                    'sign-in',
                    'sign-out',
                    'squirrel',
                    'star',
                    'star-add',
                    'star-delete',
                    'stop',
                    'sync',
                    'tag',
                    'tag-add',
                    'tag-remove',
                    'telescope',
                    'terminal',
                    'three-bars',
                    'thumbsdown',
                    'thumbsup',
                    'tools',
                    'trashcan',
                    'triangle-down',
                    'triangle-left',
                    'triangle-right',
                    'triangle-up',
                    'unfold',
                    'unmute',
                    'versions',
                    'x',
                    'zap'
                ]
            },
            {
                version: '2.2.3',
                icons: [
                    '',
                    'alert',
                    'arrow-down',
                    'arrow-left',
                    'arrow-right',
                    'arrow-small-down',
                    'arrow-small-left',
                    'arrow-small-right',
                    'arrow-small-up',
                    'arrow-up',
                    'book',
                    'bookmark',
                    'briefcase',
                    'broadcast',
                    'browser',
                    'bug',
                    'calendar',
                    'check',
                    'checklist',
                    'chevron-down',
                    'chevron-left',
                    'chevron-right',
                    'chevron-up',
                    'circle-slash',
                    'circuit-board',
                    'clippy',
                    'clock',
                    'cloud-download',
                    'cloud-upload',
                    'code',
                    'comment',
                    'comment-add',
                    'comment-discussion',
                    'credit-card',
                    'dash',
                    'dashboard',
                    'database',
                    'device-camera',
                    'device-camera-video',
                    'device-desktop',
                    'device-mobile',
                    'diff',
                    'diff-added',
                    'diff-ignored',
                    'diff-modified',
                    'diff-removed',
                    'diff-renamed',
                    'ellipsis',
                    'eye',
                    'eye-unwatch',
                    'eye-watch',
                    'file-add',
                    'file-binary',
                    'file-code',
                    'file-directory',
                    'file-directory-create',
                    'file-media',
                    'file-pdf',
                    'file-submodule',
                    'file-symlink-directory',
                    'file-symlink-file',
                    'file-text',
                    'file-zip',
                    'flame',
                    'fold',
                    'gear',
                    'gift',
                    'gist',
                    'gist-fork',
                    'gist-new',
                    'gist-private',
                    'gist-secret',
                    'git-branch',
                    'git-branch-create',
                    'git-branch-delete',
                    'git-commit',
                    'git-compare',
                    'git-fork-private',
                    'git-merge',
                    'git-pull-request',
                    'git-pull-request-abandoned',
                    'globe',
                    'graph',
                    'heart',
                    'history',
                    'home',
                    'horizontal-rule',
                    'hubot',
                    'inbox',
                    'info',
                    'issue-closed',
                    'issue-opened',
                    'issue-reopened',
                    'jersey',
                    'key',
                    'keyboard',
                    'law',
                    'light-bulb',
                    'link',
                    'link-external',
                    'list-ordered',
                    'list-unordered',
                    'location',
                    'lock',
                    'log-in',
                    'logo-github',
                    'log-out',
                    'mail',
                    'mail-read',
                    'mail-reply',
                    'markdown',
                    'mark-github',
                    'megaphone',
                    'mention',
                    'microscope',
                    'milestone',
                    'mirror',
                    'mirror-private',
                    'mirror-public',
                    'mortar-board',
                    'mute',
                    'no-newline',
                    'octoface',
                    'organization',
                    'package',
                    'paintcan',
                    'pencil',
                    'person',
                    'person-add',
                    'person-follow',
                    'pin',
                    'plug',
                    'plus',
                    'primitive-dot',
                    'primitive-square',
                    'pulse',
                    'question',
                    'quote',
                    'radio-tower',
                    'remove-close',
                    'repo',
                    'repo-clone',
                    'repo-create',
                    'repo-delete',
                    'repo-force-push',
                    'repo-forked',
                    'repo-pull',
                    'repo-push',
                    'repo-sync',
                    'rocket',
                    'rss',
                    'ruby',
                    'search',
                    'search-save',
                    'server',
                    'settings',
                    'sign-in',
                    'sign-out',
                    'squirrel',
                    'star',
                    'star-add',
                    'star-delete',
                    'stop',
                    'sync',
                    'tag',
                    'tag-add',
                    'tag-remove',
                    'telescope',
                    'terminal',
                    'three-bars',
                    'thumbsdown',
                    'thumbsup',
                    'tools',
                    'trashcan',
                    'triangle-down',
                    'triangle-left',
                    'triangle-right',
                    'triangle-up',
                    'unfold',
                    'unmute',
                    'versions',
                    'x',
                    'zap'
                ]
            },
            {
                version: '2.3.0',
                icons: [
                    '',
                    'alert',
                    'arrow-down',
                    'arrow-left',
                    'arrow-right',
                    'arrow-small-down',
                    'arrow-small-left',
                    'arrow-small-right',
                    'arrow-small-up',
                    'arrow-up',
                    'book',
                    'bookmark',
                    'briefcase',
                    'broadcast',
                    'browser',
                    'bug',
                    'calendar',
                    'check',
                    'checklist',
                    'chevron-down',
                    'chevron-left',
                    'chevron-right',
                    'chevron-up',
                    'circle-slash',
                    'circuit-board',
                    'clippy',
                    'clock',
                    'cloud-download',
                    'cloud-upload',
                    'code',
                    'comment',
                    'comment-add',
                    'comment-discussion',
                    'credit-card',
                    'dash',
                    'dashboard',
                    'database',
                    'device-camera',
                    'device-camera-video',
                    'device-desktop',
                    'device-mobile',
                    'diff',
                    'diff-added',
                    'diff-ignored',
                    'diff-modified',
                    'diff-removed',
                    'diff-renamed',
                    'ellipsis',
                    'eye',
                    'eye-unwatch',
                    'eye-watch',
                    'file-add',
                    'file-binary',
                    'file-code',
                    'file-directory',
                    'file-directory-create',
                    'file-media',
                    'file-pdf',
                    'file-submodule',
                    'file-symlink-directory',
                    'file-symlink-file',
                    'file-text',
                    'file-zip',
                    'flame',
                    'fold',
                    'gear',
                    'gift',
                    'gist',
                    'gist-fork',
                    'gist-new',
                    'gist-private',
                    'gist-secret',
                    'git-branch',
                    'git-branch-create',
                    'git-branch-delete',
                    'git-commit',
                    'git-compare',
                    'git-fork-private',
                    'git-merge',
                    'git-pull-request',
                    'git-pull-request-abandoned',
                    'globe',
                    'graph',
                    'heart',
                    'history',
                    'home',
                    'horizontal-rule',
                    'hubot',
                    'inbox',
                    'info',
                    'issue-closed',
                    'issue-opened',
                    'issue-reopened',
                    'jersey',
                    'key',
                    'keyboard',
                    'law',
                    'light-bulb',
                    'link',
                    'link-external',
                    'list-ordered',
                    'list-unordered',
                    'location',
                    'lock',
                    'log-in',
                    'logo-github',
                    'log-out',
                    'mail',
                    'mail-read',
                    'mail-reply',
                    'markdown',
                    'mark-github',
                    'megaphone',
                    'mention',
                    'microscope',
                    'milestone',
                    'mirror',
                    'mirror-private',
                    'mirror-public',
                    'mortar-board',
                    'mute',
                    'no-newline',
                    'octoface',
                    'organization',
                    'package',
                    'paintcan',
                    'pencil',
                    'person',
                    'person-add',
                    'person-follow',
                    'pin',
                    'plug',
                    'plus',
                    'primitive-dot',
                    'primitive-square',
                    'pulse',
                    'question',
                    'quote',
                    'radio-tower',
                    'remove-close',
                    'repo',
                    'repo-clone',
                    'repo-create',
                    'repo-delete',
                    'repo-force-push',
                    'repo-forked',
                    'repo-pull',
                    'repo-push',
                    'repo-sync',
                    'rocket',
                    'rss',
                    'ruby',
                    'search',
                    'search-save',
                    'server',
                    'settings',
                    'sign-in',
                    'sign-out',
                    'squirrel',
                    'star',
                    'star-add',
                    'star-delete',
                    'stop',
                    'sync',
                    'tag',
                    'tag-add',
                    'tag-remove',
                    'telescope',
                    'terminal',
                    'three-bars',
                    'thumbsdown',
                    'thumbsup',
                    'tools',
                    'trashcan',
                    'triangle-down',
                    'triangle-left',
                    'triangle-right',
                    'triangle-up',
                    'unfold',
                    'unmute',
                    'versions',
                    'x',
                    'zap'
                ]
            },
            {
                version: '2.4.0',
                icons: [
                    '',
                    'alert',
                    'arrow-down',
                    'arrow-left',
                    'arrow-right',
                    'arrow-small-down',
                    'arrow-small-left',
                    'arrow-small-right',
                    'arrow-small-up',
                    'arrow-up',
                    'book',
                    'bookmark',
                    'briefcase',
                    'broadcast',
                    'browser',
                    'bug',
                    'calendar',
                    'check',
                    'checklist',
                    'chevron-down',
                    'chevron-left',
                    'chevron-right',
                    'chevron-up',
                    'circle-slash',
                    'circuit-board',
                    'clippy',
                    'clock',
                    'cloud-download',
                    'cloud-upload',
                    'code',
                    'comment',
                    'comment-add',
                    'comment-discussion',
                    'credit-card',
                    'dash',
                    'dashboard',
                    'database',
                    'device-camera',
                    'device-camera-video',
                    'device-desktop',
                    'device-mobile',
                    'diff',
                    'diff-added',
                    'diff-ignored',
                    'diff-modified',
                    'diff-removed',
                    'diff-renamed',
                    'ellipsis',
                    'eye',
                    'eye-unwatch',
                    'eye-watch',
                    'file-add',
                    'file-binary',
                    'file-code',
                    'file-directory',
                    'file-directory-create',
                    'file-media',
                    'file-pdf',
                    'file-submodule',
                    'file-symlink-directory',
                    'file-symlink-file',
                    'file-text',
                    'file-zip',
                    'flame',
                    'fold',
                    'gear',
                    'gift',
                    'gist',
                    'gist-fork',
                    'gist-new',
                    'gist-private',
                    'gist-secret',
                    'git-branch',
                    'git-branch-create',
                    'git-branch-delete',
                    'git-commit',
                    'git-compare',
                    'git-fork-private',
                    'git-merge',
                    'git-pull-request',
                    'git-pull-request-abandoned',
                    'globe',
                    'graph',
                    'heart',
                    'history',
                    'home',
                    'horizontal-rule',
                    'hubot',
                    'inbox',
                    'info',
                    'issue-closed',
                    'issue-opened',
                    'issue-reopened',
                    'jersey',
                    'key',
                    'keyboard',
                    'law',
                    'light-bulb',
                    'link',
                    'link-external',
                    'list-ordered',
                    'list-unordered',
                    'location',
                    'lock',
                    'log-in',
                    'logo-github',
                    'log-out',
                    'mail',
                    'mail-read',
                    'mail-reply',
                    'markdown',
                    'mark-github',
                    'megaphone',
                    'mention',
                    'microscope',
                    'milestone',
                    'mirror',
                    'mirror-private',
                    'mirror-public',
                    'mortar-board',
                    'mute',
                    'no-newline',
                    'octoface',
                    'organization',
                    'package',
                    'paintcan',
                    'pencil',
                    'person',
                    'person-add',
                    'person-follow',
                    'pin',
                    'plug',
                    'plus',
                    'primitive-dot',
                    'primitive-square',
                    'pulse',
                    'question',
                    'quote',
                    'radio-tower',
                    'remove-close',
                    'repo',
                    'repo-clone',
                    'repo-create',
                    'repo-delete',
                    'repo-force-push',
                    'repo-forked',
                    'repo-pull',
                    'repo-push',
                    'repo-sync',
                    'rocket',
                    'rss',
                    'ruby',
                    'search',
                    'search-save',
                    'server',
                    'settings',
                    'sign-in',
                    'sign-out',
                    'squirrel',
                    'star',
                    'star-add',
                    'star-delete',
                    'stop',
                    'sync',
                    'tag',
                    'tag-add',
                    'tag-remove',
                    'telescope',
                    'terminal',
                    'three-bars',
                    'thumbsdown',
                    'thumbsup',
                    'tools',
                    'trashcan',
                    'triangle-down',
                    'triangle-left',
                    'triangle-right',
                    'triangle-up',
                    'unfold',
                    'unmute',
                    'versions',
                    'x',
                    'zap'
                ]
            },
            {
                version: '2.4.1',
                icons: [
                    '',
                    'alert',
                    'arrow-down',
                    'arrow-left',
                    'arrow-right',
                    'arrow-small-down',
                    'arrow-small-left',
                    'arrow-small-right',
                    'arrow-small-up',
                    'arrow-up',
                    'book',
                    'bookmark',
                    'briefcase',
                    'broadcast',
                    'browser',
                    'bug',
                    'calendar',
                    'check',
                    'checklist',
                    'chevron-down',
                    'chevron-left',
                    'chevron-right',
                    'chevron-up',
                    'circle-slash',
                    'circuit-board',
                    'clippy',
                    'clock',
                    'cloud-download',
                    'cloud-upload',
                    'code',
                    'comment',
                    'comment-add',
                    'comment-discussion',
                    'credit-card',
                    'dash',
                    'dashboard',
                    'database',
                    'device-camera',
                    'device-camera-video',
                    'device-desktop',
                    'device-mobile',
                    'diff',
                    'diff-added',
                    'diff-ignored',
                    'diff-modified',
                    'diff-removed',
                    'diff-renamed',
                    'ellipsis',
                    'eye',
                    'eye-unwatch',
                    'eye-watch',
                    'file-add',
                    'file-binary',
                    'file-code',
                    'file-directory',
                    'file-directory-create',
                    'file-media',
                    'file-pdf',
                    'file-submodule',
                    'file-symlink-directory',
                    'file-symlink-file',
                    'file-text',
                    'file-zip',
                    'flame',
                    'fold',
                    'gear',
                    'gift',
                    'gist',
                    'gist-fork',
                    'gist-new',
                    'gist-private',
                    'gist-secret',
                    'git-branch',
                    'git-branch-create',
                    'git-branch-delete',
                    'git-commit',
                    'git-compare',
                    'git-fork-private',
                    'git-merge',
                    'git-pull-request',
                    'git-pull-request-abandoned',
                    'globe',
                    'graph',
                    'heart',
                    'history',
                    'home',
                    'horizontal-rule',
                    'hubot',
                    'inbox',
                    'info',
                    'issue-closed',
                    'issue-opened',
                    'issue-reopened',
                    'jersey',
                    'key',
                    'keyboard',
                    'law',
                    'light-bulb',
                    'link',
                    'link-external',
                    'list-ordered',
                    'list-unordered',
                    'location',
                    'lock',
                    'log-in',
                    'logo-github',
                    'log-out',
                    'mail',
                    'mail-read',
                    'mail-reply',
                    'markdown',
                    'mark-github',
                    'megaphone',
                    'mention',
                    'microscope',
                    'milestone',
                    'mirror',
                    'mirror-private',
                    'mirror-public',
                    'mortar-board',
                    'mute',
                    'no-newline',
                    'octoface',
                    'organization',
                    'package',
                    'paintcan',
                    'pencil',
                    'person',
                    'person-add',
                    'person-follow',
                    'pin',
                    'plug',
                    'plus',
                    'primitive-dot',
                    'primitive-square',
                    'pulse',
                    'question',
                    'quote',
                    'radio-tower',
                    'remove-close',
                    'repo',
                    'repo-clone',
                    'repo-create',
                    'repo-delete',
                    'repo-force-push',
                    'repo-forked',
                    'repo-pull',
                    'repo-push',
                    'repo-sync',
                    'rocket',
                    'rss',
                    'ruby',
                    'search',
                    'search-save',
                    'server',
                    'settings',
                    'sign-in',
                    'sign-out',
                    'squirrel',
                    'star',
                    'star-add',
                    'star-delete',
                    'stop',
                    'sync',
                    'tag',
                    'tag-add',
                    'tag-remove',
                    'telescope',
                    'terminal',
                    'three-bars',
                    'thumbsdown',
                    'thumbsup',
                    'tools',
                    'trashcan',
                    'triangle-down',
                    'triangle-left',
                    'triangle-right',
                    'triangle-up',
                    'unfold',
                    'unmute',
                    'versions',
                    'x',
                    'zap'
                ]
            },
            {
                version: '3.0.0',
                icons: [
                    '',
                    'alert',
                    'arrow-down',
                    'arrow-left',
                    'arrow-right',
                    'arrow-small-down',
                    'arrow-small-left',
                    'arrow-small-right',
                    'arrow-small-up',
                    'arrow-up',
                    'beaker',
                    'bell',
                    'book',
                    'bookmark',
                    'briefcase',
                    'broadcast',
                    'browser',
                    'bug',
                    'calendar',
                    'check',
                    'checklist',
                    'chevron-down',
                    'chevron-left',
                    'chevron-right',
                    'chevron-up',
                    'circle-slash',
                    'circuit-board',
                    'clippy',
                    'clock',
                    'clone',
                    'cloud-download',
                    'cloud-upload',
                    'code',
                    'comment',
                    'comment-add',
                    'comment-discussion',
                    'credit-card',
                    'dash',
                    'dashboard',
                    'database',
                    'desktop-download',
                    'device-camera',
                    'device-camera-video',
                    'device-desktop',
                    'device-mobile',
                    'diff',
                    'diff-added',
                    'diff-ignored',
                    'diff-modified',
                    'diff-removed',
                    'diff-renamed',
                    'ellipsis',
                    'eye',
                    'eye-unwatch',
                    'eye-watch',
                    'file-add',
                    'file-binary',
                    'file-code',
                    'file-directory',
                    'file-directory-create',
                    'file-media',
                    'file-pdf',
                    'file-submodule',
                    'file-symlink-directory',
                    'file-symlink-file',
                    'file-text',
                    'file-zip',
                    'flame',
                    'fold',
                    'gear',
                    'gift',
                    'gist',
                    'gist-fork',
                    'gist-new',
                    'gist-private',
                    'gist-secret',
                    'git-branch',
                    'git-branch-create',
                    'git-branch-delete',
                    'git-commit',
                    'git-compare',
                    'git-fork-private',
                    'git-merge',
                    'git-pull-request',
                    'git-pull-request-abandoned',
                    'globe',
                    'graph',
                    'heart',
                    'history',
                    'home',
                    'horizontal-rule',
                    'hubot',
                    'inbox',
                    'info',
                    'issue-closed',
                    'issue-opened',
                    'issue-reopened',
                    'jersey',
                    'key',
                    'keyboard',
                    'law',
                    'light-bulb',
                    'link',
                    'link-external',
                    'list-ordered',
                    'list-unordered',
                    'location',
                    'lock',
                    'log-in',
                    'logo-github',
                    'log-out',
                    'mail',
                    'mail-read',
                    'mail-reply',
                    'markdown',
                    'mark-github',
                    'megaphone',
                    'mention',
                    'microscope',
                    'milestone',
                    'mirror',
                    'mirror-private',
                    'mirror-public',
                    'mortar-board',
                    'mute',
                    'no-newline',
                    'octoface',
                    'organization',
                    'package',
                    'paintcan',
                    'pencil',
                    'person',
                    'person-add',
                    'person-follow',
                    'pin',
                    'plug',
                    'plus',
                    'primitive-dot',
                    'primitive-square',
                    'pulse',
                    'question',
                    'quote',
                    'radio-tower',
                    'remove-close',
                    'repo',
                    'repo-clone',
                    'repo-create',
                    'repo-delete',
                    'repo-force-push',
                    'repo-forked',
                    'repo-pull',
                    'repo-push',
                    'repo-sync',
                    'rocket',
                    'rss',
                    'ruby',
                    'search',
                    'search-save',
                    'server',
                    'settings',
                    'sign-in',
                    'sign-out',
                    'squirrel',
                    'star',
                    'star-add',
                    'star-delete',
                    'stop',
                    'sync',
                    'tag',
                    'tag-add',
                    'tag-remove',
                    'telescope',
                    'terminal',
                    'three-bars',
                    'thumbsdown',
                    'thumbsup',
                    'tools',
                    'trashcan',
                    'triangle-down',
                    'triangle-left',
                    'triangle-right',
                    'triangle-up',
                    'unfold',
                    'unmute',
                    'versions',
                    'watch',
                    'x',
                    'zap'
                ]
            },
            {
                version: '3.1.0',
                icons: [
                    '',
                    'alert',
                    'arrow-down',
                    'arrow-left',
                    'arrow-right',
                    'arrow-small-down',
                    'arrow-small-left',
                    'arrow-small-right',
                    'arrow-small-up',
                    'arrow-up',
                    'beaker',
                    'bell',
                    'book',
                    'bookmark',
                    'briefcase',
                    'broadcast',
                    'browser',
                    'bug',
                    'calendar',
                    'check',
                    'checklist',
                    'chevron-down',
                    'chevron-left',
                    'chevron-right',
                    'chevron-up',
                    'circle-slash',
                    'circuit-board',
                    'clippy',
                    'clock',
                    'clone',
                    'cloud-download',
                    'cloud-upload',
                    'code',
                    'comment',
                    'comment-add',
                    'comment-discussion',
                    'credit-card',
                    'dash',
                    'dashboard',
                    'database',
                    'desktop-download',
                    'device-camera',
                    'device-camera-video',
                    'device-desktop',
                    'device-mobile',
                    'diff',
                    'diff-added',
                    'diff-ignored',
                    'diff-modified',
                    'diff-removed',
                    'diff-renamed',
                    'ellipsis',
                    'eye',
                    'eye-unwatch',
                    'eye-watch',
                    'file-add',
                    'file-binary',
                    'file-code',
                    'file-directory',
                    'file-directory-create',
                    'file-media',
                    'file-pdf',
                    'file-submodule',
                    'file-symlink-directory',
                    'file-symlink-file',
                    'file-text',
                    'file-zip',
                    'flame',
                    'fold',
                    'gear',
                    'gift',
                    'gist',
                    'gist-fork',
                    'gist-new',
                    'gist-private',
                    'gist-secret',
                    'git-branch',
                    'git-branch-create',
                    'git-branch-delete',
                    'git-commit',
                    'git-compare',
                    'git-fork-private',
                    'git-merge',
                    'git-pull-request',
                    'git-pull-request-abandoned',
                    'globe',
                    'graph',
                    'heart',
                    'history',
                    'home',
                    'horizontal-rule',
                    'hubot',
                    'inbox',
                    'info',
                    'issue-closed',
                    'issue-opened',
                    'issue-reopened',
                    'jersey',
                    'key',
                    'keyboard',
                    'law',
                    'light-bulb',
                    'link',
                    'link-external',
                    'list-ordered',
                    'list-unordered',
                    'location',
                    'lock',
                    'log-in',
                    'logo-github',
                    'log-out',
                    'mail',
                    'mail-read',
                    'mail-reply',
                    'markdown',
                    'mark-github',
                    'megaphone',
                    'mention',
                    'microscope',
                    'milestone',
                    'mirror',
                    'mirror-private',
                    'mirror-public',
                    'mortar-board',
                    'mute',
                    'no-newline',
                    'octoface',
                    'organization',
                    'package',
                    'paintcan',
                    'pencil',
                    'person',
                    'person-add',
                    'person-follow',
                    'pin',
                    'plug',
                    'plus',
                    'primitive-dot',
                    'primitive-square',
                    'pulse',
                    'question',
                    'quote',
                    'radio-tower',
                    'remove-close',
                    'repo',
                    'repo-clone',
                    'repo-create',
                    'repo-delete',
                    'repo-force-push',
                    'repo-forked',
                    'repo-pull',
                    'repo-push',
                    'repo-sync',
                    'rocket',
                    'rss',
                    'ruby',
                    'search',
                    'search-save',
                    'server',
                    'settings',
                    'shield',
                    'sign-in',
                    'sign-out',
                    'squirrel',
                    'star',
                    'star-add',
                    'star-delete',
                    'stop',
                    'sync',
                    'tag',
                    'tag-add',
                    'tag-remove',
                    'telescope',
                    'terminal',
                    'three-bars',
                    'thumbsdown',
                    'thumbsup',
                    'tools',
                    'trashcan',
                    'triangle-down',
                    'triangle-left',
                    'triangle-right',
                    'triangle-up',
                    'unfold',
                    'unmute',
                    'versions',
                    'watch',
                    'x',
                    'zap'
                ]
            },
            {
                version: '3.2.0',
                icons: [
                    '',
                    'alert',
                    'arrow-down',
                    'arrow-left',
                    'arrow-right',
                    'arrow-small-down',
                    'arrow-small-left',
                    'arrow-small-right',
                    'arrow-small-up',
                    'arrow-up',
                    'beaker',
                    'bell',
                    'bold',
                    'book',
                    'bookmark',
                    'briefcase',
                    'broadcast',
                    'browser',
                    'bug',
                    'calendar',
                    'check',
                    'checklist',
                    'chevron-down',
                    'chevron-left',
                    'chevron-right',
                    'chevron-up',
                    'circle-slash',
                    'circuit-board',
                    'clippy',
                    'clock',
                    'clone',
                    'cloud-download',
                    'cloud-upload',
                    'code',
                    'comment',
                    'comment-add',
                    'comment-discussion',
                    'credit-card',
                    'dash',
                    'dashboard',
                    'database',
                    'desktop-download',
                    'device-camera',
                    'device-camera-video',
                    'device-desktop',
                    'device-mobile',
                    'diff',
                    'diff-added',
                    'diff-ignored',
                    'diff-modified',
                    'diff-removed',
                    'diff-renamed',
                    'ellipsis',
                    'eye',
                    'eye-unwatch',
                    'eye-watch',
                    'file-add',
                    'file-binary',
                    'file-code',
                    'file-directory',
                    'file-directory-create',
                    'file-media',
                    'file-pdf',
                    'file-submodule',
                    'file-symlink-directory',
                    'file-symlink-file',
                    'file-text',
                    'file-zip',
                    'flame',
                    'fold',
                    'gear',
                    'gift',
                    'gist',
                    'gist-fork',
                    'gist-new',
                    'gist-private',
                    'gist-secret',
                    'git-branch',
                    'git-branch-create',
                    'git-branch-delete',
                    'git-commit',
                    'git-compare',
                    'git-fork-private',
                    'git-merge',
                    'git-pull-request',
                    'git-pull-request-abandoned',
                    'globe',
                    'graph',
                    'heart',
                    'history',
                    'home',
                    'horizontal-rule',
                    'hubot',
                    'inbox',
                    'info',
                    'issue-closed',
                    'issue-opened',
                    'issue-reopened',
                    'italic',
                    'jersey',
                    'key',
                    'keyboard',
                    'law',
                    'light-bulb',
                    'link',
                    'link-external',
                    'list-ordered',
                    'list-unordered',
                    'location',
                    'lock',
                    'log-in',
                    'logo-github',
                    'log-out',
                    'mail',
                    'mail-read',
                    'mail-reply',
                    'markdown',
                    'mark-github',
                    'megaphone',
                    'mention',
                    'microscope',
                    'milestone',
                    'mirror',
                    'mirror-private',
                    'mirror-public',
                    'mortar-board',
                    'mute',
                    'no-newline',
                    'octoface',
                    'organization',
                    'package',
                    'paintcan',
                    'pencil',
                    'person',
                    'person-add',
                    'person-follow',
                    'pin',
                    'plug',
                    'plus',
                    'primitive-dot',
                    'primitive-square',
                    'pulse',
                    'question',
                    'quote',
                    'radio-tower',
                    'remove-close',
                    'repo',
                    'repo-clone',
                    'repo-create',
                    'repo-delete',
                    'repo-force-push',
                    'repo-forked',
                    'repo-pull',
                    'repo-push',
                    'repo-sync',
                    'rocket',
                    'rss',
                    'ruby',
                    'search',
                    'search-save',
                    'server',
                    'settings',
                    'shield',
                    'sign-in',
                    'sign-out',
                    'squirrel',
                    'star',
                    'star-add',
                    'star-delete',
                    'stop',
                    'sync',
                    'tag',
                    'tag-add',
                    'tag-remove',
                    'tasklist',
                    'telescope',
                    'terminal',
                    'text-size',
                    'three-bars',
                    'thumbsdown',
                    'thumbsup',
                    'tools',
                    'trashcan',
                    'triangle-down',
                    'triangle-left',
                    'triangle-right',
                    'triangle-up',
                    'unfold',
                    'unmute',
                    'versions',
                    'watch',
                    'x',
                    'zap'
                ]
            },
            {
                version: '3.3.0',
                icons: [
                    '',
                    'alert',
                    'arrow-down',
                    'arrow-left',
                    'arrow-right',
                    'arrow-small-down',
                    'arrow-small-left',
                    'arrow-small-right',
                    'arrow-small-up',
                    'arrow-up',
                    'beaker',
                    'bell',
                    'bold',
                    'book',
                    'bookmark',
                    'briefcase',
                    'broadcast',
                    'browser',
                    'bug',
                    'calendar',
                    'check',
                    'checklist',
                    'chevron-down',
                    'chevron-left',
                    'chevron-right',
                    'chevron-up',
                    'circle-slash',
                    'circuit-board',
                    'clippy',
                    'clock',
                    'clone',
                    'cloud-download',
                    'cloud-upload',
                    'code',
                    'comment',
                    'comment-add',
                    'comment-discussion',
                    'credit-card',
                    'dash',
                    'dashboard',
                    'database',
                    'desktop-download',
                    'device-camera',
                    'device-camera-video',
                    'device-desktop',
                    'device-mobile',
                    'diff',
                    'diff-added',
                    'diff-ignored',
                    'diff-modified',
                    'diff-removed',
                    'diff-renamed',
                    'ellipsis',
                    'eye',
                    'eye-unwatch',
                    'eye-watch',
                    'file-add',
                    'file-binary',
                    'file-code',
                    'file-directory',
                    'file-directory-create',
                    'file-media',
                    'file-pdf',
                    'file-submodule',
                    'file-symlink-directory',
                    'file-symlink-file',
                    'file-text',
                    'file-zip',
                    'flame',
                    'fold',
                    'gear',
                    'gift',
                    'gist',
                    'gist-fork',
                    'gist-new',
                    'gist-private',
                    'gist-secret',
                    'git-branch',
                    'git-branch-create',
                    'git-branch-delete',
                    'git-commit',
                    'git-compare',
                    'git-fork-private',
                    'git-merge',
                    'git-pull-request',
                    'git-pull-request-abandoned',
                    'globe',
                    'graph',
                    'heart',
                    'history',
                    'home',
                    'horizontal-rule',
                    'hubot',
                    'inbox',
                    'info',
                    'issue-closed',
                    'issue-opened',
                    'issue-reopened',
                    'italic',
                    'jersey',
                    'key',
                    'keyboard',
                    'law',
                    'light-bulb',
                    'link',
                    'link-external',
                    'list-ordered',
                    'list-unordered',
                    'location',
                    'lock',
                    'log-in',
                    'logo-gist',
                    'logo-github',
                    'log-out',
                    'mail',
                    'mail-read',
                    'mail-reply',
                    'markdown',
                    'mark-github',
                    'megaphone',
                    'mention',
                    'microscope',
                    'milestone',
                    'mirror',
                    'mirror-private',
                    'mirror-public',
                    'mortar-board',
                    'mute',
                    'no-newline',
                    'octoface',
                    'organization',
                    'package',
                    'paintcan',
                    'pencil',
                    'person',
                    'person-add',
                    'person-follow',
                    'pin',
                    'plug',
                    'plus',
                    'primitive-dot',
                    'primitive-square',
                    'pulse',
                    'question',
                    'quote',
                    'radio-tower',
                    'remove-close',
                    'repo',
                    'repo-clone',
                    'repo-create',
                    'repo-delete',
                    'repo-force-push',
                    'repo-forked',
                    'repo-pull',
                    'repo-push',
                    'repo-sync',
                    'rocket',
                    'rss',
                    'ruby',
                    'search',
                    'search-save',
                    'server',
                    'settings',
                    'shield',
                    'sign-in',
                    'sign-out',
                    'squirrel',
                    'star',
                    'star-add',
                    'star-delete',
                    'stop',
                    'sync',
                    'tag',
                    'tag-add',
                    'tag-remove',
                    'tasklist',
                    'telescope',
                    'terminal',
                    'text-size',
                    'three-bars',
                    'thumbsdown',
                    'thumbsup',
                    'tools',
                    'trashcan',
                    'triangle-down',
                    'triangle-left',
                    'triangle-right',
                    'triangle-up',
                    'unfold',
                    'unmute',
                    'versions',
                    'watch',
                    'x',
                    'zap'
                ]
            },
            {
                version: '3.4.0',
                icons: [
                    '',
                    'alert',
                    'arrow-down',
                    'arrow-left',
                    'arrow-right',
                    'arrow-small-down',
                    'arrow-small-left',
                    'arrow-small-right',
                    'arrow-small-up',
                    'arrow-up',
                    'beaker',
                    'bell',
                    'bold',
                    'book',
                    'bookmark',
                    'briefcase',
                    'broadcast',
                    'browser',
                    'bug',
                    'calendar',
                    'check',
                    'checklist',
                    'chevron-down',
                    'chevron-left',
                    'chevron-right',
                    'chevron-up',
                    'circle-slash',
                    'circuit-board',
                    'clippy',
                    'clock',
                    'clone',
                    'cloud-download',
                    'cloud-upload',
                    'code',
                    'comment',
                    'comment-add',
                    'comment-discussion',
                    'credit-card',
                    'dash',
                    'dashboard',
                    'database',
                    'desktop-download',
                    'device-camera',
                    'device-camera-video',
                    'device-desktop',
                    'device-mobile',
                    'diff',
                    'diff-added',
                    'diff-ignored',
                    'diff-modified',
                    'diff-removed',
                    'diff-renamed',
                    'ellipsis',
                    'eye',
                    'eye-unwatch',
                    'eye-watch',
                    'file-add',
                    'file-binary',
                    'file-code',
                    'file-directory',
                    'file-directory-create',
                    'file-media',
                    'file-pdf',
                    'file-submodule',
                    'file-symlink-directory',
                    'file-symlink-file',
                    'file-text',
                    'file-zip',
                    'flame',
                    'fold',
                    'gear',
                    'gift',
                    'gist',
                    'gist-fork',
                    'gist-new',
                    'gist-private',
                    'gist-secret',
                    'git-branch',
                    'git-branch-create',
                    'git-branch-delete',
                    'git-commit',
                    'git-compare',
                    'git-fork-private',
                    'git-merge',
                    'git-pull-request',
                    'git-pull-request-abandoned',
                    'globe',
                    'graph',
                    'heart',
                    'history',
                    'home',
                    'horizontal-rule',
                    'hubot',
                    'inbox',
                    'info',
                    'issue-closed',
                    'issue-opened',
                    'issue-reopened',
                    'italic',
                    'jersey',
                    'key',
                    'keyboard',
                    'law',
                    'light-bulb',
                    'link',
                    'link-external',
                    'list-ordered',
                    'list-unordered',
                    'location',
                    'lock',
                    'log-in',
                    'logo-gist',
                    'logo-github',
                    'log-out',
                    'mail',
                    'mail-read',
                    'mail-reply',
                    'markdown',
                    'mark-github',
                    'megaphone',
                    'mention',
                    'microscope',
                    'milestone',
                    'mirror',
                    'mirror-private',
                    'mirror-public',
                    'mortar-board',
                    'mute',
                    'no-newline',
                    'octoface',
                    'organization',
                    'package',
                    'paintcan',
                    'pencil',
                    'person',
                    'person-add',
                    'person-follow',
                    'pin',
                    'plug',
                    'plus',
                    'primitive-dot',
                    'primitive-square',
                    'pulse',
                    'question',
                    'quote',
                    'radio-tower',
                    'remove-close',
                    'repo',
                    'repo-clone',
                    'repo-create',
                    'repo-delete',
                    'repo-force-push',
                    'repo-forked',
                    'repo-pull',
                    'repo-push',
                    'repo-sync',
                    'rocket',
                    'rss',
                    'ruby',
                    'search',
                    'search-save',
                    'server',
                    'settings',
                    'shield',
                    'sign-in',
                    'sign-out',
                    'smiley',
                    'squirrel',
                    'star',
                    'star-add',
                    'star-delete',
                    'stop',
                    'sync',
                    'tag',
                    'tag-add',
                    'tag-remove',
                    'tasklist',
                    'telescope',
                    'terminal',
                    'text-size',
                    'three-bars',
                    'thumbsdown',
                    'thumbsup',
                    'tools',
                    'trashcan',
                    'triangle-down',
                    'triangle-left',
                    'triangle-right',
                    'triangle-up',
                    'unfold',
                    'unmute',
                    'verified',
                    'versions',
                    'watch',
                    'x',
                    'zap'
                ]
            },
            {
                version: '3.4.1',
                icons: [
                    '',
                    'alert',
                    'arrow-down',
                    'arrow-left',
                    'arrow-right',
                    'arrow-small-down',
                    'arrow-small-left',
                    'arrow-small-right',
                    'arrow-small-up',
                    'arrow-up',
                    'beaker',
                    'bell',
                    'bold',
                    'book',
                    'bookmark',
                    'briefcase',
                    'broadcast',
                    'browser',
                    'bug',
                    'calendar',
                    'check',
                    'checklist',
                    'chevron-down',
                    'chevron-left',
                    'chevron-right',
                    'chevron-up',
                    'circle-slash',
                    'circuit-board',
                    'clippy',
                    'clock',
                    'clone',
                    'cloud-download',
                    'cloud-upload',
                    'code',
                    'comment',
                    'comment-add',
                    'comment-discussion',
                    'credit-card',
                    'dash',
                    'dashboard',
                    'database',
                    'desktop-download',
                    'device-camera',
                    'device-camera-video',
                    'device-desktop',
                    'device-mobile',
                    'diff',
                    'diff-added',
                    'diff-ignored',
                    'diff-modified',
                    'diff-removed',
                    'diff-renamed',
                    'ellipsis',
                    'eye',
                    'eye-unwatch',
                    'eye-watch',
                    'file-add',
                    'file-binary',
                    'file-code',
                    'file-directory',
                    'file-directory-create',
                    'file-media',
                    'file-pdf',
                    'file-submodule',
                    'file-symlink-directory',
                    'file-symlink-file',
                    'file-text',
                    'file-zip',
                    'flame',
                    'fold',
                    'gear',
                    'gift',
                    'gist',
                    'gist-fork',
                    'gist-new',
                    'gist-private',
                    'gist-secret',
                    'git-branch',
                    'git-branch-create',
                    'git-branch-delete',
                    'git-commit',
                    'git-compare',
                    'git-fork-private',
                    'git-merge',
                    'git-pull-request',
                    'git-pull-request-abandoned',
                    'globe',
                    'graph',
                    'heart',
                    'history',
                    'home',
                    'horizontal-rule',
                    'hubot',
                    'inbox',
                    'info',
                    'issue-closed',
                    'issue-opened',
                    'issue-reopened',
                    'italic',
                    'jersey',
                    'key',
                    'keyboard',
                    'law',
                    'light-bulb',
                    'link',
                    'link-external',
                    'list-ordered',
                    'list-unordered',
                    'location',
                    'lock',
                    'log-in',
                    'logo-gist',
                    'logo-github',
                    'log-out',
                    'mail',
                    'mail-read',
                    'mail-reply',
                    'markdown',
                    'mark-github',
                    'megaphone',
                    'mention',
                    'microscope',
                    'milestone',
                    'mirror',
                    'mirror-private',
                    'mirror-public',
                    'mortar-board',
                    'mute',
                    'no-newline',
                    'octoface',
                    'organization',
                    'package',
                    'paintcan',
                    'pencil',
                    'person',
                    'person-add',
                    'person-follow',
                    'pin',
                    'plug',
                    'plus',
                    'primitive-dot',
                    'primitive-square',
                    'pulse',
                    'question',
                    'quote',
                    'radio-tower',
                    'remove-close',
                    'repo',
                    'repo-clone',
                    'repo-create',
                    'repo-delete',
                    'repo-force-push',
                    'repo-forked',
                    'repo-pull',
                    'repo-push',
                    'repo-sync',
                    'rocket',
                    'rss',
                    'ruby',
                    'search',
                    'search-save',
                    'server',
                    'settings',
                    'shield',
                    'sign-in',
                    'sign-out',
                    'smiley',
                    'squirrel',
                    'star',
                    'star-add',
                    'star-delete',
                    'stop',
                    'sync',
                    'tag',
                    'tag-add',
                    'tag-remove',
                    'tasklist',
                    'telescope',
                    'terminal',
                    'text-size',
                    'three-bars',
                    'thumbsdown',
                    'thumbsup',
                    'tools',
                    'trashcan',
                    'triangle-down',
                    'triangle-left',
                    'triangle-right',
                    'triangle-up',
                    'unfold',
                    'unmute',
                    'verified',
                    'versions',
                    'watch',
                    'x',
                    'zap'
                ]
            },
            {
                version: '3.5.0',
                icons: [
                    '',
                    'alert',
                    'arrow-down',
                    'arrow-left',
                    'arrow-right',
                    'arrow-small-down',
                    'arrow-small-left',
                    'arrow-small-right',
                    'arrow-small-up',
                    'arrow-up',
                    'beaker',
                    'bell',
                    'bold',
                    'book',
                    'bookmark',
                    'briefcase',
                    'broadcast',
                    'browser',
                    'bug',
                    'calendar',
                    'check',
                    'checklist',
                    'chevron-down',
                    'chevron-left',
                    'chevron-right',
                    'chevron-up',
                    'circle-slash',
                    'circuit-board',
                    'clippy',
                    'clock',
                    'clone',
                    'cloud-download',
                    'cloud-upload',
                    'code',
                    'comment',
                    'comment-add',
                    'comment-discussion',
                    'credit-card',
                    'dash',
                    'dashboard',
                    'database',
                    'desktop-download',
                    'device-camera',
                    'device-camera-video',
                    'device-desktop',
                    'device-mobile',
                    'diff',
                    'diff-added',
                    'diff-ignored',
                    'diff-modified',
                    'diff-removed',
                    'diff-renamed',
                    'ellipsis',
                    'eye',
                    'eye-unwatch',
                    'eye-watch',
                    'file-add',
                    'file-binary',
                    'file-code',
                    'file-directory',
                    'file-directory-create',
                    'file-media',
                    'file-pdf',
                    'file-submodule',
                    'file-symlink-directory',
                    'file-symlink-file',
                    'file-text',
                    'file-zip',
                    'flame',
                    'fold',
                    'gear',
                    'gift',
                    'gist',
                    'gist-fork',
                    'gist-new',
                    'gist-private',
                    'gist-secret',
                    'git-branch',
                    'git-branch-create',
                    'git-branch-delete',
                    'git-commit',
                    'git-compare',
                    'git-fork-private',
                    'git-merge',
                    'git-pull-request',
                    'git-pull-request-abandoned',
                    'globe',
                    'graph',
                    'heart',
                    'history',
                    'home',
                    'horizontal-rule',
                    'hubot',
                    'inbox',
                    'info',
                    'issue-closed',
                    'issue-opened',
                    'issue-reopened',
                    'italic',
                    'jersey',
                    'key',
                    'keyboard',
                    'law',
                    'light-bulb',
                    'link',
                    'link-external',
                    'list-ordered',
                    'list-unordered',
                    'location',
                    'lock',
                    'log-in',
                    'logo-gist',
                    'logo-github',
                    'log-out',
                    'mail',
                    'mail-read',
                    'mail-reply',
                    'markdown',
                    'mark-github',
                    'megaphone',
                    'mention',
                    'microscope',
                    'milestone',
                    'mirror',
                    'mirror-private',
                    'mirror-public',
                    'mortar-board',
                    'mute',
                    'no-newline',
                    'octoface',
                    'organization',
                    'package',
                    'paintcan',
                    'pencil',
                    'person',
                    'person-add',
                    'person-follow',
                    'pin',
                    'plug',
                    'plus',
                    'primitive-dot',
                    'primitive-square',
                    'pulse',
                    'question',
                    'quote',
                    'radio-tower',
                    'remove-close',
                    'repo',
                    'repo-clone',
                    'repo-create',
                    'repo-delete',
                    'repo-force-push',
                    'repo-forked',
                    'repo-pull',
                    'repo-push',
                    'repo-sync',
                    'rocket',
                    'rss',
                    'ruby',
                    'search',
                    'search-save',
                    'server',
                    'settings',
                    'shield',
                    'sign-in',
                    'sign-out',
                    'smiley',
                    'squirrel',
                    'star',
                    'star-add',
                    'star-delete',
                    'stop',
                    'sync',
                    'tag',
                    'tag-add',
                    'tag-remove',
                    'tasklist',
                    'telescope',
                    'terminal',
                    'text-size',
                    'three-bars',
                    'thumbsdown',
                    'thumbsup',
                    'tools',
                    'trashcan',
                    'triangle-down',
                    'triangle-left',
                    'triangle-right',
                    'triangle-up',
                    'unfold',
                    'unmute',
                    'unverified',
                    'verified',
                    'versions',
                    'watch',
                    'x',
                    'zap'
                ]
            },
            {
                version: '4.0.0',
                icons: [
                    '',
                    'alert',
                    'arrow-down',
                    'arrow-left',
                    'arrow-right',
                    'arrow-small-down',
                    'arrow-small-left',
                    'arrow-small-right',
                    'arrow-small-up',
                    'arrow-up',
                    'beaker',
                    'bell',
                    'bold',
                    'book',
                    'bookmark',
                    'briefcase',
                    'broadcast',
                    'browser',
                    'bug',
                    'calendar',
                    'check',
                    'checklist',
                    'chevron-down',
                    'chevron-left',
                    'chevron-right',
                    'chevron-up',
                    'circle-slash',
                    'circuit-board',
                    'clippy',
                    'clock',
                    'cloud-download',
                    'cloud-upload',
                    'code',
                    'comment',
                    'comment-discussion',
                    'credit-card',
                    'dash',
                    'dashboard',
                    'database',
                    'desktop-download',
                    'device-camera',
                    'device-camera-video',
                    'device-desktop',
                    'device-mobile',
                    'diff',
                    'diff-added',
                    'diff-ignored',
                    'diff-modified',
                    'diff-removed',
                    'diff-renamed',
                    'ellipses',
                    'ellipsis',
                    'eye',
                    'file',
                    'file-binary',
                    'file-code',
                    'file-directory',
                    'file-media',
                    'file-pdf',
                    'file-submodule',
                    'file-symlink-directory',
                    'file-symlink-file',
                    'file-text',
                    'file-zip',
                    'flame',
                    'fold',
                    'gear',
                    'gift',
                    'gist',
                    'gist-secret',
                    'git-branch',
                    'git-commit',
                    'git-compare',
                    'git-merge',
                    'git-pull-request',
                    'globe',
                    'graph',
                    'heart',
                    'history',
                    'home',
                    'horizontal-rule',
                    'hubot',
                    'inbox',
                    'info',
                    'issue-closed',
                    'issue-opened',
                    'issue-reopened',
                    'italic',
                    'jersey',
                    'key',
                    'keyboard',
                    'law',
                    'light-bulb',
                    'link',
                    'link-external',
                    'list-ordered',
                    'list-unordered',
                    'location',
                    'lock',
                    'logo-gist',
                    'logo-github',
                    'mail',
                    'mail-read',
                    'mail-reply',
                    'markdown',
                    'mark-github',
                    'megaphone',
                    'mention',
                    'milestone',
                    'mirror',
                    'mortar-board',
                    'mute',
                    'no-newline',
                    'octoface',
                    'organization',
                    'package',
                    'paintcan',
                    'pencil',
                    'person',
                    'pin',
                    'plug',
                    'plus',
                    'primitive-dot',
                    'primitive-square',
                    'pulse',
                    'question',
                    'quote',
                    'radio-tower',
                    'repo',
                    'repo-clone',
                    'repo-force-push',
                    'repo-forked',
                    'repo-pull',
                    'repo-push',
                    'rocket',
                    'rss',
                    'ruby',
                    'search',
                    'server',
                    'settings',
                    'shield',
                    'sign-in',
                    'sign-out',
                    'smiley',
                    'squirrel',
                    'star',
                    'stop',
                    'sync',
                    'tag',
                    'tasklist',
                    'telescope',
                    'terminal',
                    'text-size',
                    'three-bars',
                    'thumbsdown',
                    'thumbsup',
                    'tools',
                    'trashcan',
                    'triangle-down',
                    'triangle-left',
                    'triangle-right',
                    'triangle-up',
                    'unfold',
                    'unmute',
                    'unverified',
                    'verified',
                    'versions',
                    'watch',
                    'x',
                    'zap'
                ]
            },
            {
                version: '4.1.0',
                icons: [
                    '',
                    'alert',
                    'arrow-down',
                    'arrow-left',
                    'arrow-right',
                    'arrow-small-down',
                    'arrow-small-left',
                    'arrow-small-right',
                    'arrow-small-up',
                    'arrow-up',
                    'beaker',
                    'bell',
                    'bold',
                    'book',
                    'bookmark',
                    'briefcase',
                    'broadcast',
                    'browser',
                    'bug',
                    'calendar',
                    'check',
                    'checklist',
                    'chevron-down',
                    'chevron-left',
                    'chevron-right',
                    'chevron-up',
                    'circle-slash',
                    'circuit-board',
                    'clippy',
                    'clock',
                    'cloud-download',
                    'cloud-upload',
                    'code',
                    'comment',
                    'comment-discussion',
                    'credit-card',
                    'dash',
                    'dashboard',
                    'database',
                    'desktop-download',
                    'device-camera',
                    'device-camera-video',
                    'device-desktop',
                    'device-mobile',
                    'diff',
                    'diff-added',
                    'diff-ignored',
                    'diff-modified',
                    'diff-removed',
                    'diff-renamed',
                    'ellipses',
                    'ellipsis',
                    'eye',
                    'file',
                    'file-binary',
                    'file-code',
                    'file-directory',
                    'file-media',
                    'file-pdf',
                    'file-submodule',
                    'file-symlink-directory',
                    'file-symlink-file',
                    'file-text',
                    'file-zip',
                    'flame',
                    'fold',
                    'gear',
                    'gift',
                    'gist',
                    'gist-secret',
                    'git-branch',
                    'git-commit',
                    'git-compare',
                    'git-merge',
                    'git-pull-request',
                    'globe',
                    'grabber',
                    'graph',
                    'heart',
                    'history',
                    'home',
                    'horizontal-rule',
                    'hubot',
                    'inbox',
                    'info',
                    'issue-closed',
                    'issue-opened',
                    'issue-reopened',
                    'italic',
                    'jersey',
                    'key',
                    'keyboard',
                    'law',
                    'light-bulb',
                    'link',
                    'link-external',
                    'list-ordered',
                    'list-unordered',
                    'location',
                    'lock',
                    'logo-gist',
                    'logo-github',
                    'mail',
                    'mail-read',
                    'mail-reply',
                    'markdown',
                    'mark-github',
                    'megaphone',
                    'mention',
                    'milestone',
                    'mirror',
                    'mortar-board',
                    'mute',
                    'no-newline',
                    'octoface',
                    'organization',
                    'package',
                    'paintcan',
                    'pencil',
                    'person',
                    'pin',
                    'plug',
                    'plus',
                    'plus-small',
                    'primitive-dot',
                    'primitive-square',
                    'pulse',
                    'question',
                    'quote',
                    'radio-tower',
                    'reply',
                    'repo',
                    'repo-clone',
                    'repo-force-push',
                    'repo-forked',
                    'repo-pull',
                    'repo-push',
                    'rocket',
                    'rss',
                    'ruby',
                    'search',
                    'server',
                    'settings',
                    'shield',
                    'sign-in',
                    'sign-out',
                    'smiley',
                    'squirrel',
                    'star',
                    'stop',
                    'sync',
                    'tag',
                    'tasklist',
                    'telescope',
                    'terminal',
                    'text-size',
                    'three-bars',
                    'thumbsdown',
                    'thumbsup',
                    'tools',
                    'trashcan',
                    'triangle-down',
                    'triangle-left',
                    'triangle-right',
                    'triangle-up',
                    'unfold',
                    'unmute',
                    'unverified',
                    'verified',
                    'versions',
                    'watch',
                    'x',
                    'zap'
                ]
            },
            {
                version: '4.1.1',
                icons: [
                    '',
                    'alert',
                    'arrow-down',
                    'arrow-left',
                    'arrow-right',
                    'arrow-small-down',
                    'arrow-small-left',
                    'arrow-small-right',
                    'arrow-small-up',
                    'arrow-up',
                    'beaker',
                    'bell',
                    'bold',
                    'book',
                    'bookmark',
                    'briefcase',
                    'broadcast',
                    'browser',
                    'bug',
                    'calendar',
                    'check',
                    'checklist',
                    'chevron-down',
                    'chevron-left',
                    'chevron-right',
                    'chevron-up',
                    'circle-slash',
                    'circuit-board',
                    'clippy',
                    'clock',
                    'cloud-download',
                    'cloud-upload',
                    'code',
                    'comment',
                    'comment-discussion',
                    'credit-card',
                    'dash',
                    'dashboard',
                    'database',
                    'desktop-download',
                    'device-camera',
                    'device-camera-video',
                    'device-desktop',
                    'device-mobile',
                    'diff',
                    'diff-added',
                    'diff-ignored',
                    'diff-modified',
                    'diff-removed',
                    'diff-renamed',
                    'ellipses',
                    'ellipsis',
                    'eye',
                    'file',
                    'file-binary',
                    'file-code',
                    'file-directory',
                    'file-media',
                    'file-pdf',
                    'file-submodule',
                    'file-symlink-directory',
                    'file-symlink-file',
                    'file-text',
                    'file-zip',
                    'flame',
                    'fold',
                    'gear',
                    'gift',
                    'gist',
                    'gist-secret',
                    'git-branch',
                    'git-commit',
                    'git-compare',
                    'git-merge',
                    'git-pull-request',
                    'globe',
                    'grabber',
                    'graph',
                    'heart',
                    'history',
                    'home',
                    'horizontal-rule',
                    'hubot',
                    'inbox',
                    'info',
                    'issue-closed',
                    'issue-opened',
                    'issue-reopened',
                    'italic',
                    'jersey',
                    'key',
                    'keyboard',
                    'law',
                    'light-bulb',
                    'link',
                    'link-external',
                    'list-ordered',
                    'list-unordered',
                    'location',
                    'lock',
                    'logo-gist',
                    'logo-github',
                    'mail',
                    'mail-read',
                    'mail-reply',
                    'markdown',
                    'mark-github',
                    'megaphone',
                    'mention',
                    'milestone',
                    'mirror',
                    'mortar-board',
                    'mute',
                    'no-newline',
                    'octoface',
                    'organization',
                    'package',
                    'paintcan',
                    'pencil',
                    'person',
                    'pin',
                    'plug',
                    'plus',
                    'plus-small',
                    'primitive-dot',
                    'primitive-square',
                    'pulse',
                    'question',
                    'quote',
                    'radio-tower',
                    'reply',
                    'repo',
                    'repo-clone',
                    'repo-force-push',
                    'repo-forked',
                    'repo-pull',
                    'repo-push',
                    'rocket',
                    'rss',
                    'ruby',
                    'search',
                    'server',
                    'settings',
                    'shield',
                    'sign-in',
                    'sign-out',
                    'smiley',
                    'squirrel',
                    'star',
                    'stop',
                    'sync',
                    'tag',
                    'tasklist',
                    'telescope',
                    'terminal',
                    'text-size',
                    'three-bars',
                    'thumbsdown',
                    'thumbsup',
                    'tools',
                    'trashcan',
                    'triangle-down',
                    'triangle-left',
                    'triangle-right',
                    'triangle-up',
                    'unfold',
                    'unmute',
                    'unverified',
                    'verified',
                    'versions',
                    'watch',
                    'x',
                    'zap'
                ]
            },
            {
                version: '4.2.0',
                icons: [
                    '',
                    'alert',
                    'arrow-down',
                    'arrow-left',
                    'arrow-right',
                    'arrow-small-down',
                    'arrow-small-left',
                    'arrow-small-right',
                    'arrow-small-up',
                    'arrow-up',
                    'beaker',
                    'bell',
                    'bold',
                    'book',
                    'bookmark',
                    'briefcase',
                    'broadcast',
                    'browser',
                    'bug',
                    'calendar',
                    'check',
                    'checklist',
                    'chevron-down',
                    'chevron-left',
                    'chevron-right',
                    'chevron-up',
                    'circle-slash',
                    'circuit-board',
                    'clippy',
                    'clock',
                    'cloud-download',
                    'cloud-upload',
                    'code',
                    'comment',
                    'comment-discussion',
                    'credit-card',
                    'dash',
                    'dashboard',
                    'database',
                    'desktop-download',
                    'device-camera',
                    'device-camera-video',
                    'device-desktop',
                    'device-mobile',
                    'diff',
                    'diff-added',
                    'diff-ignored',
                    'diff-modified',
                    'diff-removed',
                    'diff-renamed',
                    'ellipses',
                    'ellipsis',
                    'eye',
                    'file',
                    'file-binary',
                    'file-code',
                    'file-directory',
                    'file-media',
                    'file-pdf',
                    'file-submodule',
                    'file-symlink-directory',
                    'file-symlink-file',
                    'file-text',
                    'file-zip',
                    'flame',
                    'fold',
                    'gear',
                    'gift',
                    'gist',
                    'gist-secret',
                    'git-branch',
                    'git-commit',
                    'git-compare',
                    'git-merge',
                    'git-pull-request',
                    'globe',
                    'grabber',
                    'graph',
                    'heart',
                    'history',
                    'home',
                    'horizontal-rule',
                    'hubot',
                    'inbox',
                    'info',
                    'issue-closed',
                    'issue-opened',
                    'issue-reopened',
                    'italic',
                    'jersey',
                    'key',
                    'keyboard',
                    'law',
                    'light-bulb',
                    'link',
                    'link-external',
                    'list-ordered',
                    'list-unordered',
                    'location',
                    'lock',
                    'logo-gist',
                    'logo-github',
                    'mail',
                    'mail-read',
                    'mail-reply',
                    'markdown',
                    'mark-github',
                    'megaphone',
                    'mention',
                    'milestone',
                    'mirror',
                    'mortar-board',
                    'mute',
                    'no-newline',
                    'octoface',
                    'organization',
                    'package',
                    'paintcan',
                    'pencil',
                    'person',
                    'pin',
                    'plug',
                    'plus',
                    'plus-small',
                    'primitive-dot',
                    'primitive-square',
                    'pulse',
                    'question',
                    'quote',
                    'radio-tower',
                    'reply',
                    'repo',
                    'repo-clone',
                    'repo-force-push',
                    'repo-forked',
                    'repo-pull',
                    'repo-push',
                    'rocket',
                    'rss',
                    'ruby',
                    'search',
                    'server',
                    'settings',
                    'shield',
                    'sign-in',
                    'sign-out',
                    'smiley',
                    'squirrel',
                    'star',
                    'stop',
                    'sync',
                    'tag',
                    'tasklist',
                    'telescope',
                    'terminal',
                    'text-size',
                    'three-bars',
                    'thumbsdown',
                    'thumbsup',
                    'tools',
                    'trashcan',
                    'triangle-down',
                    'triangle-left',
                    'triangle-right',
                    'triangle-up',
                    'unfold',
                    'unmute',
                    'unverified',
                    'verified',
                    'versions',
                    'watch',
                    'x',
                    'zap'
                ]
            },
            {
                version: '4.2.1',
                icons: [
                    '',
                    'alert',
                    'arrow-down',
                    'arrow-left',
                    'arrow-right',
                    'arrow-small-down',
                    'arrow-small-left',
                    'arrow-small-right',
                    'arrow-small-up',
                    'arrow-up',
                    'beaker',
                    'bell',
                    'bold',
                    'book',
                    'bookmark',
                    'briefcase',
                    'broadcast',
                    'browser',
                    'bug',
                    'calendar',
                    'check',
                    'checklist',
                    'chevron-down',
                    'chevron-left',
                    'chevron-right',
                    'chevron-up',
                    'circle-slash',
                    'circuit-board',
                    'clippy',
                    'clock',
                    'cloud-download',
                    'cloud-upload',
                    'code',
                    'comment',
                    'comment-discussion',
                    'credit-card',
                    'dash',
                    'dashboard',
                    'database',
                    'desktop-download',
                    'device-camera',
                    'device-camera-video',
                    'device-desktop',
                    'device-mobile',
                    'diff',
                    'diff-added',
                    'diff-ignored',
                    'diff-modified',
                    'diff-removed',
                    'diff-renamed',
                    'ellipses',
                    'ellipsis',
                    'eye',
                    'file',
                    'file-binary',
                    'file-code',
                    'file-directory',
                    'file-media',
                    'file-pdf',
                    'file-submodule',
                    'file-symlink-directory',
                    'file-symlink-file',
                    'file-text',
                    'file-zip',
                    'flame',
                    'fold',
                    'gear',
                    'gift',
                    'gist',
                    'gist-secret',
                    'git-branch',
                    'git-commit',
                    'git-compare',
                    'git-merge',
                    'git-pull-request',
                    'globe',
                    'grabber',
                    'graph',
                    'heart',
                    'history',
                    'home',
                    'horizontal-rule',
                    'hubot',
                    'inbox',
                    'info',
                    'issue-closed',
                    'issue-opened',
                    'issue-reopened',
                    'italic',
                    'jersey',
                    'key',
                    'keyboard',
                    'law',
                    'light-bulb',
                    'link',
                    'link-external',
                    'list-ordered',
                    'list-unordered',
                    'location',
                    'lock',
                    'logo-gist',
                    'logo-github',
                    'mail',
                    'mail-read',
                    'mail-reply',
                    'markdown',
                    'mark-github',
                    'megaphone',
                    'mention',
                    'milestone',
                    'mirror',
                    'mortar-board',
                    'mute',
                    'no-newline',
                    'octoface',
                    'organization',
                    'package',
                    'paintcan',
                    'pencil',
                    'person',
                    'pin',
                    'plug',
                    'plus',
                    'plus-small',
                    'primitive-dot',
                    'primitive-square',
                    'pulse',
                    'question',
                    'quote',
                    'radio-tower',
                    'reply',
                    'repo',
                    'repo-clone',
                    'repo-force-push',
                    'repo-forked',
                    'repo-pull',
                    'repo-push',
                    'rocket',
                    'rss',
                    'ruby',
                    'search',
                    'server',
                    'settings',
                    'shield',
                    'sign-in',
                    'sign-out',
                    'smiley',
                    'squirrel',
                    'star',
                    'stop',
                    'sync',
                    'tag',
                    'tasklist',
                    'telescope',
                    'terminal',
                    'text-size',
                    'three-bars',
                    'thumbsdown',
                    'thumbsup',
                    'tools',
                    'trashcan',
                    'triangle-down',
                    'triangle-left',
                    'triangle-right',
                    'triangle-up',
                    'unfold',
                    'unmute',
                    'unverified',
                    'verified',
                    'versions',
                    'watch',
                    'x',
                    'zap'
                ]
            },
            {
                version: '4.3.0',
                icons: [
                    '',
                    'alert',
                    'arrow-down',
                    'arrow-left',
                    'arrow-right',
                    'arrow-small-down',
                    'arrow-small-left',
                    'arrow-small-right',
                    'arrow-small-up',
                    'arrow-up',
                    'beaker',
                    'bell',
                    'bold',
                    'book',
                    'bookmark',
                    'briefcase',
                    'broadcast',
                    'browser',
                    'bug',
                    'calendar',
                    'check',
                    'checklist',
                    'chevron-down',
                    'chevron-left',
                    'chevron-right',
                    'chevron-up',
                    'circle-slash',
                    'circuit-board',
                    'clippy',
                    'clock',
                    'cloud-download',
                    'cloud-upload',
                    'code',
                    'comment',
                    'comment-discussion',
                    'credit-card',
                    'dash',
                    'dashboard',
                    'database',
                    'desktop-download',
                    'device-camera',
                    'device-camera-video',
                    'device-desktop',
                    'device-mobile',
                    'diff',
                    'diff-added',
                    'diff-ignored',
                    'diff-modified',
                    'diff-removed',
                    'diff-renamed',
                    'ellipses',
                    'ellipsis',
                    'eye',
                    'file',
                    'file-binary',
                    'file-code',
                    'file-directory',
                    'file-media',
                    'file-pdf',
                    'file-submodule',
                    'file-symlink-directory',
                    'file-symlink-file',
                    'file-text',
                    'file-zip',
                    'flame',
                    'fold',
                    'gear',
                    'gift',
                    'gist',
                    'gist-secret',
                    'git-branch',
                    'git-commit',
                    'git-compare',
                    'git-merge',
                    'git-pull-request',
                    'globe',
                    'grabber',
                    'graph',
                    'heart',
                    'history',
                    'home',
                    'horizontal-rule',
                    'hubot',
                    'inbox',
                    'info',
                    'issue-closed',
                    'issue-opened',
                    'issue-reopened',
                    'italic',
                    'jersey',
                    'key',
                    'keyboard',
                    'law',
                    'light-bulb',
                    'link',
                    'link-external',
                    'list-ordered',
                    'list-unordered',
                    'location',
                    'lock',
                    'logo-gist',
                    'logo-github',
                    'mail',
                    'mail-read',
                    'mail-reply',
                    'markdown',
                    'mark-github',
                    'megaphone',
                    'mention',
                    'milestone',
                    'mirror',
                    'mortar-board',
                    'mute',
                    'no-newline',
                    'octoface',
                    'organization',
                    'package',
                    'paintcan',
                    'pencil',
                    'person',
                    'pin',
                    'plug',
                    'plus',
                    'plus-small',
                    'primitive-dot',
                    'primitive-square',
                    'pulse',
                    'question',
                    'quote',
                    'radio-tower',
                    'reply',
                    'repo',
                    'repo-clone',
                    'repo-force-push',
                    'repo-forked',
                    'repo-pull',
                    'repo-push',
                    'rocket',
                    'rss',
                    'ruby',
                    'search',
                    'server',
                    'settings',
                    'shield',
                    'sign-in',
                    'sign-out',
                    'smiley',
                    'squirrel',
                    'star',
                    'stop',
                    'sync',
                    'tag',
                    'tasklist',
                    'telescope',
                    'terminal',
                    'text-size',
                    'three-bars',
                    'thumbsdown',
                    'thumbsup',
                    'tools',
                    'trashcan',
                    'triangle-down',
                    'triangle-left',
                    'triangle-right',
                    'triangle-up',
                    'unfold',
                    'unmute',
                    'unverified',
                    'verified',
                    'versions',
                    'watch',
                    'x',
                    'zap'
                ]
            },
            {
                version: '4.4.0',
                icons: [
                    '',
                    'alert',
                    'arrow-down',
                    'arrow-left',
                    'arrow-right',
                    'arrow-small-down',
                    'arrow-small-left',
                    'arrow-small-right',
                    'arrow-small-up',
                    'arrow-up',
                    'beaker',
                    'bell',
                    'bold',
                    'book',
                    'bookmark',
                    'briefcase',
                    'broadcast',
                    'browser',
                    'bug',
                    'calendar',
                    'check',
                    'checklist',
                    'chevron-down',
                    'chevron-left',
                    'chevron-right',
                    'chevron-up',
                    'circle-slash',
                    'circuit-board',
                    'clippy',
                    'clock',
                    'cloud-download',
                    'cloud-upload',
                    'code',
                    'comment',
                    'comment-discussion',
                    'credit-card',
                    'dash',
                    'dashboard',
                    'database',
                    'desktop-download',
                    'device-camera',
                    'device-camera-video',
                    'device-desktop',
                    'device-mobile',
                    'diff',
                    'diff-added',
                    'diff-ignored',
                    'diff-modified',
                    'diff-removed',
                    'diff-renamed',
                    'ellipses',
                    'ellipsis',
                    'eye',
                    'file',
                    'file-binary',
                    'file-code',
                    'file-directory',
                    'file-media',
                    'file-pdf',
                    'file-submodule',
                    'file-symlink-directory',
                    'file-symlink-file',
                    'file-text',
                    'file-zip',
                    'flame',
                    'fold',
                    'gear',
                    'gift',
                    'gist',
                    'gist-secret',
                    'git-branch',
                    'git-commit',
                    'git-compare',
                    'git-merge',
                    'git-pull-request',
                    'globe',
                    'grabber',
                    'graph',
                    'heart',
                    'history',
                    'home',
                    'horizontal-rule',
                    'hubot',
                    'inbox',
                    'info',
                    'issue-closed',
                    'issue-opened',
                    'issue-reopened',
                    'italic',
                    'jersey',
                    'key',
                    'keyboard',
                    'law',
                    'light-bulb',
                    'link',
                    'link-external',
                    'list-ordered',
                    'list-unordered',
                    'location',
                    'lock',
                    'logo-gist',
                    'logo-github',
                    'mail',
                    'mail-read',
                    'mail-reply',
                    'markdown',
                    'mark-github',
                    'megaphone',
                    'mention',
                    'milestone',
                    'mirror',
                    'mortar-board',
                    'mute',
                    'no-newline',
                    'octoface',
                    'organization',
                    'package',
                    'paintcan',
                    'pencil',
                    'person',
                    'pin',
                    'plug',
                    'plus',
                    'plus-small',
                    'primitive-dot',
                    'primitive-square',
                    'pulse',
                    'question',
                    'quote',
                    'radio-tower',
                    'reply',
                    'repo',
                    'repo-clone',
                    'repo-force-push',
                    'repo-forked',
                    'repo-pull',
                    'repo-push',
                    'rocket',
                    'rss',
                    'ruby',
                    'search',
                    'server',
                    'settings',
                    'shield',
                    'sign-in',
                    'sign-out',
                    'smiley',
                    'squirrel',
                    'star',
                    'stop',
                    'sync',
                    'tag',
                    'tasklist',
                    'telescope',
                    'terminal',
                    'text-size',
                    'three-bars',
                    'thumbsdown',
                    'thumbsup',
                    'tools',
                    'trashcan',
                    'triangle-down',
                    'triangle-left',
                    'triangle-right',
                    'triangle-up',
                    'unfold',
                    'unmute',
                    'unverified',
                    'verified',
                    'versions',
                    'watch',
                    'x',
                    'zap'
                ]
            }
        ]
    };

    var l = data.allVersions.length;
    data.icons = data.allVersions[l-1].icons;

    $.iconset_octicon = data;

})(jQuery);
