/*!========================================================================
 * Iconset: Material Design
 * Versions: 2.0.0, 2.0.1, 2.0.2, 2.1.0, 2.1.1, 2.1.2, 2.2.0
 * http://zavoloklom.github.io/material-design-iconic-font
 * CDN: https://cdnjs.cloudflare.com/ajax/libs/material-design-iconic-font/[VERSION]/css/material-design-iconic-font.min.css
 * ======================================================================== */

;(function($){

    var data = {
        iconClass: 'zmdi',
        iconClassFix: 'zmdi-',
        icons: [],
        allVersions: [
            {
                version: '2.0.0',
                icons: [
                    '',
                    //'zmdi',
                    '3d-rotation',
                    'account',
                    'account-add',
                    'account-box',
                    'account-box-mail',
                    'account-box-o',
                    'account-box-phone',
                    'account-calendar',
                    'account-circle',
                    'account-o',
                    'accounts',
                    'accounts-add',
                    'accounts-alt',
                    'accounts-list',
                    'accounts-list-alt',
                    'accounts-outline',
                    'airline-seat-flat',
                    'airline-seat-flat-angled',
                    'airline-seat-individual-suite',
                    'airline-seat-legroom-extra',
                    'airline-seat-legroom-normal',
                    'airline-seat-legroom-reduced',
                    'airline-seat-recline-extra',
                    'airline-seat-recline-normal',
                    'airplay',
                    'alarm',
                    'alarm-check',
                    'alarm-off',
                    'alarm-snooze',
                    'album',
                    'alert-circle',
                    'alert-circle-o',
                    'alert-octagon',
                    'alert-polygon',
                    'alert-triangle',
                    'android',
                    'apps',
                    'archive',
                    'arrow-merge',
                    'arrow-missed',
                    'arrow-split',
                    'arrows',
                    'aspect-ratio',
                    'aspect-ratio-alt',
                    'assignment',
                    'assignment-account',
                    'assignment-alert',
                    'assignment-check',
                    'assignment-o',
                    'assignment-return',
                    'assignment-returned',
                    'attachment',
                    'attachment-alt',
                    'audio',
                    'badge-check',
                    'balance',
                    'balance-wallet',
                    'battery',
                    'battery-alert',
                    'battery-unknown',
                    'block',
                    'block-alt',
                    'bluetooth',
                    'bluetooth-connected',
                    'bluetooth-off',
                    'bluetooth-search',
                    'bluetooth-setting',
                    'blur',
                    'blur-circular',
                    'blur-linear',
                    'blur-off',
                    'book',
                    'bookmark',
                    'bookmark-outline',
                    'border-all',
                    'border-bottom',
                    'border-clear',
                    'border-color',
                    'border-horizontal',
                    'border-inner',
                    'border-left',
                    'border-outer',
                    'border-right',
                    'border-style',
                    'border-top',
                    'border-vertical',
                    'brightness-2',
                    'brightness-3',
                    'brightness-4',
                    'brightness-5',
                    'brightness-6',
                    'brightness-7',
                    'brightness-auto',
                    'brightness-high',
                    'brightness-setting',
                    'broken-image',
                    'brush',
                    'bug',
                    'cake',
                    'calendar',
                    'calendar-alt',
                    'calendar-check',
                    'calendar-note',
                    'camera',
                    'camera-add',
                    'camera-alt',
                    'camera-front',
                    'camera-mic',
                    'camera-party-mode',
                    'camera-rear',
                    'camera-roll',
                    'camera-switch',
                    'card',
                    'card-alert',
                    'card-giftcard',
                    'card-membership',
                    'card-off',
                    'card-sd',
                    'card-sim',
                    'card-travel',
                    'caret-down',
                    'caret-down-circle',
                    'caret-up',
                    'case',
                    'case-play',
                    'cast',
                    'cast-connected',
                    'center-focus-strong',
                    'center-focus-weak',
                    'chart',
                    'chart-donut',
                    'check',
                    'check-all',
                    'check-circle',
                    'check-circle-u',
                    'check-square',
                    'chevron-down',
                    'chevron-left',
                    'chevron-right',
                    'chevron-up',
                    'circle',
                    'circle-o',
                    'city',
                    'city-alt',
                    'close',
                    'close-circle',
                    'close-circle-o',
                    'closed-caption',
                    'cloud',
                    'cloud-circle',
                    'cloud-done',
                    'cloud-download',
                    'cloud-off',
                    'cloud-outline',
                    'cloud-outline-alt',
                    'cloud-upload',
                    'code',
                    'code-setting',
                    'code-smartphone',
                    'collection-bookmark',
                    'collection-case-play',
                    'collection-folder-image',
                    'collection-image',
                    'collection-image-o',
                    'collection-item',
                    'collection-item-1',
                    'collection-item-2',
                    'collection-item-3',
                    'collection-item-4',
                    'collection-item-5',
                    'collection-item-6',
                    'collection-item-7',
                    'collection-item-8',
                    'collection-item-9',
                    'collection-item-9-plus',
                    'collection-music',
                    'collection-pdf',
                    'collection-speaker',
                    'collection-text',
                    'collection-video',
                    'comment',
                    'comment-alert',
                    'comment-alt',
                    'comment-alt-text',
                    'comment-image',
                    'comment-list',
                    'comment-outline',
                    'comment-text',
                    'comment-text-alt',
                    'comment-video',
                    'comments',
                    'compare',
                    'compass',
                    'confirmation-number',
                    'copy',
                    'crop',
                    'crop-16-9',
                    'crop-3-2',
                    'crop-5-4',
                    'crop-7-5',
                    'crop-din',
                    'crop-free',
                    'crop-landscape',
                    'crop-portrait',
                    'crop-square',
                    'delete',
                    'desktop-mac',
                    'desktop-windows',
                    'developer-board',
                    'device-hub',
                    'devices',
                    'devices-off',
                    'dialpad',
                    'directions',
                    'directions-bike',
                    'directions-boat',
                    'directions-bus',
                    'directions-car',
                    'directions-railway',
                    'directions-run',
                    'directions-subway',
                    'directions-walk',
                    'disc-full',
                    'dns',
                    'dock',
                    'dot-circle',
                    'dot-circle-alt',
                    'download',
                    'edit',
                    'eject',
                    'eject-alt',
                    'email',
                    'email-open',
                    'equalizer',
                    'explicit',
                    'exposure',
                    'exposure-alt',
                    'eye',
                    'eye-off',
                    'face',
                    'fast-forward',
                    'fast-rewind',
                    'favorite',
                    'favorite-outline',
                    'file',
                    'file-text',
                    'filter-b-and-w',
                    'filter-center-focus',
                    'filter-frames',
                    'filter-list',
                    'filter-tilt-shift',
                    'fire',
                    'flag',
                    'flare',
                    'flash',
                    'flash-auto',
                    'flash-off',
                    'flight-land',
                    'flight-takeoff',
                    'flip',
                    'flip-to-back',
                    'flip-to-front',
                    'flower',
                    'folder',
                    'folder-outline',
                    'font',
                    'format-align-center',
                    'format-align-justify',
                    'format-align-left',
                    'format-align-right',
                    'format-bold',
                    'format-clear',
                    'format-clear-all',
                    'format-color-fill',
                    'format-color-reset',
                    'format-color-text',
                    'format-indent-decrease',
                    'format-indent-increase',
                    'format-italic',
                    'format-line-spacing',
                    'format-list-bulleted',
                    'format-list-numbered',
                    'format-size',
                    'format-strikethrough',
                    'format-strikethrough-s',
                    'format-subject',
                    'format-underlined',
                    'format-valign-bottom',
                    'format-valign-center',
                    'format-valign-top',
                    'forward',
                    'forward-10',
                    'forward-30',
                    'forward-5',
                    'fullscreen',
                    'fullscreen-alt',
                    'fullscreen-exit',
                    'functions',
                    'gamepad',
                    'gesture',
                    'gif',
                    'globe',
                    'globe-alt',
                    'globe-lock',
                    'gps',
                    'gps-dot',
                    'gps-off',
                    'gradient',
                    'graduation-cap',
                    'grain',
                    'graphic-eq',
                    'grid',
                    'grid-off',
                    'group-work',
                    'hd',
                    'hdr',
                    'hdr-off',
                    'hdr-strong',
                    'hdr-weak',
                    'headset',
                    'headset-mic',
                    'hearing',
                    'help',
                    'help-outline',
                    'home',
                    'hotel',
                    'hourglass',
                    'hourglass-outline',
                    'hq',
                    'http',
                    'image',
                    'image-alt',
                    'inbox',
                    'info',
                    'info-outline',
                    'input-antenna',
                    'input-composite',
                    'input-hdmi',
                    'input-power',
                    'input-svideo',
                    'invert-colors',
                    'invert-colors-off',
                    'key',
                    'keyboard',
                    'keyboard-hide',
                    'label',
                    'label-heart',
                    'labels',
                    'landscape',
                    'laptop',
                    'laptop-chromebook',
                    'laptop-mac',
                    'layers',
                    'leak',
                    'link',
                    'local-activity',
                    'local-airport',
                    'local-atm',
                    'local-bar',
                    'local-cafe',
                    'local-car-wash',
                    'local-convenience-store',
                    'local-dining',
                    'local-drink',
                    'local-florist',
                    'local-gas-station',
                    'local-grocery-store',
                    'local-hospital',
                    'local-hotel',
                    'local-laundry-service',
                    'local-library',
                    'local-mall',
                    'local-movies',
                    'local-offer',
                    'local-parking',
                    'local-pharmacy',
                    'local-phone',
                    'local-pizza',
                    'local-post-office',
                    'local-printshop',
                    'local-see',
                    'local-shipping',
                    'local-store',
                    'local-taxi',
                    'local-wc',
                    'lock',
                    'lock-open',
                    'lock-outline',
                    'long-arrow-left',
                    'long-arrow-return',
                    'long-arrow-tab',
                    'looks',
                    'loupe',
                    'mail-reply',
                    'mail-reply-all',
                    'mail-send',
                    'male',
                    'map',
                    'markunread-mailbox',
                    'memory',
                    'menu',
                    'mic',
                    'mic-off',
                    'mic-outline',
                    'mic-setting',
                    'minus',
                    'minus-circle',
                    'minus-circle-outline',
                    'minus-square',
                    'money',
                    'money-off',
                    'mood',
                    'mood-bad',
                    'more-vert',
                    'mouse',
                    'movie',
                    'movie-alt',
                    'my-location',
                    'n-1-square',
                    'n-2-square',
                    'n-3-square',
                    'n-4-square',
                    'n-5-square',
                    'n-6-square',
                    'nature',
                    'nature-people',
                    'navigation',
                    'neg-1',
                    'neg-2',
                    'network',
                    'network-locked',
                    'network-off',
                    'network-outline',
                    'network-setting',
                    'nfc',
                    'notifications',
                    'notifications-active',
                    'notifications-add',
                    'notifications-none',
                    'notifications-off',
                    'notifications-paused',
                    'open-in-browser',
                    'open-in-new',
                    'palette',
                    'panorama-horizontal',
                    'panorama-vertical',
                    'panorama-wide-angle',
                    'pause',
                    'pause-circle',
                    'pause-circle-outline',
                    'phone',
                    'phone-bluetooth',
                    'phone-end',
                    'phone-forwarded',
                    'phone-in-talk',
                    'phone-locked',
                    'phone-missed',
                    'phone-msg',
                    'phone-paused',
                    'phone-ring',
                    'phone-setting',
                    'phone-sip',
                    'photo-size-select-large',
                    'photo-size-select-small',
                    'picture-in-picture',
                    'pin',
                    'pin-account',
                    'pin-assistant',
                    'pin-drop',
                    'pin-help',
                    'pin-off',
                    'plaster',
                    'play',
                    'play-circle',
                    'play-circle-outline',
                    'play-for-work',
                    'plus',
                    'plus-1',
                    'plus-2',
                    'plus-circle',
                    'plus-circle-o',
                    'plus-circle-o-duplicate',
                    'polymer',
                    'portable-wifi',
                    'portable-wifi-changes',
                    'portable-wifi-off',
                    'power-input',
                    'present-to-all',
                    'print',
                    'puzzle-piece',
                    'radio',
                    'reader',
                    'receipt',
                    'redo',
                    'refresh',
                    'refresh-alt',
                    'refresh-sync',
                    'remote-control',
                    'remote-control-alt',
                    'repeat',
                    'repeat-one',
                    'replay',
                    'replay-10',
                    'replay-30',
                    'replay-5',
                    'rotate-left',
                    'rotate-right',
                    'router',
                    'ruler',
                    'satellite',
                    'scanner',
                    'screen-rotation',
                    'screen-rotation-lock',
                    'search',
                    'search-for',
                    'search-in-file',
                    'search-in-page',
                    'search-replace',
                    'seat',
                    'sec-10',
                    'sec-3',
                    'select-all',
                    'settings',
                    'settings-square',
                    'share',
                    'shield-check',
                    'shield-security',
                    'shopping-basket',
                    'shopping-cart',
                    'shuffle',
                    'sign-in',
                    'skip-next',
                    'skip-previous',
                    'slideshow',
                    'smartphone',
                    'smartphone-android',
                    'smartphone-download',
                    'smartphone-erase',
                    'smartphone-info',
                    'smartphone-iphone',
                    'smartphone-landscape',
                    'smartphone-landscape-lock',
                    'smartphone-lock',
                    'smartphone-portrait-lock',
                    'smartphone-ring',
                    'smartphone-setting',
                    'smartphone-setup',
                    'space-bar',
                    'speaker',
                    'spellcheck',
                    'square-down',
                    'square-o',
                    'square-right',
                    'star',
                    'star-circle',
                    'star-half',
                    'stop',
                    'storage',
                    'sun',
                    'surround-sound',
                    'swap',
                    'swap-alt',
                    'swap-vertical-circle',
                    'tab',
                    'tab-unselected',
                    'tablet',
                    'tablet-android',
                    'tablet-mac',
                    'tag-more',
                    'tap-and-play',
                    'text-format',
                    'texture',
                    'thumb-down',
                    'thumb-up',
                    'thumb-up-down',
                    'time',
                    'time-countdown',
                    'time-interval',
                    'time-restore',
                    'time-restore-setting',
                    'timer',
                    'timer-off',
                    'toll',
                    'tonality',
                    'toys',
                    'traffic',
                    'translate',
                    'trending-down',
                    'trending-flat',
                    'trending-up',
                    'triangle-down',
                    'triangle-up',
                    'tune',
                    'tv',
                    'tv-list',
                    'tv-play',
                    'undo',
                    'unfold-less',
                    'unfold-more',
                    'upload',
                    'usb',
                    'vibration',
                    'videocam',
                    'videocam-off',
                    'videocam-switch',
                    'view-agenda',
                    'view-array',
                    'view-carousel',
                    'view-column',
                    'view-comfy',
                    'view-compact',
                    'view-dashboard',
                    'view-day',
                    'view-headline',
                    'view-list',
                    'view-list-alt',
                    'view-module',
                    'view-quilt',
                    'view-stream',
                    'view-subtitles',
                    'view-toc',
                    'view-web',
                    'view-week',
                    'vignette',
                    'voicemail',
                    'volume-down',
                    'volume-mute',
                    'volume-off',
                    'volume-up',
                    'wallpaper',
                    'watch',
                    'wb-auto',
                    'widgets',
                    'wrap-text',
                    'wrench',
                    'zero',
                    'zoom-in',
                    'zoom-out'
                ]
            },
            {
                version: '2.0.1',
                icons: [
                    '',
                    //'zmdi',
                    '3d-rotation',
                    'account',
                    'account-add',
                    'account-box',
                    'account-box-mail',
                    'account-box-o',
                    'account-box-phone',
                    'account-calendar',
                    'account-circle',
                    'account-o',
                    'accounts',
                    'accounts-add',
                    'accounts-alt',
                    'accounts-list',
                    'accounts-list-alt',
                    'accounts-outline',
                    'airline-seat-flat',
                    'airline-seat-flat-angled',
                    'airline-seat-individual-suite',
                    'airline-seat-legroom-extra',
                    'airline-seat-legroom-normal',
                    'airline-seat-legroom-reduced',
                    'airline-seat-recline-extra',
                    'airline-seat-recline-normal',
                    'airplay',
                    'alarm',
                    'alarm-check',
                    'alarm-off',
                    'alarm-snooze',
                    'album',
                    'alert-circle',
                    'alert-circle-o',
                    'alert-octagon',
                    'alert-polygon',
                    'alert-triangle',
                    'android',
                    'apps',
                    'archive',
                    'arrow-merge',
                    'arrow-missed',
                    'arrow-split',
                    'arrows',
                    'aspect-ratio',
                    'aspect-ratio-alt',
                    'assignment',
                    'assignment-account',
                    'assignment-alert',
                    'assignment-check',
                    'assignment-o',
                    'assignment-return',
                    'assignment-returned',
                    'attachment',
                    'attachment-alt',
                    'audio',
                    'badge-check',
                    'balance',
                    'balance-wallet',
                    'battery',
                    'battery-alert',
                    'battery-unknown',
                    'block',
                    'block-alt',
                    'bluetooth',
                    'bluetooth-connected',
                    'bluetooth-off',
                    'bluetooth-search',
                    'bluetooth-setting',
                    'blur',
                    'blur-circular',
                    'blur-linear',
                    'blur-off',
                    'book',
                    'bookmark',
                    'bookmark-outline',
                    'border-all',
                    'border-bottom',
                    'border-clear',
                    'border-color',
                    'border-horizontal',
                    'border-inner',
                    'border-left',
                    'border-outer',
                    'border-right',
                    'border-style',
                    'border-top',
                    'border-vertical',
                    'brightness-2',
                    'brightness-3',
                    'brightness-4',
                    'brightness-5',
                    'brightness-6',
                    'brightness-7',
                    'brightness-auto',
                    'brightness-high',
                    'brightness-setting',
                    'broken-image',
                    'brush',
                    'bug',
                    'cake',
                    'calendar',
                    'calendar-alt',
                    'calendar-check',
                    'calendar-note',
                    'camera',
                    'camera-add',
                    'camera-alt',
                    'camera-front',
                    'camera-mic',
                    'camera-party-mode',
                    'camera-rear',
                    'camera-roll',
                    'camera-switch',
                    'card',
                    'card-alert',
                    'card-giftcard',
                    'card-membership',
                    'card-off',
                    'card-sd',
                    'card-sim',
                    'card-travel',
                    'caret-down',
                    'caret-down-circle',
                    'caret-up',
                    'case',
                    'case-play',
                    'cast',
                    'cast-connected',
                    'center-focus-strong',
                    'center-focus-weak',
                    'chart',
                    'chart-donut',
                    'check',
                    'check-all',
                    'check-circle',
                    'check-circle-u',
                    'check-square',
                    'chevron-down',
                    'chevron-left',
                    'chevron-right',
                    'chevron-up',
                    'circle',
                    'circle-o',
                    'city',
                    'city-alt',
                    'close',
                    'close-circle',
                    'close-circle-o',
                    'closed-caption',
                    'cloud',
                    'cloud-circle',
                    'cloud-done',
                    'cloud-download',
                    'cloud-off',
                    'cloud-outline',
                    'cloud-outline-alt',
                    'cloud-upload',
                    'code',
                    'code-setting',
                    'code-smartphone',
                    'collection-bookmark',
                    'collection-case-play',
                    'collection-folder-image',
                    'collection-image',
                    'collection-image-o',
                    'collection-item',
                    'collection-item-1',
                    'collection-item-2',
                    'collection-item-3',
                    'collection-item-4',
                    'collection-item-5',
                    'collection-item-6',
                    'collection-item-7',
                    'collection-item-8',
                    'collection-item-9',
                    'collection-item-9-plus',
                    'collection-music',
                    'collection-pdf',
                    'collection-speaker',
                    'collection-text',
                    'collection-video',
                    'comment',
                    'comment-alert',
                    'comment-alt',
                    'comment-alt-text',
                    'comment-image',
                    'comment-list',
                    'comment-outline',
                    'comment-text',
                    'comment-text-alt',
                    'comment-video',
                    'comments',
                    'compare',
                    'compass',
                    'confirmation-number',
                    'copy',
                    'crop',
                    'crop-16-9',
                    'crop-3-2',
                    'crop-5-4',
                    'crop-7-5',
                    'crop-din',
                    'crop-free',
                    'crop-landscape',
                    'crop-portrait',
                    'crop-square',
                    'delete',
                    'desktop-mac',
                    'desktop-windows',
                    'developer-board',
                    'device-hub',
                    'devices',
                    'devices-off',
                    'dialpad',
                    'directions',
                    'directions-bike',
                    'directions-boat',
                    'directions-bus',
                    'directions-car',
                    'directions-railway',
                    'directions-run',
                    'directions-subway',
                    'directions-walk',
                    'disc-full',
                    'dns',
                    'dock',
                    'dot-circle',
                    'dot-circle-alt',
                    'download',
                    'edit',
                    'eject',
                    'eject-alt',
                    'email',
                    'email-open',
                    'equalizer',
                    'explicit',
                    'exposure',
                    'exposure-alt',
                    'eye',
                    'eye-off',
                    'face',
                    'fast-forward',
                    'fast-rewind',
                    'favorite',
                    'favorite-outline',
                    'file',
                    'file-text',
                    'filter-b-and-w',
                    'filter-center-focus',
                    'filter-frames',
                    'filter-list',
                    'filter-tilt-shift',
                    'fire',
                    'flag',
                    'flare',
                    'flash',
                    'flash-auto',
                    'flash-off',
                    'flight-land',
                    'flight-takeoff',
                    'flip',
                    'flip-to-back',
                    'flip-to-front',
                    'flower',
                    'folder',
                    'folder-outline',
                    'font',
                    'format-align-center',
                    'format-align-justify',
                    'format-align-left',
                    'format-align-right',
                    'format-bold',
                    'format-clear',
                    'format-clear-all',
                    'format-color-fill',
                    'format-color-reset',
                    'format-color-text',
                    'format-indent-decrease',
                    'format-indent-increase',
                    'format-italic',
                    'format-line-spacing',
                    'format-list-bulleted',
                    'format-list-numbered',
                    'format-size',
                    'format-strikethrough',
                    'format-strikethrough-s',
                    'format-subject',
                    'format-underlined',
                    'format-valign-bottom',
                    'format-valign-center',
                    'format-valign-top',
                    'forward',
                    'forward-10',
                    'forward-30',
                    'forward-5',
                    'fullscreen',
                    'fullscreen-alt',
                    'fullscreen-exit',
                    'functions',
                    'gamepad',
                    'gesture',
                    'gif',
                    'globe',
                    'globe-alt',
                    'globe-lock',
                    'gps',
                    'gps-dot',
                    'gps-off',
                    'gradient',
                    'graduation-cap',
                    'grain',
                    'graphic-eq',
                    'grid',
                    'grid-off',
                    'group-work',
                    'hd',
                    'hdr',
                    'hdr-off',
                    'hdr-strong',
                    'hdr-weak',
                    'headset',
                    'headset-mic',
                    'hearing',
                    'help',
                    'help-outline',
                    'home',
                    'hotel',
                    'hourglass',
                    'hourglass-outline',
                    'hq',
                    'http',
                    'image',
                    'image-alt',
                    'inbox',
                    'info',
                    'info-outline',
                    'input-antenna',
                    'input-composite',
                    'input-hdmi',
                    'input-power',
                    'input-svideo',
                    'invert-colors',
                    'invert-colors-off',
                    'key',
                    'keyboard',
                    'keyboard-hide',
                    'label',
                    'label-heart',
                    'labels',
                    'landscape',
                    'laptop',
                    'laptop-chromebook',
                    'laptop-mac',
                    'layers',
                    'leak',
                    'link',
                    'local-activity',
                    'local-airport',
                    'local-atm',
                    'local-bar',
                    'local-cafe',
                    'local-car-wash',
                    'local-convenience-store',
                    'local-dining',
                    'local-drink',
                    'local-florist',
                    'local-gas-station',
                    'local-grocery-store',
                    'local-hospital',
                    'local-hotel',
                    'local-laundry-service',
                    'local-library',
                    'local-mall',
                    'local-movies',
                    'local-offer',
                    'local-parking',
                    'local-pharmacy',
                    'local-phone',
                    'local-pizza',
                    'local-post-office',
                    'local-printshop',
                    'local-see',
                    'local-shipping',
                    'local-store',
                    'local-taxi',
                    'local-wc',
                    'lock',
                    'lock-open',
                    'lock-outline',
                    'long-arrow-left',
                    'long-arrow-return',
                    'long-arrow-tab',
                    'looks',
                    'loupe',
                    'mail-reply',
                    'mail-reply-all',
                    'mail-send',
                    'male',
                    'map',
                    'markunread-mailbox',
                    'memory',
                    'menu',
                    'mic',
                    'mic-off',
                    'mic-outline',
                    'mic-setting',
                    'minus',
                    'minus-circle',
                    'minus-circle-outline',
                    'minus-square',
                    'money',
                    'money-off',
                    'mood',
                    'mood-bad',
                    'more-vert',
                    'mouse',
                    'movie',
                    'movie-alt',
                    'my-location',
                    'n-1-square',
                    'n-2-square',
                    'n-3-square',
                    'n-4-square',
                    'n-5-square',
                    'n-6-square',
                    'nature',
                    'nature-people',
                    'navigation',
                    'neg-1',
                    'neg-2',
                    'network',
                    'network-locked',
                    'network-off',
                    'network-outline',
                    'network-setting',
                    'nfc',
                    'notifications',
                    'notifications-active',
                    'notifications-add',
                    'notifications-none',
                    'notifications-off',
                    'notifications-paused',
                    'open-in-browser',
                    'open-in-new',
                    'palette',
                    'panorama-horizontal',
                    'panorama-vertical',
                    'panorama-wide-angle',
                    'pause',
                    'pause-circle',
                    'pause-circle-outline',
                    'phone',
                    'phone-bluetooth',
                    'phone-end',
                    'phone-forwarded',
                    'phone-in-talk',
                    'phone-locked',
                    'phone-missed',
                    'phone-msg',
                    'phone-paused',
                    'phone-ring',
                    'phone-setting',
                    'phone-sip',
                    'photo-size-select-large',
                    'photo-size-select-small',
                    'picture-in-picture',
                    'pin',
                    'pin-account',
                    'pin-assistant',
                    'pin-drop',
                    'pin-help',
                    'pin-off',
                    'plaster',
                    'play',
                    'play-circle',
                    'play-circle-outline',
                    'play-for-work',
                    'plus',
                    'plus-1',
                    'plus-2',
                    'plus-circle',
                    'plus-circle-o',
                    'plus-circle-o-duplicate',
                    'polymer',
                    'portable-wifi',
                    'portable-wifi-changes',
                    'portable-wifi-off',
                    'power-input',
                    'present-to-all',
                    'print',
                    'puzzle-piece',
                    'radio',
                    'reader',
                    'receipt',
                    'redo',
                    'refresh',
                    'refresh-alt',
                    'refresh-sync',
                    'remote-control',
                    'remote-control-alt',
                    'repeat',
                    'repeat-one',
                    'replay',
                    'replay-10',
                    'replay-30',
                    'replay-5',
                    'rotate-left',
                    'rotate-right',
                    'router',
                    'ruler',
                    'satellite',
                    'scanner',
                    'screen-rotation',
                    'screen-rotation-lock',
                    'search',
                    'search-for',
                    'search-in-file',
                    'search-in-page',
                    'search-replace',
                    'seat',
                    'sec-10',
                    'sec-3',
                    'select-all',
                    'settings',
                    'settings-square',
                    'share',
                    'shield-check',
                    'shield-security',
                    'shopping-basket',
                    'shopping-cart',
                    'shuffle',
                    'sign-in',
                    'skip-next',
                    'skip-previous',
                    'slideshow',
                    'smartphone',
                    'smartphone-android',
                    'smartphone-download',
                    'smartphone-erase',
                    'smartphone-info',
                    'smartphone-iphone',
                    'smartphone-landscape',
                    'smartphone-landscape-lock',
                    'smartphone-lock',
                    'smartphone-portrait-lock',
                    'smartphone-ring',
                    'smartphone-setting',
                    'smartphone-setup',
                    'space-bar',
                    'speaker',
                    'spellcheck',
                    'square-down',
                    'square-o',
                    'square-right',
                    'star',
                    'star-circle',
                    'star-half',
                    'stop',
                    'storage',
                    'sun',
                    'surround-sound',
                    'swap',
                    'swap-alt',
                    'swap-vertical-circle',
                    'tab',
                    'tab-unselected',
                    'tablet',
                    'tablet-android',
                    'tablet-mac',
                    'tag-more',
                    'tap-and-play',
                    'text-format',
                    'texture',
                    'thumb-down',
                    'thumb-up',
                    'thumb-up-down',
                    'time',
                    'time-countdown',
                    'time-interval',
                    'time-restore',
                    'time-restore-setting',
                    'timer',
                    'timer-off',
                    'toll',
                    'tonality',
                    'toys',
                    'traffic',
                    'translate',
                    'trending-down',
                    'trending-flat',
                    'trending-up',
                    'triangle-down',
                    'triangle-up',
                    'tune',
                    'tv',
                    'tv-list',
                    'tv-play',
                    'undo',
                    'unfold-less',
                    'unfold-more',
                    'upload',
                    'usb',
                    'vibration',
                    'videocam',
                    'videocam-off',
                    'videocam-switch',
                    'view-agenda',
                    'view-array',
                    'view-carousel',
                    'view-column',
                    'view-comfy',
                    'view-compact',
                    'view-dashboard',
                    'view-day',
                    'view-headline',
                    'view-list',
                    'view-list-alt',
                    'view-module',
                    'view-quilt',
                    'view-stream',
                    'view-subtitles',
                    'view-toc',
                    'view-web',
                    'view-week',
                    'vignette',
                    'voicemail',
                    'volume-down',
                    'volume-mute',
                    'volume-off',
                    'volume-up',
                    'wallpaper',
                    'watch',
                    'wb-auto',
                    'widgets',
                    'wrap-text',
                    'wrench',
                    'zero',
                    'zoom-in',
                    'zoom-out'
                ]
            },
            {
                version: '2.0.2',
                icons: [
                    '',
                    //'zmdi',
                    '3d-rotation',
                    'account',
                    'account-add',
                    'account-box',
                    'account-box-mail',
                    'account-box-o',
                    'account-box-phone',
                    'account-calendar',
                    'account-circle',
                    'account-o',
                    'accounts',
                    'accounts-add',
                    'accounts-alt',
                    'accounts-list',
                    'accounts-list-alt',
                    'accounts-outline',
                    'airline-seat-flat',
                    'airline-seat-flat-angled',
                    'airline-seat-individual-suite',
                    'airline-seat-legroom-extra',
                    'airline-seat-legroom-normal',
                    'airline-seat-legroom-reduced',
                    'airline-seat-recline-extra',
                    'airline-seat-recline-normal',
                    'airplay',
                    'alarm',
                    'alarm-check',
                    'alarm-off',
                    'alarm-snooze',
                    'album',
                    'alert-circle',
                    'alert-circle-o',
                    'alert-octagon',
                    'alert-polygon',
                    'alert-triangle',
                    'android',
                    'apps',
                    'archive',
                    'arrow-merge',
                    'arrow-missed',
                    'arrow-split',
                    'arrows',
                    'aspect-ratio',
                    'aspect-ratio-alt',
                    'assignment',
                    'assignment-account',
                    'assignment-alert',
                    'assignment-check',
                    'assignment-o',
                    'assignment-return',
                    'assignment-returned',
                    'attachment',
                    'attachment-alt',
                    'audio',
                    'badge-check',
                    'balance',
                    'balance-wallet',
                    'battery',
                    'battery-alert',
                    'battery-unknown',
                    'block',
                    'block-alt',
                    'bluetooth',
                    'bluetooth-connected',
                    'bluetooth-off',
                    'bluetooth-search',
                    'bluetooth-setting',
                    'blur',
                    'blur-circular',
                    'blur-linear',
                    'blur-off',
                    'book',
                    'bookmark',
                    'bookmark-outline',
                    'border-all',
                    'border-bottom',
                    'border-clear',
                    'border-color',
                    'border-horizontal',
                    'border-inner',
                    'border-left',
                    'border-outer',
                    'border-right',
                    'border-style',
                    'border-top',
                    'border-vertical',
                    'brightness-2',
                    'brightness-3',
                    'brightness-4',
                    'brightness-5',
                    'brightness-6',
                    'brightness-7',
                    'brightness-auto',
                    'brightness-high',
                    'brightness-setting',
                    'broken-image',
                    'brush',
                    'bug',
                    'cake',
                    'calendar',
                    'calendar-alt',
                    'calendar-check',
                    'calendar-note',
                    'camera',
                    'camera-add',
                    'camera-alt',
                    'camera-front',
                    'camera-mic',
                    'camera-party-mode',
                    'camera-rear',
                    'camera-roll',
                    'camera-switch',
                    'card',
                    'card-alert',
                    'card-giftcard',
                    'card-membership',
                    'card-off',
                    'card-sd',
                    'card-sim',
                    'card-travel',
                    'caret-down',
                    'caret-down-circle',
                    'caret-up',
                    'case',
                    'case-play',
                    'cast',
                    'cast-connected',
                    'center-focus-strong',
                    'center-focus-weak',
                    'chart',
                    'chart-donut',
                    'check',
                    'check-all',
                    'check-circle',
                    'check-circle-u',
                    'check-square',
                    'chevron-down',
                    'chevron-left',
                    'chevron-right',
                    'chevron-up',
                    'circle',
                    'circle-o',
                    'city',
                    'city-alt',
                    'close',
                    'close-circle',
                    'close-circle-o',
                    'closed-caption',
                    'cloud',
                    'cloud-circle',
                    'cloud-done',
                    'cloud-download',
                    'cloud-off',
                    'cloud-outline',
                    'cloud-outline-alt',
                    'cloud-upload',
                    'code',
                    'code-setting',
                    'code-smartphone',
                    'collection-bookmark',
                    'collection-case-play',
                    'collection-folder-image',
                    'collection-image',
                    'collection-image-o',
                    'collection-item',
                    'collection-item-1',
                    'collection-item-2',
                    'collection-item-3',
                    'collection-item-4',
                    'collection-item-5',
                    'collection-item-6',
                    'collection-item-7',
                    'collection-item-8',
                    'collection-item-9',
                    'collection-item-9-plus',
                    'collection-music',
                    'collection-pdf',
                    'collection-speaker',
                    'collection-text',
                    'collection-video',
                    'comment',
                    'comment-alert',
                    'comment-alt',
                    'comment-alt-text',
                    'comment-image',
                    'comment-list',
                    'comment-outline',
                    'comment-text',
                    'comment-text-alt',
                    'comment-video',
                    'comments',
                    'compare',
                    'compass',
                    'confirmation-number',
                    'copy',
                    'crop',
                    'crop-16-9',
                    'crop-3-2',
                    'crop-5-4',
                    'crop-7-5',
                    'crop-din',
                    'crop-free',
                    'crop-landscape',
                    'crop-portrait',
                    'crop-square',
                    'delete',
                    'desktop-mac',
                    'desktop-windows',
                    'developer-board',
                    'device-hub',
                    'devices',
                    'devices-off',
                    'dialpad',
                    'directions',
                    'directions-bike',
                    'directions-boat',
                    'directions-bus',
                    'directions-car',
                    'directions-railway',
                    'directions-run',
                    'directions-subway',
                    'directions-walk',
                    'disc-full',
                    'dns',
                    'dock',
                    'dot-circle',
                    'dot-circle-alt',
                    'download',
                    'edit',
                    'eject',
                    'eject-alt',
                    'email',
                    'email-open',
                    'equalizer',
                    'explicit',
                    'exposure',
                    'exposure-alt',
                    'eye',
                    'eye-off',
                    'face',
                    'fast-forward',
                    'fast-rewind',
                    'favorite',
                    'favorite-outline',
                    'file',
                    'file-text',
                    'filter-b-and-w',
                    'filter-center-focus',
                    'filter-frames',
                    'filter-list',
                    'filter-tilt-shift',
                    'fire',
                    'flag',
                    'flare',
                    'flash',
                    'flash-auto',
                    'flash-off',
                    'flight-land',
                    'flight-takeoff',
                    'flip',
                    'flip-to-back',
                    'flip-to-front',
                    'flower',
                    'folder',
                    'folder-outline',
                    'font',
                    'format-align-center',
                    'format-align-justify',
                    'format-align-left',
                    'format-align-right',
                    'format-bold',
                    'format-clear',
                    'format-clear-all',
                    'format-color-fill',
                    'format-color-reset',
                    'format-color-text',
                    'format-indent-decrease',
                    'format-indent-increase',
                    'format-italic',
                    'format-line-spacing',
                    'format-list-bulleted',
                    'format-list-numbered',
                    'format-size',
                    'format-strikethrough',
                    'format-strikethrough-s',
                    'format-subject',
                    'format-underlined',
                    'format-valign-bottom',
                    'format-valign-center',
                    'format-valign-top',
                    'forward',
                    'forward-10',
                    'forward-30',
                    'forward-5',
                    'fullscreen',
                    'fullscreen-alt',
                    'fullscreen-exit',
                    'functions',
                    'gamepad',
                    'gesture',
                    'gif',
                    'globe',
                    'globe-alt',
                    'globe-lock',
                    'gps',
                    'gps-dot',
                    'gps-off',
                    'gradient',
                    'graduation-cap',
                    'grain',
                    'graphic-eq',
                    'grid',
                    'grid-off',
                    'group-work',
                    'hd',
                    'hdr',
                    'hdr-off',
                    'hdr-strong',
                    'hdr-weak',
                    'headset',
                    'headset-mic',
                    'hearing',
                    'help',
                    'help-outline',
                    'home',
                    'hotel',
                    'hourglass',
                    'hourglass-outline',
                    'hq',
                    'http',
                    'image',
                    'image-alt',
                    'inbox',
                    'info',
                    'info-outline',
                    'input-antenna',
                    'input-composite',
                    'input-hdmi',
                    'input-power',
                    'input-svideo',
                    'invert-colors',
                    'invert-colors-off',
                    'key',
                    'keyboard',
                    'keyboard-hide',
                    'label',
                    'label-heart',
                    'labels',
                    'landscape',
                    'laptop',
                    'laptop-chromebook',
                    'laptop-mac',
                    'layers',
                    'leak',
                    'link',
                    'local-activity',
                    'local-airport',
                    'local-atm',
                    'local-bar',
                    'local-cafe',
                    'local-car-wash',
                    'local-convenience-store',
                    'local-dining',
                    'local-drink',
                    'local-florist',
                    'local-gas-station',
                    'local-grocery-store',
                    'local-hospital',
                    'local-hotel',
                    'local-laundry-service',
                    'local-library',
                    'local-mall',
                    'local-movies',
                    'local-offer',
                    'local-parking',
                    'local-pharmacy',
                    'local-phone',
                    'local-pizza',
                    'local-post-office',
                    'local-printshop',
                    'local-see',
                    'local-shipping',
                    'local-store',
                    'local-taxi',
                    'local-wc',
                    'lock',
                    'lock-open',
                    'lock-outline',
                    'long-arrow-left',
                    'long-arrow-return',
                    'long-arrow-tab',
                    'looks',
                    'loupe',
                    'mail-reply',
                    'mail-reply-all',
                    'mail-send',
                    'male',
                    'map',
                    'markunread-mailbox',
                    'memory',
                    'menu',
                    'mic',
                    'mic-off',
                    'mic-outline',
                    'mic-setting',
                    'minus',
                    'minus-circle',
                    'minus-circle-outline',
                    'minus-square',
                    'money',
                    'money-off',
                    'mood',
                    'mood-bad',
                    'more-vert',
                    'mouse',
                    'movie',
                    'movie-alt',
                    'my-location',
                    'n-1-square',
                    'n-2-square',
                    'n-3-square',
                    'n-4-square',
                    'n-5-square',
                    'n-6-square',
                    'nature',
                    'nature-people',
                    'navigation',
                    'neg-1',
                    'neg-2',
                    'network',
                    'network-locked',
                    'network-off',
                    'network-outline',
                    'network-setting',
                    'nfc',
                    'notifications',
                    'notifications-active',
                    'notifications-add',
                    'notifications-none',
                    'notifications-off',
                    'notifications-paused',
                    'open-in-browser',
                    'open-in-new',
                    'palette',
                    'panorama-horizontal',
                    'panorama-vertical',
                    'panorama-wide-angle',
                    'pause',
                    'pause-circle',
                    'pause-circle-outline',
                    'phone',
                    'phone-bluetooth',
                    'phone-end',
                    'phone-forwarded',
                    'phone-in-talk',
                    'phone-locked',
                    'phone-missed',
                    'phone-msg',
                    'phone-paused',
                    'phone-ring',
                    'phone-setting',
                    'phone-sip',
                    'photo-size-select-large',
                    'photo-size-select-small',
                    'picture-in-picture',
                    'pin',
                    'pin-account',
                    'pin-assistant',
                    'pin-drop',
                    'pin-help',
                    'pin-off',
                    'plaster',
                    'play',
                    'play-circle',
                    'play-circle-outline',
                    'play-for-work',
                    'plus',
                    'plus-1',
                    'plus-2',
                    'plus-circle',
                    'plus-circle-o',
                    'plus-circle-o-duplicate',
                    'polymer',
                    'portable-wifi',
                    'portable-wifi-changes',
                    'portable-wifi-off',
                    'power-input',
                    'present-to-all',
                    'print',
                    'puzzle-piece',
                    'radio',
                    'reader',
                    'receipt',
                    'redo',
                    'refresh',
                    'refresh-alt',
                    'refresh-sync',
                    'remote-control',
                    'remote-control-alt',
                    'repeat',
                    'repeat-one',
                    'replay',
                    'replay-10',
                    'replay-30',
                    'replay-5',
                    'rotate-left',
                    'rotate-right',
                    'router',
                    'ruler',
                    'satellite',
                    'scanner',
                    'screen-rotation',
                    'screen-rotation-lock',
                    'search',
                    'search-for',
                    'search-in-file',
                    'search-in-page',
                    'search-replace',
                    'seat',
                    'sec-10',
                    'sec-3',
                    'select-all',
                    'settings',
                    'settings-square',
                    'share',
                    'shield-check',
                    'shield-security',
                    'shopping-basket',
                    'shopping-cart',
                    'shuffle',
                    'sign-in',
                    'skip-next',
                    'skip-previous',
                    'slideshow',
                    'smartphone',
                    'smartphone-android',
                    'smartphone-download',
                    'smartphone-erase',
                    'smartphone-info',
                    'smartphone-iphone',
                    'smartphone-landscape',
                    'smartphone-landscape-lock',
                    'smartphone-lock',
                    'smartphone-portrait-lock',
                    'smartphone-ring',
                    'smartphone-setting',
                    'smartphone-setup',
                    'space-bar',
                    'speaker',
                    'spellcheck',
                    'square-down',
                    'square-o',
                    'square-right',
                    'star',
                    'star-circle',
                    'star-half',
                    'stop',
                    'storage',
                    'sun',
                    'surround-sound',
                    'swap',
                    'swap-alt',
                    'swap-vertical-circle',
                    'tab',
                    'tab-unselected',
                    'tablet',
                    'tablet-android',
                    'tablet-mac',
                    'tag-more',
                    'tap-and-play',
                    'text-format',
                    'texture',
                    'thumb-down',
                    'thumb-up',
                    'thumb-up-down',
                    'time',
                    'time-countdown',
                    'time-interval',
                    'time-restore',
                    'time-restore-setting',
                    'timer',
                    'timer-off',
                    'toll',
                    'tonality',
                    'toys',
                    'traffic',
                    'translate',
                    'trending-down',
                    'trending-flat',
                    'trending-up',
                    'triangle-down',
                    'triangle-up',
                    'tune',
                    'tv',
                    'tv-list',
                    'tv-play',
                    'undo',
                    'unfold-less',
                    'unfold-more',
                    'upload',
                    'usb',
                    'vibration',
                    'videocam',
                    'videocam-off',
                    'videocam-switch',
                    'view-agenda',
                    'view-array',
                    'view-carousel',
                    'view-column',
                    'view-comfy',
                    'view-compact',
                    'view-dashboard',
                    'view-day',
                    'view-headline',
                    'view-list',
                    'view-list-alt',
                    'view-module',
                    'view-quilt',
                    'view-stream',
                    'view-subtitles',
                    'view-toc',
                    'view-web',
                    'view-week',
                    'vignette',
                    'voicemail',
                    'volume-down',
                    'volume-mute',
                    'volume-off',
                    'volume-up',
                    'wallpaper',
                    'watch',
                    'wb-auto',
                    'widgets',
                    'wrap-text',
                    'wrench',
                    'zero',
                    'zoom-in',
                    'zoom-out'
                ]
            },
            {
                version: '2.1.0',
                icons: [
                    '',
                    //'zmdi',
                    '3d-rotation',
                    'account',
                    'account-add',
                    'account-box',
                    'account-box-mail',
                    'account-box-o',
                    'account-box-phone',
                    'account-calendar',
                    'account-circle',
                    'account-o',
                    'accounts',
                    'accounts-add',
                    'accounts-alt',
                    'accounts-list',
                    'accounts-list-alt',
                    'accounts-outline',
                    'airline-seat-flat',
                    'airline-seat-flat-angled',
                    'airline-seat-individual-suite',
                    'airline-seat-legroom-extra',
                    'airline-seat-legroom-normal',
                    'airline-seat-legroom-reduced',
                    'airline-seat-recline-extra',
                    'airline-seat-recline-normal',
                    'airplane',
                    'airplane-off',
                    'airplay',
                    'alarm',
                    'alarm-check',
                    'alarm-off',
                    'alarm-plus',
                    'alarm-snooze',
                    'album',
                    'alert-circle',
                    'alert-circle-o',
                    'alert-octagon',
                    'alert-polygon',
                    'alert-triangle',
                    'android',
                    'android-alt',
                    'apple',
                    'apps',
                    'archive',
                    'arrow-left',
                    'arrow-left-bottom',
                    'arrow-merge',
                    'arrow-missed',
                    'arrow-right',
                    'arrow-right-top',
                    'arrow-split',
                    'arrows',
                    'aspect-ratio',
                    'aspect-ratio-alt',
                    'assignment',
                    'assignment-account',
                    'assignment-alert',
                    'assignment-check',
                    'assignment-o',
                    'assignment-return',
                    'assignment-returned',
                    'attachment',
                    'attachment-alt',
                    'audio',
                    'badge-check',
                    'balance',
                    'balance-wallet',
                    'battery',
                    'battery-alert',
                    'battery-flash',
                    'battery-unknown',
                    'behance',
                    'bike',
                    'block',
                    'block-alt',
                    'bluetooth',
                    'bluetooth-connected',
                    'bluetooth-off',
                    'bluetooth-search',
                    'bluetooth-setting',
                    'blur',
                    'blur-circular',
                    'blur-linear',
                    'blur-off',
                    'boat',
                    'book',
                    'book-image',
                    'bookmark',
                    'bookmark-outline',
                    'border-all',
                    'border-bottom',
                    'border-clear',
                    'border-color',
                    'border-horizontal',
                    'border-inner',
                    'border-left',
                    'border-outer',
                    'border-right',
                    'border-style',
                    'border-top',
                    'border-vertical',
                    'brightness-2',
                    'brightness-3',
                    'brightness-4',
                    'brightness-5',
                    'brightness-6',
                    'brightness-7',
                    'brightness-auto',
                    'brightness-high',
                    'brightness-setting',
                    'broken-image',
                    'brush',
                    'bug',
                    'bus',
                    'cake',
                    'calendar',
                    'calendar-alt',
                    'calendar-check',
                    'calendar-close',
                    'calendar-note',
                    'camera',
                    'camera-add',
                    'camera-alt',
                    'camera-bw',
                    'camera-front',
                    'camera-mic',
                    'camera-party-mode',
                    'camera-rear',
                    'camera-roll',
                    'camera-switch',
                    'car',
                    'car-taxi',
                    'car-wash',
                    'card',
                    'card-alert',
                    'card-giftcard',
                    'card-membership',
                    'card-off',
                    'card-sd',
                    'card-sim',
                    'card-travel',
                    'caret-down',
                    'caret-down-circle',
                    'caret-left',
                    'caret-left-circle',
                    'caret-right',
                    'caret-right-circle',
                    'caret-up',
                    'caret-up-circle',
                    'case',
                    'case-check',
                    'case-download',
                    'case-play',
                    'cast',
                    'cast-connected',
                    'center-focus-strong',
                    'center-focus-weak',
                    'chart',
                    'chart-donut',
                    'check',
                    'check-all',
                    'check-circle',
                    'check-circle-u',
                    'check-square',
                    'chevron-down',
                    'chevron-left',
                    'chevron-right',
                    'chevron-up',
                    'circle',
                    'circle-o',
                    'city',
                    'city-alt',
                    'close',
                    'close-circle',
                    'close-circle-o',
                    'closed-caption',
                    'cloud',
                    'cloud-box',
                    'cloud-circle',
                    'cloud-done',
                    'cloud-download',
                    'cloud-off',
                    'cloud-outline',
                    'cloud-outline-alt',
                    'cloud-upload',
                    'cocktail',
                    'code',
                    'code-setting',
                    'code-smartphone',
                    'codepen',
                    'coffee',
                    'collection-bookmark',
                    'collection-case-play',
                    'collection-folder-image',
                    'collection-image',
                    'collection-image-o',
                    'collection-item',
                    'collection-item-1',
                    'collection-item-2',
                    'collection-item-3',
                    'collection-item-4',
                    'collection-item-5',
                    'collection-item-6',
                    'collection-item-7',
                    'collection-item-8',
                    'collection-item-9',
                    'collection-item-9-plus',
                    'collection-music',
                    'collection-pdf',
                    'collection-plus',
                    'collection-speaker',
                    'collection-text',
                    'collection-video',
                    'comment',
                    'comment-alert',
                    'comment-alt',
                    'comment-alt-text',
                    'comment-edit',
                    'comment-image',
                    'comment-list',
                    'comment-more',
                    'comment-outline',
                    'comment-text',
                    'comment-text-alt',
                    'comment-video',
                    'comments',
                    'compare',
                    'compass',
                    'confirmation-number',
                    'copy',
                    'crop',
                    'crop-16-9',
                    'crop-3-2',
                    'crop-5-4',
                    'crop-7-5',
                    'crop-din',
                    'crop-free',
                    'crop-landscape',
                    'crop-portrait',
                    'crop-square',
                    'cutlery',
                    'delete',
                    'desktop-mac',
                    'desktop-windows',
                    'developer-board',
                    'device-hub',
                    'devices',
                    'devices-off',
                    'dialpad',
                    'directions',
                    'directions-bike',
                    'directions-boat',
                    'directions-bus',
                    'directions-car',
                    'directions-railway',
                    'directions-run',
                    'directions-subway',
                    'directions-walk',
                    'disc-full',
                    'dns',
                    'dock',
                    'dot-circle',
                    'dot-circle-alt',
                    'download',
                    'dribbble',
                    'drink',
                    'dropbox',
                    'edit',
                    'eject',
                    'eject-alt',
                    'email',
                    'email-open',
                    'equalizer',
                    'evernote',
                    'explicit',
                    'exposure',
                    'exposure-alt',
                    'eye',
                    'eye-off',
                    'eyedropper',
                    'face',
                    'facebook',
                    'facebook-box',
                    'fast-forward',
                    'fast-rewind',
                    'favorite',
                    'favorite-outline',
                    'female',
                    'file',
                    'file-plus',
                    'file-text',
                    'filter-b-and-w',
                    'filter-center-focus',
                    'filter-frames',
                    'filter-list',
                    'filter-tilt-shift',
                    'fire',
                    'flag',
                    'flare',
                    'flash',
                    'flash-auto',
                    'flash-off',
                    'flight-land',
                    'flight-takeoff',
                    'flip',
                    'flip-to-back',
                    'flip-to-front',
                    'floppy',
                    'flower',
                    'flower-alt',
                    'folder',
                    'folder-outline',
                    'folder-person',
                    'folder-star',
                    'folder-star-alt',
                    'font',
                    'format-align-center',
                    'format-align-justify',
                    'format-align-left',
                    'format-align-right',
                    'format-bold',
                    'format-clear',
                    'format-clear-all',
                    'format-color-fill',
                    'format-color-reset',
                    'format-color-text',
                    'format-indent-decrease',
                    'format-indent-increase',
                    'format-italic',
                    'format-line-spacing',
                    'format-list-bulleted',
                    'format-list-numbered',
                    'format-ltr',
                    'format-rtl',
                    'format-size',
                    'format-strikethrough',
                    'format-strikethrough-s',
                    'format-subject',
                    'format-underlined',
                    'format-valign-bottom',
                    'format-valign-center',
                    'format-valign-top',
                    'forward',
                    'forward-10',
                    'forward-30',
                    'forward-5',
                    'fullscreen',
                    'fullscreen-alt',
                    'fullscreen-exit',
                    'functions',
                    'gamepad',
                    'gas-station',
                    'gesture',
                    'gif',
                    'github',
                    'github-box',
                    'globe',
                    'globe-alt',
                    'globe-lock',
                    'google',
                    'google-drive',
                    'google-earth',
                    'google-glass',
                    'google-maps',
                    'google-pages',
                    'google-play',
                    'google-plus',
                    'google-plus-box',
                    'gps',
                    'gps-dot',
                    'gps-off',
                    'gradient',
                    'graduation-cap',
                    'grain',
                    'graphic-eq',
                    'grid',
                    'grid-off',
                    'group-work',
                    'hd',
                    'hdr',
                    'hdr-off',
                    'hdr-strong',
                    'hdr-weak',
                    'headset',
                    'headset-mic',
                    'hearing',
                    'help',
                    'help-outline',
                    'home',
                    'hospital',
                    'hospital-alt',
                    'hotel',
                    'hourglass',
                    'hourglass-alt',
                    'hourglass-outline',
                    'hq',
                    'http',
                    'image',
                    'image-alt',
                    'image-o',
                    'inbox',
                    'info',
                    'info-outline',
                    'input-antenna',
                    'input-composite',
                    'input-hdmi',
                    'input-power',
                    'input-svideo',
                    'instagram',
                    'invert-colors',
                    'invert-colors-off',
                    'iridescent',
                    'key',
                    'keyboard',
                    'keyboard-hide',
                    'label',
                    'label-alt',
                    'label-alt-outline',
                    'label-heart',
                    'labels',
                    'lamp',
                    'landscape',
                    'language-css3',
                    'language-html5',
                    'language-javascript',
                    'language-python',
                    'language-python-alt',
                    'laptop',
                    'laptop-chromebook',
                    'laptop-mac',
                    'lastfm',
                    'layers',
                    'layers-off',
                    'leak',
                    'leak-off',
                    'library',
                    'link',
                    'linkedin-box',
                    'local-activity',
                    'local-airport',
                    'local-atm',
                    'local-bar',
                    'local-cafe',
                    'local-car-wash',
                    'local-convenience-store',
                    'local-dining',
                    'local-drink',
                    'local-florist',
                    'local-gas-station',
                    'local-grocery-store',
                    'local-hospital',
                    'local-hotel',
                    'local-laundry-service',
                    'local-library',
                    'local-mall',
                    'local-movies',
                    'local-offer',
                    'local-parking',
                    'local-pharmacy',
                    'local-phone',
                    'local-pizza',
                    'local-post-office',
                    'local-printshop',
                    'local-see',
                    'local-shipping',
                    'local-store',
                    'local-taxi',
                    'local-wc',
                    'lock',
                    'lock-open',
                    'lock-outline',
                    'long-arrow-down',
                    'long-arrow-left',
                    'long-arrow-return',
                    'long-arrow-right',
                    'long-arrow-tab',
                    'long-arrow-up',
                    'looks',
                    'loupe',
                    'mail-reply',
                    'mail-reply-all',
                    'mail-send',
                    'male',
                    'male-alt',
                    'male-female',
                    'mall',
                    'map',
                    'markunread-mailbox',
                    'memory',
                    'menu',
                    'mic',
                    'mic-off',
                    'mic-outline',
                    'mic-setting',
                    'minus',
                    'minus-circle',
                    'minus-circle-outline',
                    'minus-square',
                    'money',
                    'money-box',
                    'money-off',
                    'mood',
                    'mood-bad',
                    'more',
                    'more-vert',
                    'mouse',
                    'movie',
                    'movie-alt',
                    'my-location',
                    'n-1-square',
                    'n-2-square',
                    'n-3-square',
                    'n-4-square',
                    'n-5-square',
                    'n-6-square',
                    'nature',
                    'nature-people',
                    'navigation',
                    'neg-1',
                    'neg-2',
                    'network',
                    'network-alert',
                    'network-locked',
                    'network-off',
                    'network-outline',
                    'network-setting',
                    'nfc',
                    'notifications',
                    'notifications-active',
                    'notifications-add',
                    'notifications-none',
                    'notifications-off',
                    'notifications-paused',
                    'open-in-browser',
                    'open-in-new',
                    'palette',
                    'panorama-horizontal',
                    'panorama-vertical',
                    'panorama-wide-angle',
                    'parking',
                    'pause',
                    'pause-circle',
                    'pause-circle-outline',
                    'paypal',
                    'phone',
                    'phone-bluetooth',
                    'phone-end',
                    'phone-forwarded',
                    'phone-in-talk',
                    'phone-locked',
                    'phone-missed',
                    'phone-msg',
                    'phone-paused',
                    'phone-ring',
                    'phone-setting',
                    'phone-sip',
                    'photo-size-select-large',
                    'photo-size-select-small',
                    'picture-in-picture',
                    'pin',
                    'pin-account',
                    'pin-assistant',
                    'pin-drop',
                    'pin-help',
                    'pin-off',
                    'pinterest-box',
                    'pizza',
                    'plaster',
                    'play',
                    'play-circle',
                    'play-circle-outline',
                    'play-for-work',
                    'playlist-audio',
                    'playlist-plus',
                    'plus',
                    'plus-1',
                    'plus-2',
                    'plus-circle',
                    'plus-circle-o',
                    'plus-circle-o-duplicate',
                    'plus-square',
                    'pocket',
                    'polymer',
                    'portable-wifi',
                    'portable-wifi-changes',
                    'portable-wifi-off',
                    'power',
                    'power-input',
                    'power-setting',
                    'present-to-all',
                    'print',
                    'puzzle-piece',
                    'quote',
                    'radio',
                    'railway',
                    'reader',
                    'receipt',
                    'redo',
                    'refresh',
                    'refresh-alt',
                    'refresh-sync',
                    'refresh-sync-alert',
                    'refresh-sync-off',
                    'remote-control',
                    'remote-control-alt',
                    'repeat',
                    'repeat-one',
                    'replay',
                    'replay-10',
                    'replay-30',
                    'replay-5',
                    'roller',
                    'rotate-ccw',
                    'rotate-cw',
                    'rotate-left',
                    'rotate-right',
                    'router',
                    'ruler',
                    'run',
                    'satellite',
                    'scanner',
                    'scissors',
                    'screen-rotation',
                    'screen-rotation-lock',
                    'search',
                    'search-for',
                    'search-in-file',
                    'search-in-page',
                    'search-replace',
                    'seat',
                    'sec-10',
                    'sec-3',
                    'select-all',
                    'settings',
                    'settings-square',
                    'share',
                    'shield-check',
                    'shield-security',
                    'shopping-basket',
                    'shopping-cart',
                    'shopping-cart-plus',
                    'shuffle',
                    'sign-in',
                    'skip-next',
                    'skip-previous',
                    'slideshow',
                    'smartphone',
                    'smartphone-android',
                    'smartphone-download',
                    'smartphone-erase',
                    'smartphone-info',
                    'smartphone-iphone',
                    'smartphone-landscape',
                    'smartphone-landscape-lock',
                    'smartphone-lock',
                    'smartphone-portrait-lock',
                    'smartphone-ring',
                    'smartphone-setting',
                    'smartphone-setup',
                    'sort-amount-asc',
                    'sort-amount-desc',
                    'sort-asc',
                    'sort-desc',
                    'space-bar',
                    'speaker',
                    'spellcheck',
                    'square-down',
                    'square-o',
                    'square-right',
                    'star',
                    'star-circle',
                    'star-half',
                    'star-outline',
                    'steam',
                    'steam-square',
                    'stop',
                    'storage',
                    'store',
                    'store-24',
                    'subway',
                    'sun',
                    'surround-sound',
                    'swap',
                    'swap-alt',
                    'swap-vertical',
                    'swap-vertical-circle',
                    'tab',
                    'tab-unselected',
                    'tablet',
                    'tablet-android',
                    'tablet-mac',
                    'tag',
                    'tag-close',
                    'tag-more',
                    'tap-and-play',
                    'text-format',
                    'texture',
                    'thumb-down',
                    'thumb-up',
                    'thumb-up-down',
                    'ticket-star',
                    'time',
                    'time-countdown',
                    'time-interval',
                    'time-restore',
                    'time-restore-setting',
                    'timer',
                    'timer-off',
                    'toll',
                    'tonality',
                    'toys',
                    'traffic',
                    'transform',
                    'translate',
                    'trending-down',
                    'trending-flat',
                    'trending-up',
                    'triangle-down',
                    'triangle-up',
                    'truck',
                    'tune',
                    'turning-sign',
                    'tv',
                    'tv-alt-play',
                    'tv-list',
                    'tv-play',
                    'twitter',
                    'twitter-box',
                    'undo',
                    'unfold-less',
                    'unfold-more',
                    'upload',
                    'usb',
                    'vibration',
                    'videocam',
                    'videocam-off',
                    'videocam-switch',
                    'view-agenda',
                    'view-array',
                    'view-carousel',
                    'view-column',
                    'view-comfy',
                    'view-compact',
                    'view-dashboard',
                    'view-day',
                    'view-headline',
                    'view-list',
                    'view-list-alt',
                    'view-module',
                    'view-quilt',
                    'view-stream',
                    'view-subtitles',
                    'view-toc',
                    'view-web',
                    'view-week',
                    'vignette',
                    'vk',
                    'voicemail',
                    'volume-down',
                    'volume-mute',
                    'volume-off',
                    'volume-up',
                    'walk',
                    'wallpaper',
                    'washing-machine',
                    'watch',
                    'wb-auto',
                    'widgets',
                    'wifi',
                    'wifi-alt',
                    'wifi-alt-2',
                    'wifi-info',
                    'wifi-lock',
                    'wifi-off',
                    'wifi-outline',
                    'wikipedia',
                    'window-maximize',
                    'window-minimize',
                    'window-restore',
                    'windows',
                    'wrap-text',
                    'wrench',
                    'zero',
                    'zoom-in',
                    'zoom-out'
                ]
            },
            {
                version: '2.1.1',
                icons: [
                    '',
                    //'zmdi',
                    '3d-rotation',
                    'account',
                    'account-add',
                    'account-box',
                    'account-box-mail',
                    'account-box-o',
                    'account-box-phone',
                    'account-calendar',
                    'account-circle',
                    'account-o',
                    'accounts',
                    'accounts-add',
                    'accounts-alt',
                    'accounts-list',
                    'accounts-list-alt',
                    'accounts-outline',
                    'airline-seat-flat',
                    'airline-seat-flat-angled',
                    'airline-seat-individual-suite',
                    'airline-seat-legroom-extra',
                    'airline-seat-legroom-normal',
                    'airline-seat-legroom-reduced',
                    'airline-seat-recline-extra',
                    'airline-seat-recline-normal',
                    'airplane',
                    'airplane-off',
                    'airplay',
                    'alarm',
                    'alarm-check',
                    'alarm-off',
                    'alarm-plus',
                    'alarm-snooze',
                    'album',
                    'alert-circle',
                    'alert-circle-o',
                    'alert-octagon',
                    'alert-polygon',
                    'alert-triangle',
                    'android',
                    'android-alt',
                    'apple',
                    'apps',
                    'archive',
                    'arrow-left',
                    'arrow-left-bottom',
                    'arrow-merge',
                    'arrow-missed',
                    'arrow-right',
                    'arrow-right-top',
                    'arrow-split',
                    'arrows',
                    'aspect-ratio',
                    'aspect-ratio-alt',
                    'assignment',
                    'assignment-account',
                    'assignment-alert',
                    'assignment-check',
                    'assignment-o',
                    'assignment-return',
                    'assignment-returned',
                    'attachment',
                    'attachment-alt',
                    'audio',
                    'badge-check',
                    'balance',
                    'balance-wallet',
                    'battery',
                    'battery-alert',
                    'battery-flash',
                    'battery-unknown',
                    'behance',
                    'bike',
                    'block',
                    'block-alt',
                    'bluetooth',
                    'bluetooth-connected',
                    'bluetooth-off',
                    'bluetooth-search',
                    'bluetooth-setting',
                    'blur',
                    'blur-circular',
                    'blur-linear',
                    'blur-off',
                    'boat',
                    'book',
                    'book-image',
                    'bookmark',
                    'bookmark-outline',
                    'border-all',
                    'border-bottom',
                    'border-clear',
                    'border-color',
                    'border-horizontal',
                    'border-inner',
                    'border-left',
                    'border-outer',
                    'border-right',
                    'border-style',
                    'border-top',
                    'border-vertical',
                    'brightness-2',
                    'brightness-3',
                    'brightness-4',
                    'brightness-5',
                    'brightness-6',
                    'brightness-7',
                    'brightness-auto',
                    'brightness-high',
                    'brightness-setting',
                    'broken-image',
                    'brush',
                    'bug',
                    'bus',
                    'cake',
                    'calendar',
                    'calendar-alt',
                    'calendar-check',
                    'calendar-close',
                    'calendar-note',
                    'camera',
                    'camera-add',
                    'camera-alt',
                    'camera-bw',
                    'camera-front',
                    'camera-mic',
                    'camera-party-mode',
                    'camera-rear',
                    'camera-roll',
                    'camera-switch',
                    'car',
                    'car-taxi',
                    'car-wash',
                    'card',
                    'card-alert',
                    'card-giftcard',
                    'card-membership',
                    'card-off',
                    'card-sd',
                    'card-sim',
                    'card-travel',
                    'caret-down',
                    'caret-down-circle',
                    'caret-left',
                    'caret-left-circle',
                    'caret-right',
                    'caret-right-circle',
                    'caret-up',
                    'caret-up-circle',
                    'case',
                    'case-check',
                    'case-download',
                    'case-play',
                    'cast',
                    'cast-connected',
                    'center-focus-strong',
                    'center-focus-weak',
                    'chart',
                    'chart-donut',
                    'check',
                    'check-all',
                    'check-circle',
                    'check-circle-u',
                    'check-square',
                    'chevron-down',
                    'chevron-left',
                    'chevron-right',
                    'chevron-up',
                    'circle',
                    'circle-o',
                    'city',
                    'city-alt',
                    'close',
                    'close-circle',
                    'close-circle-o',
                    'closed-caption',
                    'cloud',
                    'cloud-box',
                    'cloud-circle',
                    'cloud-done',
                    'cloud-download',
                    'cloud-off',
                    'cloud-outline',
                    'cloud-outline-alt',
                    'cloud-upload',
                    'cocktail',
                    'code',
                    'code-setting',
                    'code-smartphone',
                    'codepen',
                    'coffee',
                    'collection-bookmark',
                    'collection-case-play',
                    'collection-folder-image',
                    'collection-image',
                    'collection-image-o',
                    'collection-item',
                    'collection-item-1',
                    'collection-item-2',
                    'collection-item-3',
                    'collection-item-4',
                    'collection-item-5',
                    'collection-item-6',
                    'collection-item-7',
                    'collection-item-8',
                    'collection-item-9',
                    'collection-item-9-plus',
                    'collection-music',
                    'collection-pdf',
                    'collection-plus',
                    'collection-speaker',
                    'collection-text',
                    'collection-video',
                    'comment',
                    'comment-alert',
                    'comment-alt',
                    'comment-alt-text',
                    'comment-edit',
                    'comment-image',
                    'comment-list',
                    'comment-more',
                    'comment-outline',
                    'comment-text',
                    'comment-text-alt',
                    'comment-video',
                    'comments',
                    'compare',
                    'compass',
                    'confirmation-number',
                    'copy',
                    'crop',
                    'crop-16-9',
                    'crop-3-2',
                    'crop-5-4',
                    'crop-7-5',
                    'crop-din',
                    'crop-free',
                    'crop-landscape',
                    'crop-portrait',
                    'crop-square',
                    'cutlery',
                    'delete',
                    'desktop-mac',
                    'desktop-windows',
                    'developer-board',
                    'device-hub',
                    'devices',
                    'devices-off',
                    'dialpad',
                    'directions',
                    'directions-bike',
                    'directions-boat',
                    'directions-bus',
                    'directions-car',
                    'directions-railway',
                    'directions-run',
                    'directions-subway',
                    'directions-walk',
                    'disc-full',
                    'dns',
                    'dock',
                    'dot-circle',
                    'dot-circle-alt',
                    'download',
                    'dribbble',
                    'drink',
                    'dropbox',
                    'edit',
                    'eject',
                    'eject-alt',
                    'email',
                    'email-open',
                    'equalizer',
                    'evernote',
                    'explicit',
                    'exposure',
                    'exposure-alt',
                    'eye',
                    'eye-off',
                    'eyedropper',
                    'face',
                    'facebook',
                    'facebook-box',
                    'fast-forward',
                    'fast-rewind',
                    'favorite',
                    'favorite-outline',
                    'female',
                    'file',
                    'file-plus',
                    'file-text',
                    'filter-b-and-w',
                    'filter-center-focus',
                    'filter-frames',
                    'filter-list',
                    'filter-tilt-shift',
                    'fire',
                    'flag',
                    'flare',
                    'flash',
                    'flash-auto',
                    'flash-off',
                    'flight-land',
                    'flight-takeoff',
                    'flip',
                    'flip-to-back',
                    'flip-to-front',
                    'floppy',
                    'flower',
                    'flower-alt',
                    'folder',
                    'folder-outline',
                    'folder-person',
                    'folder-star',
                    'folder-star-alt',
                    'font',
                    'format-align-center',
                    'format-align-justify',
                    'format-align-left',
                    'format-align-right',
                    'format-bold',
                    'format-clear',
                    'format-clear-all',
                    'format-color-fill',
                    'format-color-reset',
                    'format-color-text',
                    'format-indent-decrease',
                    'format-indent-increase',
                    'format-italic',
                    'format-line-spacing',
                    'format-list-bulleted',
                    'format-list-numbered',
                    'format-ltr',
                    'format-rtl',
                    'format-size',
                    'format-strikethrough',
                    'format-strikethrough-s',
                    'format-subject',
                    'format-underlined',
                    'format-valign-bottom',
                    'format-valign-center',
                    'format-valign-top',
                    'forward',
                    'forward-10',
                    'forward-30',
                    'forward-5',
                    'fullscreen',
                    'fullscreen-alt',
                    'fullscreen-exit',
                    'functions',
                    'gamepad',
                    'gas-station',
                    'gesture',
                    'gif',
                    'github',
                    'github-box',
                    'globe',
                    'globe-alt',
                    'globe-lock',
                    'google',
                    'google-drive',
                    'google-earth',
                    'google-glass',
                    'google-maps',
                    'google-pages',
                    'google-play',
                    'google-plus',
                    'google-plus-box',
                    'gps',
                    'gps-dot',
                    'gps-off',
                    'gradient',
                    'graduation-cap',
                    'grain',
                    'graphic-eq',
                    'grid',
                    'grid-off',
                    'group-work',
                    'hd',
                    'hdr',
                    'hdr-off',
                    'hdr-strong',
                    'hdr-weak',
                    'headset',
                    'headset-mic',
                    'hearing',
                    'help',
                    'help-outline',
                    'home',
                    'hospital',
                    'hospital-alt',
                    'hotel',
                    'hourglass',
                    'hourglass-alt',
                    'hourglass-outline',
                    'hq',
                    'http',
                    'image',
                    'image-alt',
                    'image-o',
                    'inbox',
                    'info',
                    'info-outline',
                    'input-antenna',
                    'input-composite',
                    'input-hdmi',
                    'input-power',
                    'input-svideo',
                    'instagram',
                    'invert-colors',
                    'invert-colors-off',
                    'iridescent',
                    'key',
                    'keyboard',
                    'keyboard-hide',
                    'label',
                    'label-alt',
                    'label-alt-outline',
                    'label-heart',
                    'labels',
                    'lamp',
                    'landscape',
                    'language-css3',
                    'language-html5',
                    'language-javascript',
                    'language-python',
                    'language-python-alt',
                    'laptop',
                    'laptop-chromebook',
                    'laptop-mac',
                    'lastfm',
                    'layers',
                    'layers-off',
                    'leak',
                    'leak-off',
                    'library',
                    'link',
                    'linkedin-box',
                    'local-activity',
                    'local-airport',
                    'local-atm',
                    'local-bar',
                    'local-cafe',
                    'local-car-wash',
                    'local-convenience-store',
                    'local-dining',
                    'local-drink',
                    'local-florist',
                    'local-gas-station',
                    'local-grocery-store',
                    'local-hospital',
                    'local-hotel',
                    'local-laundry-service',
                    'local-library',
                    'local-mall',
                    'local-movies',
                    'local-offer',
                    'local-parking',
                    'local-pharmacy',
                    'local-phone',
                    'local-pizza',
                    'local-post-office',
                    'local-printshop',
                    'local-see',
                    'local-shipping',
                    'local-store',
                    'local-taxi',
                    'local-wc',
                    'lock',
                    'lock-open',
                    'lock-outline',
                    'long-arrow-down',
                    'long-arrow-left',
                    'long-arrow-return',
                    'long-arrow-right',
                    'long-arrow-tab',
                    'long-arrow-up',
                    'looks',
                    'loupe',
                    'mail-reply',
                    'mail-reply-all',
                    'mail-send',
                    'male',
                    'male-alt',
                    'male-female',
                    'mall',
                    'map',
                    'markunread-mailbox',
                    'memory',
                    'menu',
                    'mic',
                    'mic-off',
                    'mic-outline',
                    'mic-setting',
                    'minus',
                    'minus-circle',
                    'minus-circle-outline',
                    'minus-square',
                    'money',
                    'money-box',
                    'money-off',
                    'mood',
                    'mood-bad',
                    'more',
                    'more-vert',
                    'mouse',
                    'movie',
                    'movie-alt',
                    'my-location',
                    'n-1-square',
                    'n-2-square',
                    'n-3-square',
                    'n-4-square',
                    'n-5-square',
                    'n-6-square',
                    'nature',
                    'nature-people',
                    'navigation',
                    'neg-1',
                    'neg-2',
                    'network',
                    'network-alert',
                    'network-locked',
                    'network-off',
                    'network-outline',
                    'network-setting',
                    'nfc',
                    'notifications',
                    'notifications-active',
                    'notifications-add',
                    'notifications-none',
                    'notifications-off',
                    'notifications-paused',
                    'open-in-browser',
                    'open-in-new',
                    'palette',
                    'panorama-horizontal',
                    'panorama-vertical',
                    'panorama-wide-angle',
                    'parking',
                    'pause',
                    'pause-circle',
                    'pause-circle-outline',
                    'paypal',
                    'phone',
                    'phone-bluetooth',
                    'phone-end',
                    'phone-forwarded',
                    'phone-in-talk',
                    'phone-locked',
                    'phone-missed',
                    'phone-msg',
                    'phone-paused',
                    'phone-ring',
                    'phone-setting',
                    'phone-sip',
                    'photo-size-select-large',
                    'photo-size-select-small',
                    'picture-in-picture',
                    'pin',
                    'pin-account',
                    'pin-assistant',
                    'pin-drop',
                    'pin-help',
                    'pin-off',
                    'pinterest-box',
                    'pizza',
                    'plaster',
                    'play',
                    'play-circle',
                    'play-circle-outline',
                    'play-for-work',
                    'playlist-audio',
                    'playlist-plus',
                    'plus',
                    'plus-1',
                    'plus-2',
                    'plus-circle',
                    'plus-circle-o',
                    'plus-circle-o-duplicate',
                    'plus-square',
                    'pocket',
                    'polymer',
                    'portable-wifi',
                    'portable-wifi-changes',
                    'portable-wifi-off',
                    'power',
                    'power-input',
                    'power-setting',
                    'present-to-all',
                    'print',
                    'puzzle-piece',
                    'quote',
                    'radio',
                    'railway',
                    'reader',
                    'receipt',
                    'redo',
                    'refresh',
                    'refresh-alt',
                    'refresh-sync',
                    'refresh-sync-alert',
                    'refresh-sync-off',
                    'remote-control',
                    'remote-control-alt',
                    'repeat',
                    'repeat-one',
                    'replay',
                    'replay-10',
                    'replay-30',
                    'replay-5',
                    'roller',
                    'rotate-ccw',
                    'rotate-cw',
                    'rotate-left',
                    'rotate-right',
                    'router',
                    'ruler',
                    'run',
                    'satellite',
                    'scanner',
                    'scissors',
                    'screen-rotation',
                    'screen-rotation-lock',
                    'search',
                    'search-for',
                    'search-in-file',
                    'search-in-page',
                    'search-replace',
                    'seat',
                    'sec-10',
                    'sec-3',
                    'select-all',
                    'settings',
                    'settings-square',
                    'share',
                    'shield-check',
                    'shield-security',
                    'shopping-basket',
                    'shopping-cart',
                    'shopping-cart-plus',
                    'shuffle',
                    'sign-in',
                    'skip-next',
                    'skip-previous',
                    'slideshow',
                    'smartphone',
                    'smartphone-android',
                    'smartphone-download',
                    'smartphone-erase',
                    'smartphone-info',
                    'smartphone-iphone',
                    'smartphone-landscape',
                    'smartphone-landscape-lock',
                    'smartphone-lock',
                    'smartphone-portrait-lock',
                    'smartphone-ring',
                    'smartphone-setting',
                    'smartphone-setup',
                    'sort-amount-asc',
                    'sort-amount-desc',
                    'sort-asc',
                    'sort-desc',
                    'space-bar',
                    'speaker',
                    'spellcheck',
                    'square-down',
                    'square-o',
                    'square-right',
                    'star',
                    'star-circle',
                    'star-half',
                    'star-outline',
                    'steam',
                    'steam-square',
                    'stop',
                    'storage',
                    'store',
                    'store-24',
                    'subway',
                    'sun',
                    'surround-sound',
                    'swap',
                    'swap-alt',
                    'swap-vertical',
                    'swap-vertical-circle',
                    'tab',
                    'tab-unselected',
                    'tablet',
                    'tablet-android',
                    'tablet-mac',
                    'tag',
                    'tag-close',
                    'tag-more',
                    'tap-and-play',
                    'text-format',
                    'texture',
                    'thumb-down',
                    'thumb-up',
                    'thumb-up-down',
                    'ticket-star',
                    'time',
                    'time-countdown',
                    'time-interval',
                    'time-restore',
                    'time-restore-setting',
                    'timer',
                    'timer-off',
                    'toll',
                    'tonality',
                    'toys',
                    'traffic',
                    'transform',
                    'translate',
                    'trending-down',
                    'trending-flat',
                    'trending-up',
                    'triangle-down',
                    'triangle-up',
                    'truck',
                    'tune',
                    'turning-sign',
                    'tv',
                    'tv-alt-play',
                    'tv-list',
                    'tv-play',
                    'twitter',
                    'twitter-box',
                    'undo',
                    'unfold-less',
                    'unfold-more',
                    'upload',
                    'usb',
                    'vibration',
                    'videocam',
                    'videocam-off',
                    'videocam-switch',
                    'view-agenda',
                    'view-array',
                    'view-carousel',
                    'view-column',
                    'view-comfy',
                    'view-compact',
                    'view-dashboard',
                    'view-day',
                    'view-headline',
                    'view-list',
                    'view-list-alt',
                    'view-module',
                    'view-quilt',
                    'view-stream',
                    'view-subtitles',
                    'view-toc',
                    'view-web',
                    'view-week',
                    'vignette',
                    'vk',
                    'voicemail',
                    'volume-down',
                    'volume-mute',
                    'volume-off',
                    'volume-up',
                    'walk',
                    'wallpaper',
                    'washing-machine',
                    'watch',
                    'wb-auto',
                    'widgets',
                    'wifi',
                    'wifi-alt',
                    'wifi-alt-2',
                    'wifi-info',
                    'wifi-lock',
                    'wifi-off',
                    'wifi-outline',
                    'wikipedia',
                    'window-maximize',
                    'window-minimize',
                    'window-restore',
                    'windows',
                    'wrap-text',
                    'wrench',
                    'zero',
                    'zoom-in',
                    'zoom-out'
                ]
            },
            {
                version: '2.1.2',
                icons: [
                    '',
                    //'zmdi',
                    '3d-rotation',
                    'account',
                    'account-add',
                    'account-box',
                    'account-box-mail',
                    'account-box-o',
                    'account-box-phone',
                    'account-calendar',
                    'account-circle',
                    'account-o',
                    'accounts',
                    'accounts-add',
                    'accounts-alt',
                    'accounts-list',
                    'accounts-list-alt',
                    'accounts-outline',
                    'airline-seat-flat',
                    'airline-seat-flat-angled',
                    'airline-seat-individual-suite',
                    'airline-seat-legroom-extra',
                    'airline-seat-legroom-normal',
                    'airline-seat-legroom-reduced',
                    'airline-seat-recline-extra',
                    'airline-seat-recline-normal',
                    'airplane',
                    'airplane-off',
                    'airplay',
                    'alarm',
                    'alarm-check',
                    'alarm-off',
                    'alarm-plus',
                    'alarm-snooze',
                    'album',
                    'alert-circle',
                    'alert-circle-o',
                    'alert-octagon',
                    'alert-polygon',
                    'alert-triangle',
                    'android',
                    'android-alt',
                    'apple',
                    'apps',
                    'archive',
                    'arrow-left',
                    'arrow-left-bottom',
                    'arrow-merge',
                    'arrow-missed',
                    'arrow-right',
                    'arrow-right-top',
                    'arrow-split',
                    'arrows',
                    'aspect-ratio',
                    'aspect-ratio-alt',
                    'assignment',
                    'assignment-account',
                    'assignment-alert',
                    'assignment-check',
                    'assignment-o',
                    'assignment-return',
                    'assignment-returned',
                    'attachment',
                    'attachment-alt',
                    'audio',
                    'badge-check',
                    'balance',
                    'balance-wallet',
                    'battery',
                    'battery-alert',
                    'battery-flash',
                    'battery-unknown',
                    'behance',
                    'bike',
                    'block',
                    'block-alt',
                    'bluetooth',
                    'bluetooth-connected',
                    'bluetooth-off',
                    'bluetooth-search',
                    'bluetooth-setting',
                    'blur',
                    'blur-circular',
                    'blur-linear',
                    'blur-off',
                    'boat',
                    'book',
                    'book-image',
                    'bookmark',
                    'bookmark-outline',
                    'border-all',
                    'border-bottom',
                    'border-clear',
                    'border-color',
                    'border-horizontal',
                    'border-inner',
                    'border-left',
                    'border-outer',
                    'border-right',
                    'border-style',
                    'border-top',
                    'border-vertical',
                    'brightness-2',
                    'brightness-3',
                    'brightness-4',
                    'brightness-5',
                    'brightness-6',
                    'brightness-7',
                    'brightness-auto',
                    'brightness-high',
                    'brightness-setting',
                    'broken-image',
                    'brush',
                    'bug',
                    'bus',
                    'cake',
                    'calendar',
                    'calendar-alt',
                    'calendar-check',
                    'calendar-close',
                    'calendar-note',
                    'camera',
                    'camera-add',
                    'camera-alt',
                    'camera-bw',
                    'camera-front',
                    'camera-mic',
                    'camera-party-mode',
                    'camera-rear',
                    'camera-roll',
                    'camera-switch',
                    'car',
                    'car-taxi',
                    'car-wash',
                    'card',
                    'card-alert',
                    'card-giftcard',
                    'card-membership',
                    'card-off',
                    'card-sd',
                    'card-sim',
                    'card-travel',
                    'caret-down',
                    'caret-down-circle',
                    'caret-left',
                    'caret-left-circle',
                    'caret-right',
                    'caret-right-circle',
                    'caret-up',
                    'caret-up-circle',
                    'case',
                    'case-check',
                    'case-download',
                    'case-play',
                    'cast',
                    'cast-connected',
                    'center-focus-strong',
                    'center-focus-weak',
                    'chart',
                    'chart-donut',
                    'check',
                    'check-all',
                    'check-circle',
                    'check-circle-u',
                    'check-square',
                    'chevron-down',
                    'chevron-left',
                    'chevron-right',
                    'chevron-up',
                    'circle',
                    'circle-o',
                    'city',
                    'city-alt',
                    'close',
                    'close-circle',
                    'close-circle-o',
                    'closed-caption',
                    'cloud',
                    'cloud-box',
                    'cloud-circle',
                    'cloud-done',
                    'cloud-download',
                    'cloud-off',
                    'cloud-outline',
                    'cloud-outline-alt',
                    'cloud-upload',
                    'cocktail',
                    'code',
                    'code-setting',
                    'code-smartphone',
                    'codepen',
                    'coffee',
                    'collection-bookmark',
                    'collection-case-play',
                    'collection-folder-image',
                    'collection-image',
                    'collection-image-o',
                    'collection-item',
                    'collection-item-1',
                    'collection-item-2',
                    'collection-item-3',
                    'collection-item-4',
                    'collection-item-5',
                    'collection-item-6',
                    'collection-item-7',
                    'collection-item-8',
                    'collection-item-9',
                    'collection-item-9-plus',
                    'collection-music',
                    'collection-pdf',
                    'collection-plus',
                    'collection-speaker',
                    'collection-text',
                    'collection-video',
                    'comment',
                    'comment-alert',
                    'comment-alt',
                    'comment-alt-text',
                    'comment-edit',
                    'comment-image',
                    'comment-list',
                    'comment-more',
                    'comment-outline',
                    'comment-text',
                    'comment-text-alt',
                    'comment-video',
                    'comments',
                    'compare',
                    'compass',
                    'confirmation-number',
                    'copy',
                    'crop',
                    'crop-16-9',
                    'crop-3-2',
                    'crop-5-4',
                    'crop-7-5',
                    'crop-din',
                    'crop-free',
                    'crop-landscape',
                    'crop-portrait',
                    'crop-square',
                    'cutlery',
                    'delete',
                    'desktop-mac',
                    'desktop-windows',
                    'developer-board',
                    'device-hub',
                    'devices',
                    'devices-off',
                    'dialpad',
                    'directions',
                    'directions-bike',
                    'directions-boat',
                    'directions-bus',
                    'directions-car',
                    'directions-railway',
                    'directions-run',
                    'directions-subway',
                    'directions-walk',
                    'disc-full',
                    'dns',
                    'dock',
                    'dot-circle',
                    'dot-circle-alt',
                    'download',
                    'dribbble',
                    'drink',
                    'dropbox',
                    'edit',
                    'eject',
                    'eject-alt',
                    'email',
                    'email-open',
                    'equalizer',
                    'evernote',
                    'explicit',
                    'exposure',
                    'exposure-alt',
                    'eye',
                    'eye-off',
                    'eyedropper',
                    'face',
                    'facebook',
                    'facebook-box',
                    'fast-forward',
                    'fast-rewind',
                    'favorite',
                    'favorite-outline',
                    'female',
                    'file',
                    'file-plus',
                    'file-text',
                    'filter-b-and-w',
                    'filter-center-focus',
                    'filter-frames',
                    'filter-list',
                    'filter-tilt-shift',
                    'fire',
                    'flag',
                    'flare',
                    'flash',
                    'flash-auto',
                    'flash-off',
                    'flight-land',
                    'flight-takeoff',
                    'flip',
                    'flip-to-back',
                    'flip-to-front',
                    'floppy',
                    'flower',
                    'flower-alt',
                    'folder',
                    'folder-outline',
                    'folder-person',
                    'folder-star',
                    'folder-star-alt',
                    'font',
                    'format-align-center',
                    'format-align-justify',
                    'format-align-left',
                    'format-align-right',
                    'format-bold',
                    'format-clear',
                    'format-clear-all',
                    'format-color-fill',
                    'format-color-reset',
                    'format-color-text',
                    'format-indent-decrease',
                    'format-indent-increase',
                    'format-italic',
                    'format-line-spacing',
                    'format-list-bulleted',
                    'format-list-numbered',
                    'format-ltr',
                    'format-rtl',
                    'format-size',
                    'format-strikethrough',
                    'format-strikethrough-s',
                    'format-subject',
                    'format-underlined',
                    'format-valign-bottom',
                    'format-valign-center',
                    'format-valign-top',
                    'forward',
                    'forward-10',
                    'forward-30',
                    'forward-5',
                    'fullscreen',
                    'fullscreen-alt',
                    'fullscreen-exit',
                    'functions',
                    'gamepad',
                    'gas-station',
                    'gesture',
                    'gif',
                    'github',
                    'github-box',
                    'globe',
                    'globe-alt',
                    'globe-lock',
                    'google',
                    'google-drive',
                    'google-earth',
                    'google-glass',
                    'google-maps',
                    'google-pages',
                    'google-play',
                    'google-plus',
                    'google-plus-box',
                    'gps',
                    'gps-dot',
                    'gps-off',
                    'gradient',
                    'graduation-cap',
                    'grain',
                    'graphic-eq',
                    'grid',
                    'grid-off',
                    'group-work',
                    'hd',
                    'hdr',
                    'hdr-off',
                    'hdr-strong',
                    'hdr-weak',
                    'headset',
                    'headset-mic',
                    'hearing',
                    'help',
                    'help-outline',
                    'home',
                    'hospital',
                    'hospital-alt',
                    'hotel',
                    'hourglass',
                    'hourglass-alt',
                    'hourglass-outline',
                    'hq',
                    'http',
                    'image',
                    'image-alt',
                    'image-o',
                    'inbox',
                    'info',
                    'info-outline',
                    'input-antenna',
                    'input-composite',
                    'input-hdmi',
                    'input-power',
                    'input-svideo',
                    'instagram',
                    'invert-colors',
                    'invert-colors-off',
                    'iridescent',
                    'key',
                    'keyboard',
                    'keyboard-hide',
                    'label',
                    'label-alt',
                    'label-alt-outline',
                    'label-heart',
                    'labels',
                    'lamp',
                    'landscape',
                    'language-css3',
                    'language-html5',
                    'language-javascript',
                    'language-python',
                    'language-python-alt',
                    'laptop',
                    'laptop-chromebook',
                    'laptop-mac',
                    'lastfm',
                    'layers',
                    'layers-off',
                    'leak',
                    'leak-off',
                    'library',
                    'link',
                    'linkedin-box',
                    'local-activity',
                    'local-airport',
                    'local-atm',
                    'local-bar',
                    'local-cafe',
                    'local-car-wash',
                    'local-convenience-store',
                    'local-dining',
                    'local-drink',
                    'local-florist',
                    'local-gas-station',
                    'local-grocery-store',
                    'local-hospital',
                    'local-hotel',
                    'local-laundry-service',
                    'local-library',
                    'local-mall',
                    'local-movies',
                    'local-offer',
                    'local-parking',
                    'local-pharmacy',
                    'local-phone',
                    'local-pizza',
                    'local-post-office',
                    'local-printshop',
                    'local-see',
                    'local-shipping',
                    'local-store',
                    'local-taxi',
                    'local-wc',
                    'lock',
                    'lock-open',
                    'lock-outline',
                    'long-arrow-down',
                    'long-arrow-left',
                    'long-arrow-return',
                    'long-arrow-right',
                    'long-arrow-tab',
                    'long-arrow-up',
                    'looks',
                    'loupe',
                    'mail-reply',
                    'mail-reply-all',
                    'mail-send',
                    'male',
                    'male-alt',
                    'male-female',
                    'mall',
                    'map',
                    'markunread-mailbox',
                    'memory',
                    'menu',
                    'mic',
                    'mic-off',
                    'mic-outline',
                    'mic-setting',
                    'minus',
                    'minus-circle',
                    'minus-circle-outline',
                    'minus-square',
                    'money',
                    'money-box',
                    'money-off',
                    'mood',
                    'mood-bad',
                    'more',
                    'more-vert',
                    'mouse',
                    'movie',
                    'movie-alt',
                    'my-location',
                    'n-1-square',
                    'n-2-square',
                    'n-3-square',
                    'n-4-square',
                    'n-5-square',
                    'n-6-square',
                    'nature',
                    'nature-people',
                    'navigation',
                    'neg-1',
                    'neg-2',
                    'network',
                    'network-alert',
                    'network-locked',
                    'network-off',
                    'network-outline',
                    'network-setting',
                    'nfc',
                    'notifications',
                    'notifications-active',
                    'notifications-add',
                    'notifications-none',
                    'notifications-off',
                    'notifications-paused',
                    'open-in-browser',
                    'open-in-new',
                    'palette',
                    'panorama-horizontal',
                    'panorama-vertical',
                    'panorama-wide-angle',
                    'parking',
                    'pause',
                    'pause-circle',
                    'pause-circle-outline',
                    'paypal',
                    'phone',
                    'phone-bluetooth',
                    'phone-end',
                    'phone-forwarded',
                    'phone-in-talk',
                    'phone-locked',
                    'phone-missed',
                    'phone-msg',
                    'phone-paused',
                    'phone-ring',
                    'phone-setting',
                    'phone-sip',
                    'photo-size-select-large',
                    'photo-size-select-small',
                    'picture-in-picture',
                    'pin',
                    'pin-account',
                    'pin-assistant',
                    'pin-drop',
                    'pin-help',
                    'pin-off',
                    'pinterest-box',
                    'pizza',
                    'plaster',
                    'play',
                    'play-circle',
                    'play-circle-outline',
                    'play-for-work',
                    'playlist-audio',
                    'playlist-plus',
                    'plus',
                    'plus-1',
                    'plus-2',
                    'plus-circle',
                    'plus-circle-o',
                    'plus-circle-o-duplicate',
                    'plus-square',
                    'pocket',
                    'polymer',
                    'portable-wifi',
                    'portable-wifi-changes',
                    'portable-wifi-off',
                    'power',
                    'power-input',
                    'power-setting',
                    'present-to-all',
                    'print',
                    'puzzle-piece',
                    'quote',
                    'radio',
                    'railway',
                    'reader',
                    'receipt',
                    'redo',
                    'refresh',
                    'refresh-alt',
                    'refresh-sync',
                    'refresh-sync-alert',
                    'refresh-sync-off',
                    'remote-control',
                    'remote-control-alt',
                    'repeat',
                    'repeat-one',
                    'replay',
                    'replay-10',
                    'replay-30',
                    'replay-5',
                    'roller',
                    'rotate-ccw',
                    'rotate-cw',
                    'rotate-left',
                    'rotate-right',
                    'router',
                    'ruler',
                    'run',
                    'satellite',
                    'scanner',
                    'scissors',
                    'screen-rotation',
                    'screen-rotation-lock',
                    'search',
                    'search-for',
                    'search-in-file',
                    'search-in-page',
                    'search-replace',
                    'seat',
                    'sec-10',
                    'sec-3',
                    'select-all',
                    'settings',
                    'settings-square',
                    'share',
                    'shield-check',
                    'shield-security',
                    'shopping-basket',
                    'shopping-cart',
                    'shopping-cart-plus',
                    'shuffle',
                    'sign-in',
                    'skip-next',
                    'skip-previous',
                    'slideshow',
                    'smartphone',
                    'smartphone-android',
                    'smartphone-download',
                    'smartphone-erase',
                    'smartphone-info',
                    'smartphone-iphone',
                    'smartphone-landscape',
                    'smartphone-landscape-lock',
                    'smartphone-lock',
                    'smartphone-portrait-lock',
                    'smartphone-ring',
                    'smartphone-setting',
                    'smartphone-setup',
                    'sort-amount-asc',
                    'sort-amount-desc',
                    'sort-asc',
                    'sort-desc',
                    'space-bar',
                    'speaker',
                    'spellcheck',
                    'square-down',
                    'square-o',
                    'square-right',
                    'star',
                    'star-circle',
                    'star-half',
                    'star-outline',
                    'steam',
                    'steam-square',
                    'stop',
                    'storage',
                    'store',
                    'store-24',
                    'subway',
                    'sun',
                    'surround-sound',
                    'swap',
                    'swap-alt',
                    'swap-vertical',
                    'swap-vertical-circle',
                    'tab',
                    'tab-unselected',
                    'tablet',
                    'tablet-android',
                    'tablet-mac',
                    'tag',
                    'tag-close',
                    'tag-more',
                    'tap-and-play',
                    'text-format',
                    'texture',
                    'thumb-down',
                    'thumb-up',
                    'thumb-up-down',
                    'ticket-star',
                    'time',
                    'time-countdown',
                    'time-interval',
                    'time-restore',
                    'time-restore-setting',
                    'timer',
                    'timer-off',
                    'toll',
                    'tonality',
                    'toys',
                    'traffic',
                    'transform',
                    'translate',
                    'trending-down',
                    'trending-flat',
                    'trending-up',
                    'triangle-down',
                    'triangle-up',
                    'truck',
                    'tune',
                    'turning-sign',
                    'tv',
                    'tv-alt-play',
                    'tv-list',
                    'tv-play',
                    'twitter',
                    'twitter-box',
                    'undo',
                    'unfold-less',
                    'unfold-more',
                    'upload',
                    'usb',
                    'vibration',
                    'videocam',
                    'videocam-off',
                    'videocam-switch',
                    'view-agenda',
                    'view-array',
                    'view-carousel',
                    'view-column',
                    'view-comfy',
                    'view-compact',
                    'view-dashboard',
                    'view-day',
                    'view-headline',
                    'view-list',
                    'view-list-alt',
                    'view-module',
                    'view-quilt',
                    'view-stream',
                    'view-subtitles',
                    'view-toc',
                    'view-web',
                    'view-week',
                    'vignette',
                    'vk',
                    'voicemail',
                    'volume-down',
                    'volume-mute',
                    'volume-off',
                    'volume-up',
                    'walk',
                    'wallpaper',
                    'washing-machine',
                    'watch',
                    'wb-auto',
                    'widgets',
                    'wifi',
                    'wifi-alt',
                    'wifi-alt-2',
                    'wifi-info',
                    'wifi-lock',
                    'wifi-off',
                    'wifi-outline',
                    'wikipedia',
                    'window-maximize',
                    'window-minimize',
                    'window-restore',
                    'windows',
                    'wrap-text',
                    'wrench',
                    'zero',
                    'zoom-in',
                    'zoom-out'
                ]
            },
            {
                version: '2.2.0',
                icons: [
                    '',
                    //'zmdi',
                    '3d-rotation',
                    '500px',
                    '8tracks',
                    'account',
                    'account-add',
                    'account-box',
                    'account-box-mail',
                    'account-box-o',
                    'account-box-phone',
                    'account-calendar',
                    'account-circle',
                    'account-o',
                    'accounts',
                    'accounts-add',
                    'accounts-alt',
                    'accounts-list',
                    'accounts-list-alt',
                    'accounts-outline',
                    'airline-seat-flat',
                    'airline-seat-flat-angled',
                    'airline-seat-individual-suite',
                    'airline-seat-legroom-extra',
                    'airline-seat-legroom-normal',
                    'airline-seat-legroom-reduced',
                    'airline-seat-recline-extra',
                    'airline-seat-recline-normal',
                    'airplane',
                    'airplane-off',
                    'airplay',
                    'alarm',
                    'alarm-check',
                    'alarm-off',
                    'alarm-plus',
                    'alarm-snooze',
                    'album',
                    'alert-circle',
                    'alert-circle-o',
                    'alert-octagon',
                    'alert-polygon',
                    'alert-triangle',
                    'amazon',
                    'android',
                    'android-alt',
                    'apple',
                    'apps',
                    'archive',
                    'arrow-left',
                    'arrow-left-bottom',
                    'arrow-merge',
                    'arrow-missed',
                    'arrow-right',
                    'arrow-right-top',
                    'arrow-split',
                    'arrows',
                    'aspect-ratio',
                    'aspect-ratio-alt',
                    'assignment',
                    'assignment-account',
                    'assignment-alert',
                    'assignment-check',
                    'assignment-o',
                    'assignment-return',
                    'assignment-returned',
                    'attachment',
                    'attachment-alt',
                    'audio',
                    'badge-check',
                    'balance',
                    'balance-wallet',
                    'battery',
                    'battery-alert',
                    'battery-flash',
                    'battery-unknown',
                    'behance',
                    'bike',
                    'block',
                    'block-alt',
                    'blogger',
                    'bluetooth',
                    'bluetooth-connected',
                    'bluetooth-off',
                    'bluetooth-search',
                    'bluetooth-setting',
                    'blur',
                    'blur-circular',
                    'blur-linear',
                    'blur-off',
                    'boat',
                    'book',
                    'book-image',
                    'bookmark',
                    'bookmark-outline',
                    'border-all',
                    'border-bottom',
                    'border-clear',
                    'border-color',
                    'border-horizontal',
                    'border-inner',
                    'border-left',
                    'border-outer',
                    'border-right',
                    'border-style',
                    'border-top',
                    'border-vertical',
                    'brightness-2',
                    'brightness-3',
                    'brightness-4',
                    'brightness-5',
                    'brightness-6',
                    'brightness-7',
                    'brightness-auto',
                    'brightness-high',
                    'brightness-setting',
                    'broken-image',
                    'brush',
                    'bug',
                    'bus',
                    'cake',
                    'calendar',
                    'calendar-alt',
                    'calendar-check',
                    'calendar-close',
                    'calendar-note',
                    'camera',
                    'camera-add',
                    'camera-alt',
                    'camera-bw',
                    'camera-front',
                    'camera-mic',
                    'camera-party-mode',
                    'camera-rear',
                    'camera-roll',
                    'camera-switch',
                    'car',
                    'car-taxi',
                    'car-wash',
                    'card',
                    'card-alert',
                    'card-giftcard',
                    'card-membership',
                    'card-off',
                    'card-sd',
                    'card-sim',
                    'card-travel',
                    'caret-down',
                    'caret-down-circle',
                    'caret-left',
                    'caret-left-circle',
                    'caret-right',
                    'caret-right-circle',
                    'caret-up',
                    'caret-up-circle',
                    'case',
                    'case-check',
                    'case-download',
                    'case-play',
                    'cast',
                    'cast-connected',
                    'center-focus-strong',
                    'center-focus-weak',
                    'chart',
                    'chart-donut',
                    'check',
                    'check-all',
                    'check-circle',
                    'check-circle-u',
                    'check-square',
                    'chevron-down',
                    'chevron-left',
                    'chevron-right',
                    'chevron-up',
                    'circle',
                    'circle-o',
                    'city',
                    'city-alt',
                    'close',
                    'close-circle',
                    'close-circle-o',
                    'closed-caption',
                    'cloud',
                    'cloud-box',
                    'cloud-circle',
                    'cloud-done',
                    'cloud-download',
                    'cloud-off',
                    'cloud-outline',
                    'cloud-outline-alt',
                    'cloud-upload',
                    'cocktail',
                    'code',
                    'code-setting',
                    'code-smartphone',
                    'codepen',
                    'coffee',
                    'collection-bookmark',
                    'collection-case-play',
                    'collection-folder-image',
                    'collection-image',
                    'collection-image-o',
                    'collection-item',
                    'collection-item-1',
                    'collection-item-2',
                    'collection-item-3',
                    'collection-item-4',
                    'collection-item-5',
                    'collection-item-6',
                    'collection-item-7',
                    'collection-item-8',
                    'collection-item-9',
                    'collection-item-9-plus',
                    'collection-music',
                    'collection-pdf',
                    'collection-plus',
                    'collection-speaker',
                    'collection-text',
                    'collection-video',
                    'comment',
                    'comment-alert',
                    'comment-alt',
                    'comment-alt-text',
                    'comment-edit',
                    'comment-image',
                    'comment-list',
                    'comment-more',
                    'comment-outline',
                    'comment-text',
                    'comment-text-alt',
                    'comment-video',
                    'comments',
                    'compare',
                    'compass',
                    'confirmation-number',
                    'copy',
                    'crop',
                    'crop-16-9',
                    'crop-3-2',
                    'crop-5-4',
                    'crop-7-5',
                    'crop-din',
                    'crop-free',
                    'crop-landscape',
                    'crop-portrait',
                    'crop-square',
                    'cutlery',
                    'delete',
                    'delicious',
                    'desktop-mac',
                    'desktop-windows',
                    'developer-board',
                    'device-hub',
                    'devices',
                    'devices-off',
                    'dialpad',
                    'directions',
                    'directions-bike',
                    'directions-boat',
                    'directions-bus',
                    'directions-car',
                    'directions-railway',
                    'directions-run',
                    'directions-subway',
                    'directions-walk',
                    'disc-full',
                    'disqus',
                    'dns',
                    'dock',
                    'dot-circle',
                    'dot-circle-alt',
                    'download',
                    'dribbble',
                    'drink',
                    'dropbox',
                    'edit',
                    'eject',
                    'eject-alt',
                    'email',
                    'email-open',
                    'equalizer',
                    'evernote',
                    'explicit',
                    'exposure',
                    'exposure-alt',
                    'eye',
                    'eye-off',
                    'eyedropper',
                    'face',
                    'facebook',
                    'facebook-box',
                    'fast-forward',
                    'fast-rewind',
                    'favorite',
                    'favorite-outline',
                    'female',
                    'file',
                    'file-plus',
                    'file-text',
                    'filter-b-and-w',
                    'filter-center-focus',
                    'filter-frames',
                    'filter-list',
                    'filter-tilt-shift',
                    'fire',
                    'flag',
                    'flare',
                    'flash',
                    'flash-auto',
                    'flash-off',
                    'flattr',
                    'flickr',
                    'flight-land',
                    'flight-takeoff',
                    'flip',
                    'flip-to-back',
                    'flip-to-front',
                    'floppy',
                    'flower',
                    'flower-alt',
                    'folder',
                    'folder-outline',
                    'folder-person',
                    'folder-star',
                    'folder-star-alt',
                    'font',
                    'format-align-center',
                    'format-align-justify',
                    'format-align-left',
                    'format-align-right',
                    'format-bold',
                    'format-clear',
                    'format-clear-all',
                    'format-color-fill',
                    'format-color-reset',
                    'format-color-text',
                    'format-indent-decrease',
                    'format-indent-increase',
                    'format-italic',
                    'format-line-spacing',
                    'format-list-bulleted',
                    'format-list-numbered',
                    'format-ltr',
                    'format-rtl',
                    'format-size',
                    'format-strikethrough',
                    'format-strikethrough-s',
                    'format-subject',
                    'format-underlined',
                    'format-valign-bottom',
                    'format-valign-center',
                    'format-valign-top',
                    'forward',
                    'forward-10',
                    'forward-30',
                    'forward-5',
                    'fullscreen',
                    'fullscreen-alt',
                    'fullscreen-exit',
                    'functions',
                    'gamepad',
                    'gas-station',
                    'gesture',
                    'gif',
                    'github',
                    'github-alt',
                    'github-box',
                    'globe',
                    'globe-alt',
                    'globe-lock',
                    'google',
                    'google-drive',
                    'google-earth',
                    'google-glass',
                    'google-maps',
                    'google-old',
                    'google-pages',
                    'google-play',
                    'google-plus',
                    'google-plus-box',
                    'gps',
                    'gps-dot',
                    'gps-off',
                    'gradient',
                    'graduation-cap',
                    'grain',
                    'graphic-eq',
                    'grid',
                    'grid-off',
                    'group',
                    'group-work',
                    'hd',
                    'hdr',
                    'hdr-off',
                    'hdr-strong',
                    'hdr-weak',
                    'headset',
                    'headset-mic',
                    'hearing',
                    'help',
                    'help-outline',
                    'home',
                    'hospital',
                    'hospital-alt',
                    'hotel',
                    'hourglass',
                    'hourglass-alt',
                    'hourglass-outline',
                    'hq',
                    'http',
                    'image',
                    'image-alt',
                    'image-o',
                    'inbox',
                    'info',
                    'info-outline',
                    'input-antenna',
                    'input-composite',
                    'input-hdmi',
                    'input-power',
                    'input-svideo',
                    'instagram',
                    'invert-colors',
                    'invert-colors-off',
                    'iridescent',
                    'key',
                    'keyboard',
                    'keyboard-hide',
                    'label',
                    'label-alt',
                    'label-alt-outline',
                    'label-heart',
                    'labels',
                    'lamp',
                    'landscape',
                    'language-css3',
                    'language-html5',
                    'language-javascript',
                    'language-python',
                    'language-python-alt',
                    'laptop',
                    'laptop-chromebook',
                    'laptop-mac',
                    'lastfm',
                    'layers',
                    'layers-off',
                    'leak',
                    'leak-off',
                    'library',
                    'link',
                    'linkedin',
                    'linkedin-box',
                    'local-activity',
                    'local-airport',
                    'local-atm',
                    'local-bar',
                    'local-cafe',
                    'local-car-wash',
                    'local-convenience-store',
                    'local-dining',
                    'local-drink',
                    'local-florist',
                    'local-gas-station',
                    'local-grocery-store',
                    'local-hospital',
                    'local-hotel',
                    'local-laundry-service',
                    'local-library',
                    'local-mall',
                    'local-movies',
                    'local-offer',
                    'local-parking',
                    'local-pharmacy',
                    'local-phone',
                    'local-pizza',
                    'local-post-office',
                    'local-printshop',
                    'local-see',
                    'local-shipping',
                    'local-store',
                    'local-taxi',
                    'local-wc',
                    'lock',
                    'lock-open',
                    'lock-outline',
                    'long-arrow-down',
                    'long-arrow-left',
                    'long-arrow-return',
                    'long-arrow-right',
                    'long-arrow-tab',
                    'long-arrow-up',
                    'looks',
                    'loupe',
                    'mail-reply',
                    'mail-reply-all',
                    'mail-send',
                    'male',
                    'male-alt',
                    'male-female',
                    'mall',
                    'map',
                    'markunread-mailbox',
                    'memory',
                    'menu',
                    'mic',
                    'mic-off',
                    'mic-outline',
                    'mic-setting',
                    'minus',
                    'minus-circle',
                    'minus-circle-outline',
                    'minus-square',
                    'money',
                    'money-box',
                    'money-off',
                    'mood',
                    'mood-bad',
                    'more',
                    'more-vert',
                    'mouse',
                    'movie',
                    'movie-alt',
                    'my-location',
                    'n-1-square',
                    'n-2-square',
                    'n-3-square',
                    'n-4-square',
                    'n-5-square',
                    'n-6-square',
                    'nature',
                    'nature-people',
                    'navigation',
                    'neg-1',
                    'neg-2',
                    'network',
                    'network-alert',
                    'network-locked',
                    'network-off',
                    'network-outline',
                    'network-setting',
                    'nfc',
                    'notifications',
                    'notifications-active',
                    'notifications-add',
                    'notifications-none',
                    'notifications-off',
                    'notifications-paused',
                    'odnoklassniki',
                    'open-in-browser',
                    'open-in-new',
                    'outlook',
                    'palette',
                    'panorama-horizontal',
                    'panorama-vertical',
                    'panorama-wide-angle',
                    'parking',
                    'pause',
                    'pause-circle',
                    'pause-circle-outline',
                    'paypal',
                    'paypal-alt',
                    'phone',
                    'phone-bluetooth',
                    'phone-end',
                    'phone-forwarded',
                    'phone-in-talk',
                    'phone-locked',
                    'phone-missed',
                    'phone-msg',
                    'phone-paused',
                    'phone-ring',
                    'phone-setting',
                    'phone-sip',
                    'photo-size-select-large',
                    'photo-size-select-small',
                    'picture-in-picture',
                    'pin',
                    'pin-account',
                    'pin-assistant',
                    'pin-drop',
                    'pin-help',
                    'pin-off',
                    'pinterest',
                    'pinterest-box',
                    'pizza',
                    'plaster',
                    'play',
                    'play-circle',
                    'play-circle-outline',
                    'play-for-work',
                    'playlist-audio',
                    'playlist-plus',
                    'playstation',
                    'plus',
                    'plus-1',
                    'plus-2',
                    'plus-circle',
                    'plus-circle-o',
                    'plus-circle-o-duplicate',
                    'plus-square',
                    'pocket',
                    'polymer',
                    'portable-wifi',
                    'portable-wifi-changes',
                    'portable-wifi-off',
                    'power',
                    'power-input',
                    'power-setting',
                    'present-to-all',
                    'print',
                    'puzzle-piece',
                    'quote',
                    'radio',
                    'railway',
                    'reader',
                    'receipt',
                    'reddit',
                    'redo',
                    'refresh',
                    'refresh-alt',
                    'refresh-sync',
                    'refresh-sync-alert',
                    'refresh-sync-off',
                    'remote-control',
                    'remote-control-alt',
                    'repeat',
                    'repeat-one',
                    'replay',
                    'replay-10',
                    'replay-30',
                    'replay-5',
                    'roller',
                    'rotate-ccw',
                    'rotate-cw',
                    'rotate-left',
                    'rotate-right',
                    'router',
                    'rss',
                    'ruler',
                    'run',
                    'satellite',
                    'scanner',
                    'scissors',
                    'screen-rotation',
                    'screen-rotation-lock',
                    'search',
                    'search-for',
                    'search-in-file',
                    'search-in-page',
                    'search-replace',
                    'seat',
                    'sec-10',
                    'sec-3',
                    'select-all',
                    'settings',
                    'settings-square',
                    'shape',
                    'share',
                    'shield-check',
                    'shield-security',
                    'shopping-basket',
                    'shopping-cart',
                    'shopping-cart-plus',
                    'shuffle',
                    'sign-in',
                    'skip-next',
                    'skip-previous',
                    'skype',
                    'slideshare',
                    'slideshow',
                    'smartphone',
                    'smartphone-android',
                    'smartphone-download',
                    'smartphone-erase',
                    'smartphone-info',
                    'smartphone-iphone',
                    'smartphone-landscape',
                    'smartphone-landscape-lock',
                    'smartphone-lock',
                    'smartphone-portrait-lock',
                    'smartphone-ring',
                    'smartphone-setting',
                    'smartphone-setup',
                    'sort-amount-asc',
                    'sort-amount-desc',
                    'sort-asc',
                    'sort-desc',
                    'soundcloud',
                    'space-bar',
                    'speaker',
                    'spellcheck',
                    'spinner',
                    'square-down',
                    'square-o',
                    'square-right',
                    'stackoverflow',
                    'star',
                    'star-circle',
                    'star-half',
                    'star-outline',
                    'steam',
                    'steam-square',
                    'stop',
                    'storage',
                    'store',
                    'store-24',
                    'subway',
                    'sun',
                    'surround-sound',
                    'swap',
                    'swap-alt',
                    'swap-vertical',
                    'swap-vertical-circle',
                    'tab',
                    'tab-unselected',
                    'tablet',
                    'tablet-android',
                    'tablet-mac',
                    'tag',
                    'tag-close',
                    'tag-more',
                    'tap-and-play',
                    'text-format',
                    'texture',
                    'thumb-down',
                    'thumb-up',
                    'thumb-up-down',
                    'ticket-star',
                    'time',
                    'time-countdown',
                    'time-interval',
                    'time-restore',
                    'time-restore-setting',
                    'timer',
                    'timer-off',
                    'toll',
                    'tonality',
                    'toys',
                    'traffic',
                    'transform',
                    'translate',
                    'trending-down',
                    'trending-flat',
                    'trending-up',
                    'triangle-down',
                    'triangle-up',
                    'truck',
                    'tumblr',
                    'tune',
                    'turning-sign',
                    'tv',
                    'tv-alt-play',
                    'tv-list',
                    'tv-play',
                    'twitch',
                    'twitter',
                    'twitter-box',
                    'undo',
                    'unfold-less',
                    'unfold-more',
                    'ungroup',
                    'upload',
                    'usb',
                    'vibration',
                    'videocam',
                    'videocam-off',
                    'videocam-switch',
                    'view-agenda',
                    'view-array',
                    'view-carousel',
                    'view-column',
                    'view-comfy',
                    'view-compact',
                    'view-dashboard',
                    'view-day',
                    'view-headline',
                    'view-list',
                    'view-list-alt',
                    'view-module',
                    'view-quilt',
                    'view-stream',
                    'view-subtitles',
                    'view-toc',
                    'view-web',
                    'view-week',
                    'vignette',
                    'vimeo',
                    'vk',
                    'voicemail',
                    'volume-down',
                    'volume-mute',
                    'volume-off',
                    'volume-up',
                    'walk',
                    'wallpaper',
                    'washing-machine',
                    'watch',
                    'wb-auto',
                    'whatsapp',
                    'widgets',
                    'wifi',
                    'wifi-alt',
                    'wifi-alt-2',
                    'wifi-info',
                    'wifi-lock',
                    'wifi-off',
                    'wifi-outline',
                    'wikipedia',
                    'window-maximize',
                    'window-minimize',
                    'window-restore',
                    'windows',
                    'wrap-text',
                    'wrench',
                    'xbox',
                    'yahoo',
                    'youtube',
                    'youtube-play',
                    'zero',
                    'zoom-in',
                    'zoom-out'
                ]
            }
        ]
    };

    var l = data.allVersions.length;
    data.icons = data.allVersions[l-1].icons;

    $.iconset_materialdesign = data;

})(jQuery);
