@charset "UTF-8";.popover{position:absolute;top:0;left:0;z-index:1060;display:none;padding:1px;font-family:"Helvetica Neue",Helvetica,Arial,sans-serif;font-size:14px;font-style:normal;font-weight:400;line-height:1.42857143;text-align:left;text-align:start;text-decoration:none;text-shadow:none;text-transform:none;letter-spacing:normal;word-break:normal;word-spacing:normal;word-wrap:normal;white-space:normal;background-color:#fff;background-clip:padding-box;border:1px solid #ccc;border:1px solid rgba(0,0,0,.2);border-radius:6px;box-shadow:0 5px 10px rgba(0,0,0,.2);line-break:auto}.popover.top{margin-top:-10px}.popover.right{margin-left:10px}.popover.bottom{margin-top:10px}.popover.left{margin-left:-10px}.popover-title{padding:8px 14px;margin:0;font-size:14px;background-color:#f7f7f7;border-bottom:1px solid #ebebeb;border-radius:5px 5px 0 0}.popover-content{padding:9px 14px}.popover>.arrow,.popover>.arrow:after{position:absolute;display:block;width:0;height:0;border-color:transparent;border-style:solid}.popover>.arrow{border-width:11px}.popover>.arrow:after{content:"";border-width:10px}.popover.top>.arrow{bottom:-11px;left:50%;margin-left:-11px;border-top-color:#999;border-top-color:rgba(0,0,0,.25);border-bottom-width:0}.popover.top>.arrow:after{bottom:1px;margin-left:-10px;content:" ";border-top-color:#fff;border-bottom-width:0}.popover.right>.arrow{top:50%;left:-11px;margin-top:-11px;border-right-color:#999;border-right-color:rgba(0,0,0,.25);border-left-width:0}.popover.right>.arrow:after{bottom:-10px;left:1px;content:" ";border-right-color:#fff;border-left-width:0}.popover.bottom>.arrow{top:-11px;left:50%;margin-left:-11px;border-top-width:0;border-bottom-color:#999;border-bottom-color:rgba(0,0,0,.25)}.popover.bottom>.arrow:after{top:1px;margin-left:-10px;content:" ";border-top-width:0;border-bottom-color:#fff}.popover.left>.arrow{top:50%;right:-11px;margin-top:-11px;border-right-width:0;border-left-color:#999;border-left-color:rgba(0,0,0,.25)}.popover.left>.arrow:after{right:1px;bottom:-10px;content:" ";border-right-width:0;border-left-color:#fff}.djangocms-icon .caret{display:inline-block;width:0;height:0;margin-left:2px;border-top:4px dashed;border-right:4px solid transparent;border-left:4px solid transparent}.djangocms-icon .icon-widgets{display:-ms-flexbox;display:flex;-ms-flex-align:center;align-items:center}.djangocms-icon .icon-widgets label{display:inline!important}.djangocms-icon .icon-widgets .form-control{padding-right:30px}.djangocms-icon .icon-widgets .iconpicker i{padding-right:5px}.djangocms-icon select{margin:0;vertical-align:top}.djangocms-icon select.form-control{width:auto!important}.djangocms-icon button.iconpicker{height:36px;font-size:20px!important;padding-right:10px!important;padding-left:10px!important;display:-ms-inline-flexbox;display:inline-flex;-ms-flex-align:center;align-items:center}.djangocms-icon-left:before{content:'←'}.djangocms-icon-right:before{content:'→'}.field-icon_left{min-width:300px}.iconpicker-popover .form-control{line-height:34px;height:34px}.iconpicker-popover .text-center{text-align:center}.iconpicker-popover .search-control{margin-top:10px;margin-bottom:10px}.iconpicker-popover .form-control{display:block;width:100%;height:34px;padding:6px 12px;font-size:14px;line-height:1.42857143;color:#555;background-color:#fff;background-image:none;border:1px solid #ccc;border-radius:4px;box-shadow:inset 0 1px 1px rgba(0,0,0,.075);transition:border-color ease-in-out .15s,box-shadow ease-in-out .15s}.iconpicker-popover .btn{display:inline-block;padding:6px 12px;margin-bottom:0;font-size:14px;font-weight:400;line-height:1.42857143;text-align:center;white-space:nowrap;vertical-align:middle;-ms-touch-action:manipulation;touch-action:manipulation;cursor:pointer;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none;background-image:none;border:1px solid transparent;border-radius:4px}.iconpicker-popover .search-control{width:100%!important}.iconpicker-popover table tfoot tr td{padding-top:10px;border-top:0;background:0 0}.iconpicker-popover .page-count{display:inline-block;padding-top:12px}.iconpicker-popover .fa-{width:14px}.icon[data-svg=true]:before{content:none!important}.djangocms-svg-icon{font-size:20px}.djangocms-svg-icon:before{content:none!important}.djangocms-svg-icon svg{display:inline-block;width:1em;height:1em;vertical-align:top}.table-icons .disabled{pointer-events:none!important}.table-icons .btn{width:72px!important;height:42px!important;font-size:20px!important}.table-icons .btn .icon{vertical-align:middle!important}.table-icons td{padding:2px}