/*!========================================================================
 * Iconset: Elusive Icons
 * Versions: 2.0.0
 * http://elusiveicons.com/
 * ======================================================================== */

;(function($){

    var data = {
        iconClass: '',
        iconClassFix: 'el-icon-',
        icons: [],
        allVersions: [
            {
                version: '2.0.0',
                icons: [
                    '',
                    'address-book',
                    'address-book-alt',
                    'adjust',
                    'adjust-alt',
                    'adult',
                    'align-center',
                    'align-justify',
                    'align-left',
                    'align-right',
                    'arrow-down',
                    'arrow-left',
                    'arrow-right',
                    'arrow-up',
                    'asl',
                    'asterisk',
                    'backward',
                    'ban-circle',
                    'barcode',
                    'behance',
                    'bell',
                    'blind',
                    'blogger',
                    'bold',
                    'book',
                    'bookmark',
                    'bookmark-empty',
                    'braille',
                    'briefcase',
                    'broom',
                    'brush',
                    'bulb',
                    'bullhorn',
                    'calendar',
                    'calendar-sign',
                    'camera',
                    'car',
                    'caret-down',
                    'caret-left',
                    'caret-right',
                    'caret-up',
                    'cc',
                    'certificate',
                    'check',
                    'check-empty',
                    'chevron-down',
                    'chevron-left',
                    'chevron-right',
                    'chevron-up',
                    'child',
                    'circle-arrow-down',
                    'circle-arrow-left',
                    'circle-arrow-right',
                    'circle-arrow-up',
                    'cloud',
                    'cloud-alt',
                    'cog',
                    'cog-alt',
                    'cogs',
                    'comment',
                    'comment-alt',
                    'compass',
                    'compass-alt',
                    'credit-card',
                    'css',
                    'dashboard',
                    'delicious',
                    'deviantart',
                    'digg',
                    'download',
                    'download-alt',
                    'dribbble',
                    'edit',
                    'eject',
                    'envelope',
                    'envelope-alt',
                    'error',
                    'error-alt',
                    'eur',
                    'exclamation-sign',
                    'eye-close',
                    'eye-open',
                    'facebook',
                    'facetime-video',
                    'fast-backward',
                    'fast-forward',
                    'female',
                    'file',
                    'file-alt',
                    'file-edit',
                    'file-edit-alt',
                    'file-new',
                    'file-new-alt',
                    'film',
                    'filter',
                    'fire',
                    'flag',
                    'flag-alt',
                    'flickr',
                    'folder',
                    'folder-close',
                    'folder-open',
                    'folder-sign',
                    'font',
                    'fontsize',
                    'fork',
                    'forward',
                    'forward-alt',
                    'foursquare',
                    'friendfeed',
                    'friendfeed-rect',
                    'fullscreen',
                    'gbp',
                    'gift',
                    'github',
                    'github-text',
                    'glass',
                    'glasses',
                    'globe',
                    'globe-alt',
                    'googleplus',
                    'graph',
                    'graph-alt',
                    'group',
                    'group-alt',
                    'guidedog',
                    'hand-down',
                    'hand-left',
                    'hand-right',
                    'hand-up',
                    'hdd',
                    'headphones',
                    'hearing-impaired',
                    'heart',
                    'heart-alt',
                    'heart-empty',
                    'home',
                    'home-alt',
                    'hourglass',
                    'idea',
                    'idea-alt',
                    'inbox',
                    'inbox-alt',
                    'inbox-box',
                    'indent-left',
                    'indent-right',
                    'info-sign',
                    'instagram',
                    'iphone-home',
                    'italic',
                    'key',
                    'laptop',
                    'laptop-alt',
                    'lastfm',
                    'leaf',
                    'lines',
                    'link',
                    'linkedin',
                    'list',
                    'list-alt',
                    'livejournal',
                    'lock',
                    'lock-alt',
                    'magic',
                    'magnet',
                    'male',
                    'map-marker',
                    'map-marker-alt',
                    'mic',
                    'mic-alt',
                    'minus',
                    'minus-sign',
                    'move',
                    'music',
                    'myspace',
                    'network',
                    'off',
                    'ok',
                    'ok-circle',
                    'ok-sign',
                    'opensource',
                    'paper-clip',
                    'paper-clip-alt',
                    'path',
                    'pause',
                    'pause-alt',
                    'pencil',
                    'pencil-alt',
                    'person',
                    'phone',
                    'phone-alt',
                    'photo',
                    'photo-alt',
                    'picasa',
                    'picture',
                    'pinterest',
                    'plane',
                    'play',
                    'play-alt',
                    'play-circle',
                    'plus',
                    'plus-sign',
                    'podcast',
                    'print',
                    'puzzle',
                    'qrcode',
                    'question',
                    'question-sign',
                    'quotes',
                    'quotes-alt',
                    'random',
                    'record',
                    'reddit',
                    'refresh',
                    'remove',
                    'remove-circle',
                    'remove-sign',
                    'repeat',
                    'repeat-alt',
                    'resize-full',
                    'resize-horizontal',
                    'resize-small',
                    'resize-vertical',
                    'return-key',
                    'retweet',
                    'reverse-alt',
                    'road',
                    'rss',
                    'scissors',
                    'screen',
                    'screen-alt',
                    'screenshot',
                    'search',
                    'search-alt',
                    'share',
                    'share-alt',
                    'shopping-cart',
                    'shopping-cart-sign',
                    'signal',
                    'skype',
                    'slideshare',
                    'smiley',
                    'smiley-alt',
                    'soundcloud',
                    'speaker',
                    'spotify',
                    'stackoverflow',
                    'star',
                    'star-alt',
                    'star-empty',
                    'step-backward',
                    'step-forward',
                    'stop',
                    'stop-alt',
                    'stumbleupon',
                    'tag',
                    'tags',
                    'tasks',
                    'text-height',
                    'text-width',
                    'th',
                    'th-large',
                    'th-list',
                    'thumbs-down',
                    'thumbs-up',
                    'time',
                    'time-alt',
                    'tint',
                    'torso',
                    'trash',
                    'trash-alt',
                    'tumblr',
                    'twitter',
                    'universal-access',
                    'unlock',
                    'unlock-alt',
                    'upload',
                    'usd',
                    'user',
                    'viadeo',
                    'video',
                    'video-alt',
                    'video-chat',
                    'view-mode',
                    'vimeo',
                    'vkontakte',
                    'volume-down',
                    'volume-off',
                    'volume-up',
                    'w3c',
                    'warning-sign',
                    'website',
                    'website-alt',
                    'wheelchair',
                    'wordpress',
                    'wrench',
                    'wrench-alt',
                    'youtube',
                    'zoom-in',
                    'zoom-out'
                ]
            }
        ]
    };

    var l = data.allVersions.length;
    data.icons = data.allVersions[l-1].icons;

    $.iconset_elusiveicon = data;

})(jQuery);
