/*!========================================================================
 * Iconset: Map Icons
 * Versions: 2.1.0
 * https://github.com/scottdejonge/Map-Icons
 * ======================================================================== */

;(function($){

    var data = {
        iconClass: '',
        iconClassFix: 'map-icon-',
        icons: [],
        allVersions: [
            {
                version: '2.1.0',
                icons: [
                    '',
                    'abseiling',
                    'accounting',
                    'airport',
                    'amusement-park',
                    'aquarium',
                    'archery',
                    'art-gallery',
                    'assistive-listening-system',
                    'atm',
                    'audio-description',
                    'bakery',
                    'bank',
                    'bar',
                    'baseball',
                    'beauty-salon',
                    'bicycle-store',
                    'bicycling',
                    'boat-ramp',
                    'boat-tour',
                    'boating',
                    'book-store',
                    'bowling-alley',
                    'braille',
                    'bus-station',
                    'cafe',
                    'campground',
                    'canoe',
                    'car-dealer',
                    'car-rental',
                    'car-repair',
                    'car-wash',
                    'casino',
                    'cemetery',
                    'chairlift',
                    'church',
                    'circle',
                    'city-hall',
                    'climbing',
                    'closed-captioning',
                    'clothing-store',
                    'compass',
                    'convenience-store',
                    'courthouse',
                    'cross-country-skiing',
                    'crosshairs',
                    'dentist',
                    'department-store',
                    'diving',
                    'doctor',
                    'electrician',
                    'electronics-store',
                    'embassy',
                    'expand',
                    'female',
                    'finance',
                    'fire-station',
                    'fish-cleaning',
                    'fishing',
                    'fishing-pier',
                    'florist',
                    'food',
                    'fullscreen',
                    'funeral-home',
                    'furniture-store',
                    'gas-station',
                    'general-contractor',
                    'golf',
                    'grocery-or-supermarket',
                    'gym',
                    'hair-care',
                    'hang-gliding',
                    'hardware-store',
                    'health',
                    'hindu-temple',
                    'horse-riding',
                    'hospital',
                    'ice-fishing',
                    'ice-skating',
                    'inline-skating',
                    'insurance-agency',
                    'jet-skiing',
                    'jewelry-store',
                    'kayaking',
                    'laundry',
                    'lawyer',
                    'library',
                    'liquor-store',
                    'local-government',
                    'location-arrow',
                    'locksmith',
                    'lodging',
                    'low-vision-access',
                    'male',
                    'map-pin',
                    'marina',
                    'mosque',
                    'motobike-trail',
                    'movie-rental',
                    'movie-theater',
                    'moving-company',
                    'museum',
                    'natural-feature',
                    'night-club',
                    'open-captioning',
                    'painter',
                    'park',
                    'parking',
                    'pet-store',
                    'pharmacy',
                    'physiotherapist',
                    'place-of-worship',
                    'playground',
                    'plumber',
                    'point-of-interest',
                    'police',
                    'political',
                    'post-box',
                    'post-office',
                    'postal-code',
                    'postal-code-prefix',
                    'rafting',
                    'real-estate-agency',
                    'restaurant',
                    'roofing-contractor',
                    'route',
                    'route-pin',
                    'rv-park',
                    'sailing',
                    'school',
                    'scuba-diving',
                    'search',
                    'sheild',
                    'shopping-mall',
                    'sign-language',
                    'skateboarding',
                    'ski-jumping',
                    'skiing',
                    'sledding',
                    'snow',
                    'snow-shoeing',
                    'snowboarding',
                    'snowmobile',
                    'spa',
                    'square',
                    'square-pin',
                    'square-rounded',
                    'stadium',
                    'storage',
                    'store',
                    'subway-station',
                    'surfing',
                    'swimming',
                    'synagogue',
                    'taxi-stand',
                    'tennis',
                    'toilet',
                    'trail-walking',
                    'train-station',
                    'transit-station',
                    'travel-agency',
                    'unisex',
                    'university',
                    'veterinary-care',
                    'viewing',
                    'volume-control-telephone',
                    'walking',
                    'waterskiing',
                    'whale-watching',
                    'wheelchair',
                    'wind-surfing',
                    'zoo',
                    'zoom-in',
                    'zoom-in-alt',
                    'zoom-out',
                    'zoom-out-alt'
                ]
            }
        ]
    };

    var l = data.allVersions.length;
    data.icons = data.allVersions[l-1].icons;

    $.iconset_mapicon = data;

})(jQuery);
