/*!========================================================================
 * Iconset: Font Awesome
 * Versions: 5.3.1, 5.3.1_pro
 * http://fortawesome.github.io/Font-Awesome/
 * CDN: https://use.fontawesome.com/releases/[VERSION]/css/all.css
 * ======================================================================== */

;(function($){

    var data = {
        iconClass: 'far',
        iconClassFix: 'fa-',
        icons: [],
        allVersions: [
            {
                version: '5.3.1',
                icons: [
                    '',
                    'address-book',
                    'address-card',
                    'angry',
                    'arrow-alt-circle-down',
                    'arrow-alt-circle-left',
                    'arrow-alt-circle-right',
                    'arrow-alt-circle-up',
                    'bell',
                    'bell-slash',
                    'bookmark',
                    'building',
                    'calendar',
                    'calendar-alt',
                    'calendar-check',
                    'calendar-minus',
                    'calendar-plus',
                    'calendar-times',
                    'caret-square-down',
                    'caret-square-left',
                    'caret-square-right',
                    'caret-square-up',
                    'chart-bar',
                    'check-circle',
                    'check-square',
                    'circle',
                    'clipboard',
                    'clock',
                    'clone',
                    'closed-captioning',
                    'comment',
                    'comment-alt',
                    'comment-dots',
                    'comments',
                    'compass',
                    'copy',
                    'copyright',
                    'credit-card',
                    'dizzy',
                    'dot-circle',
                    'edit',
                    'envelope',
                    'envelope-open',
                    'eye',
                    'eye-slash',
                    'file',
                    'file-alt',
                    'file-archive',
                    'file-audio',
                    'file-code',
                    'file-excel',
                    'file-image',
                    'file-pdf',
                    'file-powerpoint',
                    'file-video',
                    'file-word',
                    'flag',
                    'flushed',
                    'folder',
                    'folder-open',
                    'frown',
                    'frown-open',
                    'futbol',
                    'gem',
                    'grimace',
                    'grin',
                    'grin-alt',
                    'grin-beam',
                    'grin-beam-sweat',
                    'grin-hearts',
                    'grin-squint',
                    'grin-squint-tears',
                    'grin-stars',
                    'grin-tears',
                    'grin-tongue',
                    'grin-tongue-squint',
                    'grin-tongue-wink',
                    'grin-wink',
                    'hand-lizard',
                    'hand-paper',
                    'hand-peace',
                    'hand-point-down',
                    'hand-point-left',
                    'hand-point-right',
                    'hand-point-up',
                    'hand-pointer',
                    'hand-rock',
                    'hand-scissors',
                    'hand-spock',
                    'handshake',
                    'hdd',
                    'heart',
                    'hospital',
                    'hourglass',
                    'id-badge',
                    'id-card',
                    'image',
                    'images',
                    'keyboard',
                    'kiss',
                    'kiss-beam',
                    'kiss-wink-heart',
                    'laugh',
                    'laugh-beam',
                    'laugh-squint',
                    'laugh-wink',
                    'lemon',
                    'life-ring',
                    'lightbulb',
                    'list-alt',
                    'map',
                    'meh',
                    'meh-blank',
                    'meh-rolling-eyes',
                    'minus-square',
                    'money-bill-alt',
                    'moon',
                    'newspaper',
                    'object-group',
                    'object-ungroup',
                    'paper-plane',
                    'pause-circle',
                    'play-circle',
                    'plus-square',
                    'question-circle',
                    'registered',
                    'sad-cry',
                    'sad-tear',
                    'save',
                    'share-square',
                    'smile',
                    'smile-beam',
                    'smile-wink',
                    'snowflake',
                    'square',
                    'star',
                    'star-half',
                    'sticky-note',
                    'stop-circle',
                    'sun',
                    'surprise',
                    'thumbs-down',
                    'thumbs-up',
                    'times-circle',
                    'tired',
                    'trash-alt',
                    'user',
                    'user-circle',
                    'window-close',
                    'window-maximize',
                    'window-minimize',
                    'window-restore',
                    ]
            },
            {
                version: '5.3.1_pro',
                icons: [
                    '',
                    'abacus',
                    'ad',
                    'address-book',
                    'address-card',
                    'adjust',
                    'air-freshener',
                    'alarm-clock',
                    'align-center',
                    'align-justify',
                    'align-left',
                    'align-right',
                    'allergies',
                    'ambulance',
                    'american-sign-language-interpreting',
                    'analytics',
                    'anchor',
                    'angle-double-down',
                    'angle-double-left',
                    'angle-double-right',
                    'angle-double-up',
                    'angle-down',
                    'angle-left',
                    'angle-right',
                    'angle-up',
                    'angry',
                    'ankh',
                    'apple-alt',
                    'archive',
                    'archway',
                    'arrow-alt-circle-down',
                    'arrow-alt-circle-left',
                    'arrow-alt-circle-right',
                    'arrow-alt-circle-up',
                    'arrow-alt-down',
                    'arrow-alt-from-bottom',
                    'arrow-alt-from-left',
                    'arrow-alt-from-right',
                    'arrow-alt-from-top',
                    'arrow-alt-left',
                    'arrow-alt-right',
                    'arrow-alt-square-down',
                    'arrow-alt-square-left',
                    'arrow-alt-square-right',
                    'arrow-alt-square-up',
                    'arrow-alt-to-bottom',
                    'arrow-alt-to-left',
                    'arrow-alt-to-right',
                    'arrow-alt-to-top',
                    'arrow-alt-up',
                    'arrow-circle-down',
                    'arrow-circle-left',
                    'arrow-circle-right',
                    'arrow-circle-up',
                    'arrow-down',
                    'arrow-from-bottom',
                    'arrow-from-left',
                    'arrow-from-right',
                    'arrow-from-top',
                    'arrow-left',
                    'arrow-right',
                    'arrow-square-down',
                    'arrow-square-left',
                    'arrow-square-right',
                    'arrow-square-up',
                    'arrow-to-bottom',
                    'arrow-to-left',
                    'arrow-to-right',
                    'arrow-to-top',
                    'arrow-up',
                    'arrows',
                    'arrows-alt',
                    'arrows-alt-h',
                    'arrows-alt-v',
                    'arrows-h',
                    'arrows-v',
                    'assistive-listening-systems',
                    'asterisk',
                    'at',
                    'atlas',
                    'atom',
                    'atom-alt',
                    'audio-description',
                    'award',
                    'backpack',
                    'backspace',
                    'backward',
                    'badge',
                    'badge-check',
                    'badge-dollar',
                    'badge-percent',
                    'balance-scale',
                    'balance-scale-left',
                    'balance-scale-right',
                    'ban',
                    'band-aid',
                    'barcode',
                    'barcode-alt',
                    'barcode-read',
                    'barcode-scan',
                    'bars',
                    'baseball',
                    'baseball-ball',
                    'basketball-ball',
                    'basketball-hoop',
                    'bath',
                    'battery-bolt',
                    'battery-empty',
                    'battery-full',
                    'battery-half',
                    'battery-quarter',
                    'battery-slash',
                    'battery-three-quarters',
                    'bed',
                    'beer',
                    'bell',
                    'bell-school',
                    'bell-school-slash',
                    'bell-slash',
                    'bezier-curve',
                    'bible',
                    'bicycle',
                    'binoculars',
                    'birthday-cake',
                    'blanket',
                    'blender',
                    'blind',
                    'bold',
                    'bolt',
                    'bomb',
                    'bone',
                    'bone-break',
                    'bong',
                    'book',
                    'book-alt',
                    'book-heart',
                    'book-open',
                    'book-reader',
                    'bookmark',
                    'books',
                    'bowling-ball',
                    'bowling-pins',
                    'box',
                    'box-alt',
                    'box-check',
                    'box-fragile',
                    'box-full',
                    'box-heart',
                    'box-open',
                    'box-up',
                    'box-usd',
                    'boxes',
                    'boxes-alt',
                    'boxing-glove',
                    'braille',
                    'brain',
                    'briefcase',
                    'briefcase-medical',
                    'broadcast-tower',
                    'broom',
                    'browser',
                    'brush',
                    'bug',
                    'building',
                    'bullhorn',
                    'bullseye',
                    'bullseye-arrow',
                    'bullseye-pointer',
                    'burn',
                    'bus',
                    'bus-alt',
                    'bus-school',
                    'business-time',
                    'cabinet-filing',
                    'calculator',
                    'calculator-alt',
                    'calendar',
                    'calendar-alt',
                    'calendar-check',
                    'calendar-edit',
                    'calendar-exclamation',
                    'calendar-minus',
                    'calendar-plus',
                    'calendar-times',
                    'camera',
                    'camera-alt',
                    'camera-retro',
                    'cannabis',
                    'capsules',
                    'car',
                    'car-alt',
                    'car-battery',
                    'car-bump',
                    'car-crash',
                    'car-garage',
                    'car-mechanic',
                    'car-side',
                    'car-tilt',
                    'car-wash',
                    'caret-circle-down',
                    'caret-circle-left',
                    'caret-circle-right',
                    'caret-circle-up',
                    'caret-down',
                    'caret-left',
                    'caret-right',
                    'caret-square-down',
                    'caret-square-left',
                    'caret-square-right',
                    'caret-square-up',
                    'caret-up',
                    'cart-arrow-down',
                    'cart-plus',
                    'certificate',
                    'chalkboard',
                    'chalkboard-teacher',
                    'charging-station',
                    'chart-area',
                    'chart-bar',
                    'chart-line',
                    'chart-line-down',
                    'chart-pie',
                    'chart-pie-alt',
                    'check',
                    'check-circle',
                    'check-double',
                    'check-square',
                    'chess',
                    'chess-bishop',
                    'chess-bishop-alt',
                    'chess-board',
                    'chess-clock',
                    'chess-clock-alt',
                    'chess-king',
                    'chess-king-alt',
                    'chess-knight',
                    'chess-knight-alt',
                    'chess-pawn',
                    'chess-pawn-alt',
                    'chess-queen',
                    'chess-queen-alt',
                    'chess-rook',
                    'chess-rook-alt',
                    'chevron-circle-down',
                    'chevron-circle-left',
                    'chevron-circle-right',
                    'chevron-circle-up',
                    'chevron-double-down',
                    'chevron-double-left',
                    'chevron-double-right',
                    'chevron-double-up',
                    'chevron-down',
                    'chevron-left',
                    'chevron-right',
                    'chevron-square-down',
                    'chevron-square-left',
                    'chevron-square-right',
                    'chevron-square-up',
                    'chevron-up',
                    'child',
                    'church',
                    'circle',
                    'circle-notch',
                    'city',
                    'clipboard',
                    'clipboard-check',
                    'clipboard-list',
                    'clipboard-prescription',
                    'clock',
                    'clone',
                    'closed-captioning',
                    'cloud',
                    'cloud-download',
                    'cloud-download-alt',
                    'cloud-upload',
                    'cloud-upload-alt',
                    'club',
                    'cocktail',
                    'code',
                    'code-branch',
                    'code-commit',
                    'code-merge',
                    'coffee',
                    'cog',
                    'cogs',
                    'coins',
                    'columns',
                    'comment',
                    'comment-alt',
                    'comment-alt-check',
                    'comment-alt-dollar',
                    'comment-alt-dots',
                    'comment-alt-edit',
                    'comment-alt-exclamation',
                    'comment-alt-lines',
                    'comment-alt-minus',
                    'comment-alt-plus',
                    'comment-alt-slash',
                    'comment-alt-smile',
                    'comment-alt-times',
                    'comment-check',
                    'comment-dollar',
                    'comment-dots',
                    'comment-edit',
                    'comment-exclamation',
                    'comment-lines',
                    'comment-minus',
                    'comment-plus',
                    'comment-slash',
                    'comment-smile',
                    'comment-times',
                    'comments',
                    'comments-alt',
                    'comments-alt-dollar',
                    'comments-dollar',
                    'compact-disc',
                    'compass',
                    'compass-slash',
                    'compress',
                    'compress-alt',
                    'compress-wide',
                    'concierge-bell',
                    'container-storage',
                    'conveyor-belt',
                    'conveyor-belt-alt',
                    'cookie',
                    'cookie-bite',
                    'copy',
                    'copyright',
                    'couch',
                    'credit-card',
                    'credit-card-blank',
                    'credit-card-front',
                    'cricket',
                    'crop',
                    'crop-alt',
                    'cross',
                    'crosshairs',
                    'crow',
                    'crown',
                    'cube',
                    'cubes',
                    'curling',
                    'cut',
                    'database',
                    'deaf',
                    'desktop',
                    'desktop-alt',
                    'dharmachakra',
                    'diagnoses',
                    'diamond',
                    'dice',
                    'dice-five',
                    'dice-four',
                    'dice-one',
                    'dice-six',
                    'dice-three',
                    'dice-two',
                    'digital-tachograph',
                    'diploma',
                    'directions',
                    'divide',
                    'dizzy',
                    'dna',
                    'do-not-enter',
                    'dollar-sign',
                    'dolly',
                    'dolly-empty',
                    'dolly-flatbed',
                    'dolly-flatbed-alt',
                    'dolly-flatbed-empty',
                    'donate',
                    'door-closed',
                    'door-open',
                    'dot-circle',
                    'dove',
                    'download',
                    'drafting-compass',
                    'draw-circle',
                    'draw-polygon',
                    'draw-square',
                    'drum',
                    'drum-steelpan',
                    'dumbbell',
                    'ear',
                    'edit',
                    'eject',
                    'ellipsis-h',
                    'ellipsis-h-alt',
                    'ellipsis-v',
                    'ellipsis-v-alt',
                    'empty-set',
                    'engine-warning',
                    'envelope',
                    'envelope-open',
                    'envelope-open-dollar',
                    'envelope-open-text',
                    'envelope-square',
                    'equals',
                    'eraser',
                    'euro-sign',
                    'exchange',
                    'exchange-alt',
                    'exclamation',
                    'exclamation-circle',
                    'exclamation-square',
                    'exclamation-triangle',
                    'expand',
                    'expand-alt',
                    'expand-arrows',
                    'expand-arrows-alt',
                    'expand-wide',
                    'external-link',
                    'external-link-alt',
                    'external-link-square',
                    'external-link-square-alt',
                    'eye',
                    'eye-dropper',
                    'eye-slash',
                    'fast-backward',
                    'fast-forward',
                    'fax',
                    'feather',
                    'feather-alt',
                    'female',
                    'field-hockey',
                    'fighter-jet',
                    'file',
                    'file-alt',
                    'file-archive',
                    'file-audio',
                    'file-certificate',
                    'file-chart-line',
                    'file-chart-pie',
                    'file-check',
                    'file-code',
                    'file-contract',
                    'file-download',
                    'file-edit',
                    'file-excel',
                    'file-exclamation',
                    'file-export',
                    'file-image',
                    'file-import',
                    'file-invoice',
                    'file-invoice-dollar',
                    'file-medical',
                    'file-medical-alt',
                    'file-minus',
                    'file-pdf',
                    'file-plus',
                    'file-powerpoint',
                    'file-prescription',
                    'file-signature',
                    'file-spreadsheet',
                    'file-times',
                    'file-upload',
                    'file-user',
                    'file-video',
                    'file-word',
                    'fill',
                    'fill-drip',
                    'film',
                    'film-alt',
                    'filter',
                    'fingerprint',
                    'fire',
                    'fire-extinguisher',
                    'first-aid',
                    'fish',
                    'flag',
                    'flag-checkered',
                    'flask',
                    'flushed',
                    'folder',
                    'folder-minus',
                    'folder-open',
                    'folder-plus',
                    'folder-times',
                    'folders',
                    'font',
                    'football-ball',
                    'football-helmet',
                    'forklift',
                    'forward',
                    'fragile',
                    'frog',
                    'frown',
                    'frown-open',
                    'function',
                    'funnel-dollar',
                    'futbol',
                    'gamepad',
                    'gas-pump',
                    'gas-pump-slash',
                    'gavel',
                    'gem',
                    'genderless',
                    'gift',
                    'gift-card',
                    'glass-martini',
                    'glass-martini-alt',
                    'glasses',
                    'glasses-alt',
                    'globe',
                    'globe-africa',
                    'globe-americas',
                    'globe-asia',
                    'globe-stand',
                    'golf-ball',
                    'golf-club',
                    'gopuram',
                    'graduation-cap',
                    'greater-than',
                    'greater-than-equal',
                    'grimace',
                    'grin',
                    'grin-alt',
                    'grin-beam',
                    'grin-beam-sweat',
                    'grin-hearts',
                    'grin-squint',
                    'grin-squint-tears',
                    'grin-stars',
                    'grin-tears',
                    'grin-tongue',
                    'grin-tongue-squint',
                    'grin-tongue-wink',
                    'grin-wink',
                    'grip-horizontal',
                    'grip-vertical',
                    'h-square',
                    'h1',
                    'h2',
                    'h3',
                    'hamsa',
                    'hand-heart',
                    'hand-holding',
                    'hand-holding-box',
                    'hand-holding-heart',
                    'hand-holding-seedling',
                    'hand-holding-usd',
                    'hand-holding-water',
                    'hand-lizard',
                    'hand-paper',
                    'hand-peace',
                    'hand-point-down',
                    'hand-point-left',
                    'hand-point-right',
                    'hand-point-up',
                    'hand-pointer',
                    'hand-receiving',
                    'hand-rock',
                    'hand-scissors',
                    'hand-spock',
                    'hands',
                    'hands-heart',
                    'hands-helping',
                    'hands-usd',
                    'handshake',
                    'handshake-alt',
                    'hashtag',
                    'haykal',
                    'hdd',
                    'heading',
                    'headphones',
                    'headphones-alt',
                    'headset',
                    'heart',
                    'heart-circle',
                    'heart-rate',
                    'heart-square',
                    'heartbeat',
                    'helicopter',
                    'hexagon',
                    'highlighter',
                    'history',
                    'hockey-puck',
                    'hockey-sticks',
                    'home',
                    'home-heart',
                    'hospital',
                    'hospital-alt',
                    'hospital-symbol',
                    'hot-tub',
                    'hotel',
                    'hourglass',
                    'hourglass-end',
                    'hourglass-half',
                    'hourglass-start',
                    'i-cursor',
                    'id-badge',
                    'id-card',
                    'id-card-alt',
                    'image',
                    'images',
                    'inbox',
                    'inbox-in',
                    'inbox-out',
                    'indent',
                    'industry',
                    'industry-alt',
                    'infinity',
                    'info',
                    'info-circle',
                    'info-square',
                    'inhaler',
                    'integral',
                    'intersection',
                    'inventory',
                    'italic',
                    'jack-o-lantern',
                    'jedi',
                    'joint',
                    'journal-whills',
                    'kaaba',
                    'key',
                    'keyboard',
                    'keynote',
                    'khanda',
                    'kidneys',
                    'kiss',
                    'kiss-beam',
                    'kiss-wink-heart',
                    'kiwi-bird',
                    'lambda',
                    'lamp',
                    'landmark',
                    'language',
                    'laptop',
                    'laptop-code',
                    'laugh',
                    'laugh-beam',
                    'laugh-squint',
                    'laugh-wink',
                    'layer-group',
                    'layer-minus',
                    'layer-plus',
                    'leaf',
                    'leaf-heart',
                    'lemon',
                    'less-than',
                    'less-than-equal',
                    'level-down',
                    'level-down-alt',
                    'level-up',
                    'level-up-alt',
                    'life-ring',
                    'lightbulb',
                    'lightbulb-dollar',
                    'lightbulb-exclamation',
                    'lightbulb-on',
                    'lightbulb-slash',
                    'link',
                    'lips',
                    'lira-sign',
                    'list',
                    'list-alt',
                    'list-ol',
                    'list-ul',
                    'location',
                    'location-arrow',
                    'location-circle',
                    'location-slash',
                    'lock',
                    'lock-alt',
                    'lock-open',
                    'lock-open-alt',
                    'long-arrow-alt-down',
                    'long-arrow-alt-left',
                    'long-arrow-alt-right',
                    'long-arrow-alt-up',
                    'long-arrow-down',
                    'long-arrow-left',
                    'long-arrow-right',
                    'long-arrow-up',
                    'loveseat',
                    'low-vision',
                    'luchador',
                    'luggage-cart',
                    'lungs',
                    'magic',
                    'magnet',
                    'mail-bulk',
                    'male',
                    'map',
                    'map-marked',
                    'map-marked-alt',
                    'map-marker',
                    'map-marker-alt',
                    'map-marker-alt-slash',
                    'map-marker-check',
                    'map-marker-edit',
                    'map-marker-exclamation',
                    'map-marker-minus',
                    'map-marker-plus',
                    'map-marker-question',
                    'map-marker-slash',
                    'map-marker-smile',
                    'map-marker-times',
                    'map-pin',
                    'map-signs',
                    'marker',
                    'mars',
                    'mars-double',
                    'mars-stroke',
                    'mars-stroke-h',
                    'mars-stroke-v',
                    'medal',
                    'medkit',
                    'megaphone',
                    'meh',
                    'meh-blank',
                    'meh-rolling-eyes',
                    'memory',
                    'menorah',
                    'mercury',
                    'microchip',
                    'microphone',
                    'microphone-alt',
                    'microphone-alt-slash',
                    'microphone-slash',
                    'microscope',
                    'mind-share',
                    'minus',
                    'minus-circle',
                    'minus-hexagon',
                    'minus-octagon',
                    'minus-square',
                    'mobile',
                    'mobile-alt',
                    'mobile-android',
                    'mobile-android-alt',
                    'money-bill',
                    'money-bill-alt',
                    'money-bill-wave',
                    'money-bill-wave-alt',
                    'money-check',
                    'money-check-alt',
                    'monitor-heart-rate',
                    'monument',
                    'moon',
                    'mortar-pestle',
                    'mosque',
                    'motorcycle',
                    'mouse-pointer',
                    'music',
                    'neuter',
                    'newspaper',
                    'not-equal',
                    'notes-medical',
                    'object-group',
                    'object-ungroup',
                    'octagon',
                    'oil-can',
                    'oil-temp',
                    'om',
                    'omega',
                    'outdent',
                    'paint-brush',
                    'paint-brush-alt',
                    'paint-roller',
                    'palette',
                    'pallet',
                    'pallet-alt',
                    'paper-plane',
                    'paperclip',
                    'parachute-box',
                    'paragraph',
                    'parking',
                    'parking-circle',
                    'parking-circle-slash',
                    'parking-slash',
                    'passport',
                    'pastafarianism',
                    'paste',
                    'pause',
                    'pause-circle',
                    'paw',
                    'peace',
                    'pen',
                    'pen-alt',
                    'pen-fancy',
                    'pen-nib',
                    'pen-square',
                    'pencil',
                    'pencil-alt',
                    'pencil-paintbrush',
                    'pencil-ruler',
                    'pennant',
                    'people-carry',
                    'percent',
                    'percentage',
                    'person-carry',
                    'person-dolly',
                    'person-dolly-empty',
                    'phone',
                    'phone-office',
                    'phone-plus',
                    'phone-slash',
                    'phone-square',
                    'phone-volume',
                    'pi',
                    'piggy-bank',
                    'pills',
                    'place-of-worship',
                    'plane',
                    'plane-alt',
                    'plane-arrival',
                    'plane-departure',
                    'play',
                    'play-circle',
                    'plug',
                    'plus',
                    'plus-circle',
                    'plus-hexagon',
                    'plus-octagon',
                    'plus-square',
                    'podcast',
                    'podium',
                    'poll',
                    'poll-h',
                    'poo',
                    'poop',
                    'portrait',
                    'pound-sign',
                    'power-off',
                    'pray',
                    'praying-hands',
                    'prescription',
                    'prescription-bottle',
                    'prescription-bottle-alt',
                    'presentation',
                    'print',
                    'print-slash',
                    'procedures',
                    'project-diagram',
                    'puzzle-piece',
                    'qrcode',
                    'question',
                    'question-circle',
                    'question-square',
                    'quidditch',
                    'quote-left',
                    'quote-right',
                    'quran',
                    'racquet',
                    'ramp-loading',
                    'random',
                    'receipt',
                    'rectangle-landscape',
                    'rectangle-portrait',
                    'rectangle-wide',
                    'recycle',
                    'redo',
                    'redo-alt',
                    'registered',
                    'repeat',
                    'repeat-1',
                    'repeat-1-alt',
                    'repeat-alt',
                    'reply',
                    'reply-all',
                    'retweet',
                    'retweet-alt',
                    'ribbon',
                    'road',
                    'robot',
                    'rocket',
                    'route',
                    'route-highway',
                    'route-interstate',
                    'rss',
                    'rss-square',
                    'ruble-sign',
                    'ruler',
                    'ruler-combined',
                    'ruler-horizontal',
                    'ruler-triangle',
                    'ruler-vertical',
                    'rupee-sign',
                    'sad-cry',
                    'sad-tear',
                    'save',
                    'scalpel',
                    'scalpel-path',
                    'scanner',
                    'scanner-keyboard',
                    'scanner-touchscreen',
                    'school',
                    'screwdriver',
                    'scrubber',
                    'search',
                    'search-dollar',
                    'search-location',
                    'search-minus',
                    'search-plus',
                    'seedling',
                    'server',
                    'shapes',
                    'share',
                    'share-all',
                    'share-alt',
                    'share-alt-square',
                    'share-square',
                    'shekel-sign',
                    'shield',
                    'shield-alt',
                    'shield-check',
                    'ship',
                    'shipping-fast',
                    'shipping-timed',
                    'shoe-prints',
                    'shopping-bag',
                    'shopping-basket',
                    'shopping-cart',
                    'shower',
                    'shredder',
                    'shuttle-van',
                    'shuttlecock',
                    'sigma',
                    'sign',
                    'sign-in',
                    'sign-in-alt',
                    'sign-language',
                    'sign-out',
                    'sign-out-alt',
                    'signal',
                    'signal-1',
                    'signal-2',
                    'signal-3',
                    'signal-4',
                    'signal-alt',
                    'signal-alt-1',
                    'signal-alt-2',
                    'signal-alt-3',
                    'signal-alt-slash',
                    'signal-slash',
                    'signature',
                    'sitemap',
                    'skeleton',
                    'skull',
                    'sliders-h',
                    'sliders-h-square',
                    'sliders-v',
                    'sliders-v-square',
                    'smile',
                    'smile-beam',
                    'smile-plus',
                    'smile-wink',
                    'smoking',
                    'smoking-ban',
                    'snowflake',
                    'socks',
                    'solar-panel',
                    'sort',
                    'sort-alpha-down',
                    'sort-alpha-up',
                    'sort-amount-down',
                    'sort-amount-up',
                    'sort-down',
                    'sort-numeric-down',
                    'sort-numeric-up',
                    'sort-up',
                    'spa',
                    'space-shuttle',
                    'spade',
                    'spinner',
                    'spinner-third',
                    'splotch',
                    'spray-can',
                    'square',
                    'square-full',
                    'square-root',
                    'square-root-alt',
                    'stamp',
                    'star',
                    'star-and-crescent',
                    'star-exclamation',
                    'star-half',
                    'star-half-alt',
                    'star-of-david',
                    'star-of-life',
                    'steering-wheel',
                    'step-backward',
                    'step-forward',
                    'stethoscope',
                    'sticky-note',
                    'stomach',
                    'stop',
                    'stop-circle',
                    'stopwatch',
                    'store',
                    'store-alt',
                    'stream',
                    'street-view',
                    'strikethrough',
                    'stroopwafel',
                    'subscript',
                    'subway',
                    'suitcase',
                    'suitcase-rolling',
                    'sun',
                    'superscript',
                    'surprise',
                    'swatchbook',
                    'swimmer',
                    'swimming-pool',
                    'synagogue',
                    'sync',
                    'sync-alt',
                    'syringe',
                    'table',
                    'table-tennis',
                    'tablet',
                    'tablet-alt',
                    'tablet-android',
                    'tablet-android-alt',
                    'tablet-rugged',
                    'tablets',
                    'tachometer',
                    'tachometer-alt',
                    'tachometer-alt-average',
                    'tachometer-alt-fast',
                    'tachometer-alt-fastest',
                    'tachometer-alt-slow',
                    'tachometer-alt-slowest',
                    'tachometer-average',
                    'tachometer-fast',
                    'tachometer-fastest',
                    'tachometer-slow',
                    'tachometer-slowest',
                    'tag',
                    'tags',
                    'tally',
                    'tape',
                    'tasks',
                    'taxi',
                    'teeth',
                    'teeth-open',
                    'tennis-ball',
                    'terminal',
                    'text-height',
                    'text-width',
                    'th',
                    'th-large',
                    'th-list',
                    'theater-masks',
                    'thermometer',
                    'thermometer-empty',
                    'thermometer-full',
                    'thermometer-half',
                    'thermometer-quarter',
                    'thermometer-three-quarters',
                    'theta',
                    'thumbs-down',
                    'thumbs-up',
                    'thumbtack',
                    'ticket',
                    'ticket-alt',
                    'tilde',
                    'times',
                    'times-circle',
                    'times-hexagon',
                    'times-octagon',
                    'times-square',
                    'tint',
                    'tint-slash',
                    'tire',
                    'tire-flat',
                    'tire-pressure-warning',
                    'tire-rugged',
                    'tired',
                    'toggle-off',
                    'toggle-on',
                    'toolbox',
                    'tooth',
                    'toothbrush',
                    'torah',
                    'torii-gate',
                    'trademark',
                    'traffic-cone',
                    'traffic-light',
                    'traffic-light-go',
                    'traffic-light-slow',
                    'traffic-light-stop',
                    'train',
                    'transgender',
                    'transgender-alt',
                    'trash',
                    'trash-alt',
                    'tree',
                    'tree-alt',
                    'triangle',
                    'trophy',
                    'trophy-alt',
                    'truck',
                    'truck-container',
                    'truck-couch',
                    'truck-loading',
                    'truck-monster',
                    'truck-moving',
                    'truck-pickup',
                    'truck-ramp',
                    'tshirt',
                    'tty',
                    'tv',
                    'tv-retro',
                    'umbrella',
                    'umbrella-beach',
                    'underline',
                    'undo',
                    'undo-alt',
                    'union',
                    'universal-access',
                    'university',
                    'unlink',
                    'unlock',
                    'unlock-alt',
                    'upload',
                    'usd-circle',
                    'usd-square',
                    'user',
                    'user-alt',
                    'user-alt-slash',
                    'user-astronaut',
                    'user-chart',
                    'user-check',
                    'user-circle',
                    'user-clock',
                    'user-cog',
                    'user-crown',
                    'user-edit',
                    'user-friends',
                    'user-graduate',
                    'user-lock',
                    'user-md',
                    'user-minus',
                    'user-ninja',
                    'user-plus',
                    'user-secret',
                    'user-shield',
                    'user-slash',
                    'user-tag',
                    'user-tie',
                    'user-times',
                    'users',
                    'users-class',
                    'users-cog',
                    'users-crown',
                    'utensil-fork',
                    'utensil-knife',
                    'utensil-spoon',
                    'utensils',
                    'utensils-alt',
                    'value-absolute',
                    'vector-square',
                    'venus',
                    'venus-double',
                    'venus-mars',
                    'vial',
                    'vials',
                    'video',
                    'video-plus',
                    'video-slash',
                    'vihara',
                    'volleyball-ball',
                    'volume',
                    'volume-down',
                    'volume-mute',
                    'volume-off',
                    'volume-slash',
                    'volume-up',
                    'walking',
                    'wallet',
                    'warehouse',
                    'warehouse-alt',
                    'watch',
                    'watch-fitness',
                    'weight',
                    'weight-hanging',
                    'wheelchair',
                    'whistle',
                    'wifi',
                    'wifi-1',
                    'wifi-2',
                    'wifi-slash',
                    'window',
                    'window-alt',
                    'window-close',
                    'window-maximize',
                    'window-minimize',
                    'window-restore',
                    'wine-glass',
                    'wine-glass-alt',
                    'won-sign',
                    'wrench',
                    'x-ray',
                    'yen-sign',
                    'yin-yang',
                    ]
            }
        ]
    };

    data.icons = data.allVersions[0].icons;

    $.iconset_fontawesome_5_regular = data;

})(jQuery);
