/*!========================================================================
 * Iconset: Ionicons
 * Versions: 1.5.2, 2.0.1
 * http://ionicons.com/
 * CDN: http://code.ionicframework.com/ionicons/[VERSION]/css/ionicons.min.css
 * ======================================================================== */

;(function($){

    var data = {
        iconClass: '',
        iconClassFix: 'ion-',
        icons: [],
        allVersions: [
            {
                version: '1.5.2',
                icons: [
                    '',
                    'alert',
                    'alert-circled',
                    'android-add',
                    'android-add-contact',
                    'android-alarm',
                    'android-archive',
                    'android-arrow-back',
                    'android-arrow-down-left',
                    'android-arrow-down-right',
                    'android-arrow-forward',
                    'android-arrow-up-left',
                    'android-arrow-up-right',
                    'android-battery',
                    'android-book',
                    'android-calendar',
                    'android-call',
                    'android-camera',
                    'android-chat',
                    'android-checkmark',
                    'android-clock',
                    'android-close',
                    'android-contact',
                    'android-contacts',
                    'android-data',
                    'android-developer',
                    'android-display',
                    'android-download',
                    'android-drawer',
                    'android-dropdown',
                    'android-earth',
                    'android-folder',
                    'android-forums',
                    'android-friends',
                    'android-hand',
                    'android-image',
                    'android-inbox',
                    'android-information',
                    'android-keypad',
                    'android-lightbulb',
                    'android-locate',
                    'android-location',
                    'android-mail',
                    'android-microphone',
                    'android-mixer',
                    'android-more',
                    'android-note',
                    'android-playstore',
                    'android-printer',
                    'android-promotion',
                    'android-reminder',
                    'android-remove',
                    'android-search',
                    'android-send',
                    'android-settings',
                    'android-share',
                    'android-social',
                    'android-social-user',
                    'android-sort',
                    'android-stair-drawer',
                    'android-star',
                    'android-stopwatch',
                    'android-storage',
                    'android-system-back',
                    'android-system-home',
                    'android-system-windows',
                    'android-timer',
                    'android-trash',
                    'android-user-menu',
                    'android-volume',
                    'android-wifi',
                    'aperture',
                    'archive',
                    'arrow-down-a',
                    'arrow-down-b',
                    'arrow-down-c',
                    'arrow-expand',
                    'arrow-graph-down-left',
                    'arrow-graph-down-right',
                    'arrow-graph-up-left',
                    'arrow-graph-up-right',
                    'arrow-left-a',
                    'arrow-left-b',
                    'arrow-left-c',
                    'arrow-move',
                    'arrow-resize',
                    'arrow-return-left',
                    'arrow-return-right',
                    'arrow-right-a',
                    'arrow-right-b',
                    'arrow-right-c',
                    'arrow-shrink',
                    'arrow-swap',
                    'arrow-up-a',
                    'arrow-up-b',
                    'arrow-up-c',
                    'asterisk',
                    'at',
                    'bag',
                    'battery-charging',
                    'battery-empty',
                    'battery-full',
                    'battery-half',
                    'battery-low',
                    'beaker',
                    'beer',
                    'bluetooth',
                    'bonfire',
                    'bookmark',
                    'briefcase',
                    'bug',
                    'calculator',
                    'calendar',
                    'camera',
                    'card',
                    'cash',
                    'chatbox',
                    'chatbox-working',
                    'chatboxes',
                    'chatbubble',
                    'chatbubble-working',
                    'chatbubbles',
                    'checkmark',
                    'checkmark-circled',
                    'checkmark-round',
                    'chevron-down',
                    'chevron-left',
                    'chevron-right',
                    'chevron-up',
                    'clipboard',
                    'clock',
                    'close',
                    'close-circled',
                    'close-round',
                    'closed-captioning',
                    'cloud',
                    'code',
                    'code-download',
                    'code-working',
                    'coffee',
                    'compass',
                    'compose',
                    'connection-bars',
                    'contrast',
                    'cube',
                    'disc',
                    'document',
                    'document-text',
                    'drag',
                    'earth',
                    'edit',
                    'egg',
                    'eject',
                    'email',
                    'eye',
                    'eye-disabled',
                    'female',
                    'filing',
                    'film-marker',
                    'fireball',
                    'flag',
                    'flame',
                    'flash',
                    'flash-off',
                    'flask',
                    'folder',
                    'fork',
                    'fork-repo',
                    'forward',
                    'funnel',
                    'game-controller-a',
                    'game-controller-b',
                    'gear-a',
                    'gear-b',
                    'grid',
                    'hammer',
                    'happy',
                    'headphone',
                    'heart',
                    'heart-broken',
                    'help',
                    'help-buoy',
                    'help-circled',
                    'home',
                    'icecream',
                    'image',
                    'images',
                    'information',
                    'information-circled',
                    'ionic',
                    'ios7-alarm',
                    'ios7-alarm-outline',
                    'ios7-albums',
                    'ios7-albums-outline',
                    'ios7-americanfootball',
                    'ios7-americanfootball-outline',
                    'ios7-analytics',
                    'ios7-analytics-outline',
                    'ios7-arrow-back',
                    'ios7-arrow-down',
                    'ios7-arrow-forward',
                    'ios7-arrow-left',
                    'ios7-arrow-right',
                    'ios7-arrow-thin-down',
                    'ios7-arrow-thin-left',
                    'ios7-arrow-thin-right',
                    'ios7-arrow-thin-up',
                    'ios7-arrow-up',
                    'ios7-at',
                    'ios7-at-outline',
                    'ios7-barcode',
                    'ios7-barcode-outline',
                    'ios7-baseball',
                    'ios7-baseball-outline',
                    'ios7-basketball',
                    'ios7-basketball-outline',
                    'ios7-bell',
                    'ios7-bell-outline',
                    'ios7-bolt',
                    'ios7-bolt-outline',
                    'ios7-bookmarks',
                    'ios7-bookmarks-outline',
                    'ios7-box',
                    'ios7-box-outline',
                    'ios7-briefcase',
                    'ios7-briefcase-outline',
                    'ios7-browsers',
                    'ios7-browsers-outline',
                    'ios7-calculator',
                    'ios7-calculator-outline',
                    'ios7-calendar',
                    'ios7-calendar-outline',
                    'ios7-camera',
                    'ios7-camera-outline',
                    'ios7-cart',
                    'ios7-cart-outline',
                    'ios7-chatboxes',
                    'ios7-chatboxes-outline',
                    'ios7-chatbubble',
                    'ios7-chatbubble-outline',
                    'ios7-checkmark',
                    'ios7-checkmark-empty',
                    'ios7-checkmark-outline',
                    'ios7-circle-filled',
                    'ios7-circle-outline',
                    'ios7-clock',
                    'ios7-clock-outline',
                    'ios7-close',
                    'ios7-close-empty',
                    'ios7-close-outline',
                    'ios7-cloud',
                    'ios7-cloud-download',
                    'ios7-cloud-download-outline',
                    'ios7-cloud-outline',
                    'ios7-cloud-upload',
                    'ios7-cloud-upload-outline',
                    'ios7-cloudy',
                    'ios7-cloudy-night',
                    'ios7-cloudy-night-outline',
                    'ios7-cloudy-outline',
                    'ios7-cog',
                    'ios7-cog-outline',
                    'ios7-compose',
                    'ios7-compose-outline',
                    'ios7-copy',
                    'ios7-copy-outline',
                    'ios7-download',
                    'ios7-download-outline',
                    'ios7-drag',
                    'ios7-email',
                    'ios7-email-outline',
                    'ios7-eye',
                    'ios7-eye-outline',
                    'ios7-fastforward',
                    'ios7-fastforward-outline',
                    'ios7-filing',
                    'ios7-filing-outline',
                    'ios7-film',
                    'ios7-film-outline',
                    'ios7-flag',
                    'ios7-flag-outline',
                    'ios7-folder',
                    'ios7-folder-outline',
                    'ios7-football',
                    'ios7-football-outline',
                    'ios7-gear',
                    'ios7-gear-outline',
                    'ios7-glasses',
                    'ios7-glasses-outline',
                    'ios7-heart',
                    'ios7-heart-outline',
                    'ios7-help',
                    'ios7-help-empty',
                    'ios7-help-outline',
                    'ios7-home',
                    'ios7-home-outline',
                    'ios7-infinite',
                    'ios7-infinite-outline',
                    'ios7-information',
                    'ios7-information-empty',
                    'ios7-information-outline',
                    'ios7-ionic-outline',
                    'ios7-keypad',
                    'ios7-keypad-outline',
                    'ios7-lightbulb',
                    'ios7-lightbulb-outline',
                    'ios7-location',
                    'ios7-location-outline',
                    'ios7-locked',
                    'ios7-locked-outline',
                    'ios7-loop',
                    'ios7-loop-strong',
                    'ios7-medkit',
                    'ios7-medkit-outline',
                    'ios7-mic',
                    'ios7-mic-off',
                    'ios7-mic-outline',
                    'ios7-minus',
                    'ios7-minus-empty',
                    'ios7-minus-outline',
                    'ios7-monitor',
                    'ios7-monitor-outline',
                    'ios7-moon',
                    'ios7-moon-outline',
                    'ios7-more',
                    'ios7-more-outline',
                    'ios7-musical-note',
                    'ios7-musical-notes',
                    'ios7-navigate',
                    'ios7-navigate-outline',
                    'ios7-paper',
                    'ios7-paper-outline',
                    'ios7-paperplane',
                    'ios7-paperplane-outline',
                    'ios7-partlysunny',
                    'ios7-partlysunny-outline',
                    'ios7-pause',
                    'ios7-pause-outline',
                    'ios7-paw',
                    'ios7-paw-outline',
                    'ios7-people',
                    'ios7-people-outline',
                    'ios7-person',
                    'ios7-person-outline',
                    'ios7-personadd',
                    'ios7-personadd-outline',
                    'ios7-photos',
                    'ios7-photos-outline',
                    'ios7-pie',
                    'ios7-pie-outline',
                    'ios7-play',
                    'ios7-play-outline',
                    'ios7-plus',
                    'ios7-plus-empty',
                    'ios7-plus-outline',
                    'ios7-pricetag',
                    'ios7-pricetag-outline',
                    'ios7-pricetags',
                    'ios7-pricetags-outline',
                    'ios7-printer',
                    'ios7-printer-outline',
                    'ios7-pulse',
                    'ios7-pulse-strong',
                    'ios7-rainy',
                    'ios7-rainy-outline',
                    'ios7-recording',
                    'ios7-recording-outline',
                    'ios7-redo',
                    'ios7-redo-outline',
                    'ios7-refresh',
                    'ios7-refresh-empty',
                    'ios7-refresh-outline',
                    'ios7-reload',
                    'ios7-reloading',
                    'ios7-reverse-camera',
                    'ios7-reverse-camera-outline',
                    'ios7-rewind',
                    'ios7-rewind-outline',
                    'ios7-search',
                    'ios7-search-strong',
                    'ios7-settings',
                    'ios7-settings-strong',
                    'ios7-skipbackward',
                    'ios7-skipbackward-outline',
                    'ios7-skipforward',
                    'ios7-skipforward-outline',
                    'ios7-snowy',
                    'ios7-speedometer',
                    'ios7-speedometer-outline',
                    'ios7-star',
                    'ios7-star-half',
                    'ios7-star-outline',
                    'ios7-stopwatch',
                    'ios7-stopwatch-outline',
                    'ios7-sunny',
                    'ios7-sunny-outline',
                    'ios7-telephone',
                    'ios7-telephone-outline',
                    'ios7-tennisball',
                    'ios7-tennisball-outline',
                    'ios7-thunderstorm',
                    'ios7-thunderstorm-outline',
                    'ios7-time',
                    'ios7-time-outline',
                    'ios7-timer',
                    'ios7-timer-outline',
                    'ios7-toggle',
                    'ios7-toggle-outline',
                    'ios7-trash',
                    'ios7-trash-outline',
                    'ios7-undo',
                    'ios7-undo-outline',
                    'ios7-unlocked',
                    'ios7-unlocked-outline',
                    'ios7-upload',
                    'ios7-upload-outline',
                    'ios7-videocam',
                    'ios7-videocam-outline',
                    'ios7-volume-high',
                    'ios7-volume-low',
                    'ios7-wineglass',
                    'ios7-wineglass-outline',
                    'ios7-world',
                    'ios7-world-outline',
                    'ipad',
                    'iphone',
                    'ipod',
                    'jet',
                    'key',
                    'knife',
                    'laptop',
                    'leaf',
                    'levels',
                    'lightbulb',
                    'link',
                    'load-a',
                    'load-b',
                    'load-c',
                    'load-d',
                    'loading-a',
                    'loading-b',
                    'loading-c',
                    'loading-d',
                    'location',
                    'locked',
                    'log-in',
                    'log-out',
                    'loop',
                    'looping',
                    'magnet',
                    'male',
                    'man',
                    'map',
                    'medkit',
                    'merge',
                    'mic-a',
                    'mic-b',
                    'mic-c',
                    'minus',
                    'minus-circled',
                    'minus-round',
                    'model-s',
                    'monitor',
                    'more',
                    'mouse',
                    'music-note',
                    'navicon',
                    'navicon-round',
                    'navigate',
                    'network',
                    'no-smoking',
                    'nuclear',
                    'outlet',
                    'paper-airplane',
                    'paperclip',
                    'pause',
                    'person',
                    'person-add',
                    'person-stalker',
                    'pie-graph',
                    'pin',
                    'pinpoint',
                    'pizza',
                    'plane',
                    'planet',
                    'play',
                    'playstation',
                    'plus',
                    'plus-circled',
                    'plus-round',
                    'podium',
                    'pound',
                    'power',
                    'pricetag',
                    'pricetags',
                    'printer',
                    'pull-request',
                    'qr-scanner',
                    'quote',
                    'radio-waves',
                    'record',
                    'refresh',
                    'refreshing',
                    'reply',
                    'reply-all',
                    'ribbon-a',
                    'ribbon-b',
                    'sad',
                    'scissors',
                    'search',
                    'settings',
                    'share',
                    'shuffle',
                    'skip-backward',
                    'skip-forward',
                    'social-android',
                    'social-android-outline',
                    'social-apple',
                    'social-apple-outline',
                    'social-bitcoin',
                    'social-bitcoin-outline',
                    'social-buffer',
                    'social-buffer-outline',
                    'social-designernews',
                    'social-designernews-outline',
                    'social-dribbble',
                    'social-dribbble-outline',
                    'social-dropbox',
                    'social-dropbox-outline',
                    'social-facebook',
                    'social-facebook-outline',
                    'social-foursquare',
                    'social-foursquare-outline',
                    'social-freebsd-devil',
                    'social-github',
                    'social-github-outline',
                    'social-google',
                    'social-google-outline',
                    'social-googleplus',
                    'social-googleplus-outline',
                    'social-hackernews',
                    'social-hackernews-outline',
                    'social-instagram',
                    'social-instagram-outline',
                    'social-linkedin',
                    'social-linkedin-outline',
                    'social-pinterest',
                    'social-pinterest-outline',
                    'social-reddit',
                    'social-reddit-outline',
                    'social-rss',
                    'social-rss-outline',
                    'social-skype',
                    'social-skype-outline',
                    'social-tumblr',
                    'social-tumblr-outline',
                    'social-tux',
                    'social-twitter',
                    'social-twitter-outline',
                    'social-usd',
                    'social-usd-outline',
                    'social-vimeo',
                    'social-vimeo-outline',
                    'social-windows',
                    'social-windows-outline',
                    'social-wordpress',
                    'social-wordpress-outline',
                    'social-yahoo',
                    'social-yahoo-outline',
                    'social-youtube',
                    'social-youtube-outline',
                    'speakerphone',
                    'speedometer',
                    'spoon',
                    'star',
                    'stats-bars',
                    'steam',
                    'stop',
                    'thermometer',
                    'thumbsdown',
                    'thumbsup',
                    'toggle',
                    'toggle-filled',
                    'trash-a',
                    'trash-b',
                    'trophy',
                    'umbrella',
                    'university',
                    'unlocked',
                    'upload',
                    'usb',
                    'videocamera',
                    'volume-high',
                    'volume-low',
                    'volume-medium',
                    'volume-mute',
                    'wand',
                    'waterdrop',
                    'wifi',
                    'wineglass',
                    'woman',
                    'wrench',
                    'xbox'
                ]
            },
            {
                version: '2.0.1',
                icons: [
                    '',
                    'alert',
                    'alert-circled',
                    'android-add',
                    'android-add-circle',
                    'android-alarm-clock',
                    'android-alert',
                    'android-apps',
                    'android-archive',
                    'android-arrow-back',
                    'android-arrow-down',
                    'android-arrow-dropdown',
                    'android-arrow-dropdown-circle',
                    'android-arrow-dropleft',
                    'android-arrow-dropleft-circle',
                    'android-arrow-dropright',
                    'android-arrow-dropright-circle',
                    'android-arrow-dropup',
                    'android-arrow-dropup-circle',
                    'android-arrow-forward',
                    'android-arrow-up',
                    'android-attach',
                    'android-bar',
                    'android-bicycle',
                    'android-boat',
                    'android-bookmark',
                    'android-bulb',
                    'android-bus',
                    'android-calendar',
                    'android-call',
                    'android-camera',
                    'android-cancel',
                    'android-car',
                    'android-cart',
                    'android-chat',
                    'android-checkbox',
                    'android-checkbox-blank',
                    'android-checkbox-outline',
                    'android-checkbox-outline-blank',
                    'android-checkmark-circle',
                    'android-clipboard',
                    'android-close',
                    'android-cloud',
                    'android-cloud-circle',
                    'android-cloud-done',
                    'android-cloud-outline',
                    'android-color-palette',
                    'android-compass',
                    'android-contact',
                    'android-contacts',
                    'android-contract',
                    'android-create',
                    'android-delete',
                    'android-desktop',
                    'android-document',
                    'android-done',
                    'android-done-all',
                    'android-download',
                    'android-drafts',
                    'android-exit',
                    'android-expand',
                    'android-favorite',
                    'android-favorite-outline',
                    'android-film',
                    'android-folder',
                    'android-folder-open',
                    'android-funnel',
                    'android-globe',
                    'android-hand',
                    'android-hangout',
                    'android-happy',
                    'android-home',
                    'android-image',
                    'android-laptop',
                    'android-list',
                    'android-locate',
                    'android-lock',
                    'android-mail',
                    'android-map',
                    'android-menu',
                    'android-microphone',
                    'android-microphone-off',
                    'android-more-horizontal',
                    'android-more-vertical',
                    'android-navigate',
                    'android-notifications',
                    'android-notifications-none',
                    'android-notifications-off',
                    'android-open',
                    'android-options',
                    'android-people',
                    'android-person',
                    'android-person-add',
                    'android-phone-landscape',
                    'android-phone-portrait',
                    'android-pin',
                    'android-plane',
                    'android-playstore',
                    'android-print',
                    'android-radio-button-off',
                    'android-radio-button-on',
                    'android-refresh',
                    'android-remove',
                    'android-remove-circle',
                    'android-restaurant',
                    'android-sad',
                    'android-search',
                    'android-send',
                    'android-settings',
                    'android-share',
                    'android-share-alt',
                    'android-star',
                    'android-star-half',
                    'android-star-outline',
                    'android-stopwatch',
                    'android-subway',
                    'android-sunny',
                    'android-sync',
                    'android-textsms',
                    'android-time',
                    'android-train',
                    'android-unlock',
                    'android-upload',
                    'android-volume-down',
                    'android-volume-mute',
                    'android-volume-off',
                    'android-volume-up',
                    'android-walk',
                    'android-warning',
                    'android-watch',
                    'android-wifi',
                    'aperture',
                    'archive',
                    'arrow-down-a',
                    'arrow-down-b',
                    'arrow-down-c',
                    'arrow-expand',
                    'arrow-graph-down-left',
                    'arrow-graph-down-right',
                    'arrow-graph-up-left',
                    'arrow-graph-up-right',
                    'arrow-left-a',
                    'arrow-left-b',
                    'arrow-left-c',
                    'arrow-move',
                    'arrow-resize',
                    'arrow-return-left',
                    'arrow-return-right',
                    'arrow-right-a',
                    'arrow-right-b',
                    'arrow-right-c',
                    'arrow-shrink',
                    'arrow-swap',
                    'arrow-up-a',
                    'arrow-up-b',
                    'arrow-up-c',
                    'asterisk',
                    'at',
                    'backspace',
                    'backspace-outline',
                    'bag',
                    'battery-charging',
                    'battery-empty',
                    'battery-full',
                    'battery-half',
                    'battery-low',
                    'beaker',
                    'beer',
                    'bluetooth',
                    'bonfire',
                    'bookmark',
                    'bowtie',
                    'briefcase',
                    'bug',
                    'calculator',
                    'calendar',
                    'camera',
                    'card',
                    'cash',
                    'chatbox',
                    'chatbox-working',
                    'chatboxes',
                    'chatbubble',
                    'chatbubble-working',
                    'chatbubbles',
                    'checkmark',
                    'checkmark-circled',
                    'checkmark-round',
                    'chevron-down',
                    'chevron-left',
                    'chevron-right',
                    'chevron-up',
                    'clipboard',
                    'clock',
                    'close',
                    'close-circled',
                    'close-round',
                    'closed-captioning',
                    'cloud',
                    'code',
                    'code-download',
                    'code-working',
                    'coffee',
                    'compass',
                    'compose',
                    'connection-bars',
                    'contrast',
                    'crop',
                    'cube',
                    'disc',
                    'document',
                    'document-text',
                    'drag',
                    'earth',
                    'easel',
                    'edit',
                    'egg',
                    'eject',
                    'email',
                    'email-unread',
                    'erlenmeyer-flask',
                    'erlenmeyer-flask-bubbles',
                    'eye',
                    'eye-disabled',
                    'female',
                    'filing',
                    'film-marker',
                    'fireball',
                    'flag',
                    'flame',
                    'flash',
                    'flash-off',
                    'folder',
                    'fork',
                    'fork-repo',
                    'forward',
                    'funnel',
                    'gear-a',
                    'gear-b',
                    'grid',
                    'hammer',
                    'happy',
                    'happy-outline',
                    'headphone',
                    'heart',
                    'heart-broken',
                    'help',
                    'help-buoy',
                    'help-circled',
                    'home',
                    'icecream',
                    'image',
                    'images',
                    'information',
                    'information-circled',
                    'ionic',
                    'ios-alarm',
                    'ios-alarm-outline',
                    'ios-albums',
                    'ios-albums-outline',
                    'ios-americanfootball',
                    'ios-americanfootball-outline',
                    'ios-analytics',
                    'ios-analytics-outline',
                    'ios-arrow-back',
                    'ios-arrow-down',
                    'ios-arrow-forward',
                    'ios-arrow-left',
                    'ios-arrow-right',
                    'ios-arrow-thin-down',
                    'ios-arrow-thin-left',
                    'ios-arrow-thin-right',
                    'ios-arrow-thin-up',
                    'ios-arrow-up',
                    'ios-at',
                    'ios-at-outline',
                    'ios-barcode',
                    'ios-barcode-outline',
                    'ios-baseball',
                    'ios-baseball-outline',
                    'ios-basketball',
                    'ios-basketball-outline',
                    'ios-bell',
                    'ios-bell-outline',
                    'ios-body',
                    'ios-body-outline',
                    'ios-bolt',
                    'ios-bolt-outline',
                    'ios-book',
                    'ios-book-outline',
                    'ios-bookmarks',
                    'ios-bookmarks-outline',
                    'ios-box',
                    'ios-box-outline',
                    'ios-briefcase',
                    'ios-briefcase-outline',
                    'ios-browsers',
                    'ios-browsers-outline',
                    'ios-calculator',
                    'ios-calculator-outline',
                    'ios-calendar',
                    'ios-calendar-outline',
                    'ios-camera',
                    'ios-camera-outline',
                    'ios-cart',
                    'ios-cart-outline',
                    'ios-chatboxes',
                    'ios-chatboxes-outline',
                    'ios-chatbubble',
                    'ios-chatbubble-outline',
                    'ios-checkmark',
                    'ios-checkmark-empty',
                    'ios-checkmark-outline',
                    'ios-circle-filled',
                    'ios-circle-outline',
                    'ios-clock',
                    'ios-clock-outline',
                    'ios-close',
                    'ios-close-empty',
                    'ios-close-outline',
                    'ios-cloud',
                    'ios-cloud-download',
                    'ios-cloud-download-outline',
                    'ios-cloud-outline',
                    'ios-cloud-upload',
                    'ios-cloud-upload-outline',
                    'ios-cloudy',
                    'ios-cloudy-night',
                    'ios-cloudy-night-outline',
                    'ios-cloudy-outline',
                    'ios-cog',
                    'ios-cog-outline',
                    'ios-color-filter',
                    'ios-color-filter-outline',
                    'ios-color-wand',
                    'ios-color-wand-outline',
                    'ios-compose',
                    'ios-compose-outline',
                    'ios-contact',
                    'ios-contact-outline',
                    'ios-copy',
                    'ios-copy-outline',
                    'ios-crop',
                    'ios-crop-strong',
                    'ios-download',
                    'ios-download-outline',
                    'ios-drag',
                    'ios-email',
                    'ios-email-outline',
                    'ios-eye',
                    'ios-eye-outline',
                    'ios-fastforward',
                    'ios-fastforward-outline',
                    'ios-filing',
                    'ios-filing-outline',
                    'ios-film',
                    'ios-film-outline',
                    'ios-flag',
                    'ios-flag-outline',
                    'ios-flame',
                    'ios-flame-outline',
                    'ios-flask',
                    'ios-flask-outline',
                    'ios-flower',
                    'ios-flower-outline',
                    'ios-folder',
                    'ios-folder-outline',
                    'ios-football',
                    'ios-football-outline',
                    'ios-game-controller-a',
                    'ios-game-controller-a-outline',
                    'ios-game-controller-b',
                    'ios-game-controller-b-outline',
                    'ios-gear',
                    'ios-gear-outline',
                    'ios-glasses',
                    'ios-glasses-outline',
                    'ios-grid-view',
                    'ios-grid-view-outline',
                    'ios-heart',
                    'ios-heart-outline',
                    'ios-help',
                    'ios-help-empty',
                    'ios-help-outline',
                    'ios-home',
                    'ios-home-outline',
                    'ios-infinite',
                    'ios-infinite-outline',
                    'ios-information',
                    'ios-information-empty',
                    'ios-information-outline',
                    'ios-ionic-outline',
                    'ios-keypad',
                    'ios-keypad-outline',
                    'ios-lightbulb',
                    'ios-lightbulb-outline',
                    'ios-list',
                    'ios-list-outline',
                    'ios-location',
                    'ios-location-outline',
                    'ios-locked',
                    'ios-locked-outline',
                    'ios-loop',
                    'ios-loop-strong',
                    'ios-medical',
                    'ios-medical-outline',
                    'ios-medkit',
                    'ios-medkit-outline',
                    'ios-mic',
                    'ios-mic-off',
                    'ios-mic-outline',
                    'ios-minus',
                    'ios-minus-empty',
                    'ios-minus-outline',
                    'ios-monitor',
                    'ios-monitor-outline',
                    'ios-moon',
                    'ios-moon-outline',
                    'ios-more',
                    'ios-more-outline',
                    'ios-musical-note',
                    'ios-musical-notes',
                    'ios-navigate',
                    'ios-navigate-outline',
                    'ios-nutrition',
                    'ios-nutrition-outline',
                    'ios-paper',
                    'ios-paper-outline',
                    'ios-paperplane',
                    'ios-paperplane-outline',
                    'ios-partlysunny',
                    'ios-partlysunny-outline',
                    'ios-pause',
                    'ios-pause-outline',
                    'ios-paw',
                    'ios-paw-outline',
                    'ios-people',
                    'ios-people-outline',
                    'ios-person',
                    'ios-person-outline',
                    'ios-personadd',
                    'ios-personadd-outline',
                    'ios-photos',
                    'ios-photos-outline',
                    'ios-pie',
                    'ios-pie-outline',
                    'ios-pint',
                    'ios-pint-outline',
                    'ios-play',
                    'ios-play-outline',
                    'ios-plus',
                    'ios-plus-empty',
                    'ios-plus-outline',
                    'ios-pricetag',
                    'ios-pricetag-outline',
                    'ios-pricetags',
                    'ios-pricetags-outline',
                    'ios-printer',
                    'ios-printer-outline',
                    'ios-pulse',
                    'ios-pulse-strong',
                    'ios-rainy',
                    'ios-rainy-outline',
                    'ios-recording',
                    'ios-recording-outline',
                    'ios-redo',
                    'ios-redo-outline',
                    'ios-refresh',
                    'ios-refresh-empty',
                    'ios-refresh-outline',
                    'ios-reload',
                    'ios-reverse-camera',
                    'ios-reverse-camera-outline',
                    'ios-rewind',
                    'ios-rewind-outline',
                    'ios-rose',
                    'ios-rose-outline',
                    'ios-search',
                    'ios-search-strong',
                    'ios-settings',
                    'ios-settings-strong',
                    'ios-shuffle',
                    'ios-shuffle-strong',
                    'ios-skipbackward',
                    'ios-skipbackward-outline',
                    'ios-skipforward',
                    'ios-skipforward-outline',
                    'ios-snowy',
                    'ios-speedometer',
                    'ios-speedometer-outline',
                    'ios-star',
                    'ios-star-half',
                    'ios-star-outline',
                    'ios-stopwatch',
                    'ios-stopwatch-outline',
                    'ios-sunny',
                    'ios-sunny-outline',
                    'ios-telephone',
                    'ios-telephone-outline',
                    'ios-tennisball',
                    'ios-tennisball-outline',
                    'ios-thunderstorm',
                    'ios-thunderstorm-outline',
                    'ios-time',
                    'ios-time-outline',
                    'ios-timer',
                    'ios-timer-outline',
                    'ios-toggle',
                    'ios-toggle-outline',
                    'ios-trash',
                    'ios-trash-outline',
                    'ios-undo',
                    'ios-undo-outline',
                    'ios-unlocked',
                    'ios-unlocked-outline',
                    'ios-upload',
                    'ios-upload-outline',
                    'ios-videocam',
                    'ios-videocam-outline',
                    'ios-volume-high',
                    'ios-volume-low',
                    'ios-wineglass',
                    'ios-wineglass-outline',
                    'ios-world',
                    'ios-world-outline',
                    'ipad',
                    'iphone',
                    'ipod',
                    'jet',
                    'key',
                    'knife',
                    'laptop',
                    'leaf',
                    'levels',
                    'lightbulb',
                    'link',
                    'load-a',
                    'load-b',
                    'load-c',
                    'load-d',
                    'location',
                    'lock-combination',
                    'locked',
                    'log-in',
                    'log-out',
                    'loop',
                    'magnet',
                    'male',
                    'man',
                    'map',
                    'medkit',
                    'merge',
                    'mic-a',
                    'mic-b',
                    'mic-c',
                    'minus',
                    'minus-circled',
                    'minus-round',
                    'model-s',
                    'monitor',
                    'more',
                    'mouse',
                    'music-note',
                    'navicon',
                    'navicon-round',
                    'navigate',
                    'network',
                    'no-smoking',
                    'nuclear',
                    'outlet',
                    'paintbrush',
                    'paintbucket',
                    'paper-airplane',
                    'paperclip',
                    'pause',
                    'person',
                    'person-add',
                    'person-stalker',
                    'pie-graph',
                    'pin',
                    'pinpoint',
                    'pizza',
                    'plane',
                    'planet',
                    'play',
                    'playstation',
                    'plus',
                    'plus-circled',
                    'plus-round',
                    'podium',
                    'pound',
                    'power',
                    'pricetag',
                    'pricetags',
                    'printer',
                    'pull-request',
                    'qr-scanner',
                    'quote',
                    'radio-waves',
                    'record',
                    'refresh',
                    'reply',
                    'reply-all',
                    'ribbon-a',
                    'ribbon-b',
                    'sad',
                    'sad-outline',
                    'scissors',
                    'search',
                    'settings',
                    'share',
                    'shuffle',
                    'skip-backward',
                    'skip-forward',
                    'social-android',
                    'social-android-outline',
                    'social-angular',
                    'social-angular-outline',
                    'social-apple',
                    'social-apple-outline',
                    'social-bitcoin',
                    'social-bitcoin-outline',
                    'social-buffer',
                    'social-buffer-outline',
                    'social-chrome',
                    'social-chrome-outline',
                    'social-codepen',
                    'social-codepen-outline',
                    'social-css3',
                    'social-css3-outline',
                    'social-designernews',
                    'social-designernews-outline',
                    'social-dribbble',
                    'social-dribbble-outline',
                    'social-dropbox',
                    'social-dropbox-outline',
                    'social-euro',
                    'social-euro-outline',
                    'social-facebook',
                    'social-facebook-outline',
                    'social-foursquare',
                    'social-foursquare-outline',
                    'social-freebsd-devil',
                    'social-github',
                    'social-github-outline',
                    'social-google',
                    'social-google-outline',
                    'social-googleplus',
                    'social-googleplus-outline',
                    'social-hackernews',
                    'social-hackernews-outline',
                    'social-html5',
                    'social-html5-outline',
                    'social-instagram',
                    'social-instagram-outline',
                    'social-javascript',
                    'social-javascript-outline',
                    'social-linkedin',
                    'social-linkedin-outline',
                    'social-markdown',
                    'social-nodejs',
                    'social-octocat',
                    'social-pinterest',
                    'social-pinterest-outline',
                    'social-python',
                    'social-reddit',
                    'social-reddit-outline',
                    'social-rss',
                    'social-rss-outline',
                    'social-sass',
                    'social-skype',
                    'social-skype-outline',
                    'social-snapchat',
                    'social-snapchat-outline',
                    'social-tumblr',
                    'social-tumblr-outline',
                    'social-tux',
                    'social-twitch',
                    'social-twitch-outline',
                    'social-twitter',
                    'social-twitter-outline',
                    'social-usd',
                    'social-usd-outline',
                    'social-vimeo',
                    'social-vimeo-outline',
                    'social-whatsapp',
                    'social-whatsapp-outline',
                    'social-windows',
                    'social-windows-outline',
                    'social-wordpress',
                    'social-wordpress-outline',
                    'social-yahoo',
                    'social-yahoo-outline',
                    'social-yen',
                    'social-yen-outline',
                    'social-youtube',
                    'social-youtube-outline',
                    'soup-can',
                    'soup-can-outline',
                    'speakerphone',
                    'speedometer',
                    'spoon',
                    'star',
                    'stats-bars',
                    'steam',
                    'stop',
                    'thermometer',
                    'thumbsdown',
                    'thumbsup',
                    'toggle',
                    'toggle-filled',
                    'transgender',
                    'trash-a',
                    'trash-b',
                    'trophy',
                    'tshirt',
                    'tshirt-outline',
                    'umbrella',
                    'university',
                    'unlocked',
                    'upload',
                    'usb',
                    'videocamera',
                    'volume-high',
                    'volume-low',
                    'volume-medium',
                    'volume-mute',
                    'wand',
                    'waterdrop',
                    'wifi',
                    'wineglass',
                    'woman',
                    'wrench',
                    'xbox'
                ]
            }
        ]
    };

    var l = data.allVersions.length;
    data.icons = data.allVersions[l-1].icons;

    $.iconset_ionicon = data;

})(jQuery);
