/*!========================================================================
 * Iconset: Typicons
 * Versions: 2.0.1, 2.0.2, 2.0.3, 2.0.4, 2.0.5, 2.0.6, 2.0.7, 2.0.8, 2.0.9
 * https://github.com/stephenhutchings/typicons.font
 * CDN: https://cdnjs.cloudflare.com/ajax/libs/typicons/[VERSION]/typicons.css
 * ======================================================================== */

;(function($){

    var data = {
        iconClass: 'typcn',
        iconClassFix: 'typcn-',
        icons: [],
        allVersions: [
            {
                version: '2.0.1',
                icons: [
                    '',
                    'adjust-brightness',
                    'adjust-contrast',
                    'anchor',
                    'anchor-outline',
                    'archive',
                    'arrow-back',
                    'arrow-back-outline',
                    'arrow-down',
                    'arrow-down-outline',
                    'arrow-down-thick',
                    'arrow-forward',
                    'arrow-forward-outline',
                    'arrow-left',
                    'arrow-left-outline',
                    'arrow-left-thick',
                    'arrow-loop',
                    'arrow-loop-outline',
                    'arrow-maximise',
                    'arrow-maximise-outline',
                    'arrow-minimise',
                    'arrow-minimise-outline',
                    'arrow-move',
                    'arrow-move-outline',
                    'arrow-repeat',
                    'arrow-repeat-outline',
                    'arrow-right',
                    'arrow-right-outline',
                    'arrow-right-thick',
                    'arrow-shuffle',
                    'arrow-sync',
                    'arrow-sync-outline',
                    'arrow-up',
                    'arrow-up-outline',
                    'arrow-up-thick',
                    'at',
                    'attachment',
                    'attachment-outline',
                    'backspace',
                    'backspace-outline',
                    'battery-charge',
                    'battery-full',
                    'battery-high',
                    'battery-low',
                    'battery-mid',
                    'beaker',
                    'beer',
                    'bell',
                    'book',
                    'bookmark',
                    'briefcase',
                    'brush',
                    'business-card',
                    'calculator',
                    'calender',
                    'calender-outline',
                    'camera',
                    'camera-outline',
                    'cancel',
                    'cancel-outline',
                    'chart-area',
                    'chart-area-outline',
                    'chart-bar',
                    'chart-bar-outline',
                    'chart-line',
                    'chart-line-outline',
                    'chart-pie',
                    'chart-pie-outline',
                    'chevron-left',
                    'chevron-left-outline',
                    'chevron-right',
                    'chevron-right-outline',
                    'clipboard',
                    'cloud-storage',
                    'code',
                    'code-outline',
                    'coffee',
                    'cog',
                    'cog-outline',
                    'compass',
                    'contacts',
                    'credit-card',
                    'cross',
                    'database',
                    'delete',
                    'delete-outline',
                    'device-desktop',
                    'device-laptop',
                    'device-phone',
                    'device-tablet',
                    'directions',
                    'divide',
                    'divide-outline',
                    'document',
                    'document-add',
                    'document-delete',
                    'document-text',
                    'download',
                    'download-outline',
                    'edit',
                    'eject',
                    'eject-outline',
                    'equals',
                    'equals-outline',
                    'export',
                    'export-outline',
                    'eye',
                    'eye-outline',
                    'feather',
                    'film',
                    'flag',
                    'flag-outline',
                    'flash',
                    'flash-outline',
                    'flow-children',
                    'flow-merge',
                    'flow-parallel',
                    'flow-switch',
                    'folder',
                    'folder-add',
                    'folder-delete',
                    'gift',
                    'globe',
                    'globe-outline',
                    'group',
                    'group-outline',
                    'headphones',
                    'heart',
                    'heart-outline',
                    'home',
                    'home-outline',
                    'image',
                    'image-outline',
                    'infinity',
                    'infinity-outline',
                    'info',
                    'info-large',
                    'info-large-outline',
                    'info-outline',
                    'input-checked',
                    'input-checked-outline',
                    'key',
                    'key-outline',
                    'leaf',
                    'lightbulb',
                    'link',
                    'link-outline',
                    'location',
                    'location-arrow',
                    'location-arrow-outline',
                    'location-outline',
                    'lock-closed',
                    'lock-closed-outline',
                    'lock-open',
                    'lock-open-outline',
                    'mail',
                    'map',
                    'media-eject',
                    'media-eject-outline',
                    'media-fast-forward',
                    'media-fast-forward-outline',
                    'media-pause',
                    'media-pause-outline',
                    'media-play',
                    'media-play-outline',
                    'media-record',
                    'media-record-outline',
                    'media-rewind',
                    'media-rewind-outline',
                    'media-stop',
                    'media-stop-outline',
                    'message',
                    'messages',
                    'message-typing',
                    'microphone',
                    'microphone-outline',
                    'minus',
                    'minus-outline',
                    'news',
                    'notes',
                    'notes-outline',
                    'pen',
                    'pencil',
                    'phone',
                    'phone-outline',
                    'pi',
                    'pin',
                    'pin-outline',
                    'pi-outline',
                    'pipette',
                    'plane',
                    'plane-outline',
                    'plug',
                    'plus',
                    'plus-outline',
                    'point-of-interest',
                    'point-of-interest-outline',
                    'power',
                    'power-outline',
                    'printer',
                    'puzzle',
                    'puzzle-outline',
                    'radar',
                    'radar-outline',
                    'refresh',
                    'refresh-outline',
                    'rss',
                    'rss-outline',
                    'scissors',
                    'scissors-outline',
                    'shopping-bag',
                    'shopping-cart',
                    'social-at-circular',
                    'social-dribbble',
                    'social-dribbble-circular',
                    'social-facebook',
                    'social-facebook-circular',
                    'social-flickr',
                    'social-flickr-circular',
                    'social-github',
                    'social-github-circular',
                    'social-last-fm',
                    'social-last-fm-circular',
                    'social-linkedin',
                    'social-linkedin-circular',
                    'social-pinterest',
                    'social-pinterest-circular',
                    'social-skype',
                    'social-skype-outline',
                    'social-tumbler',
                    'social-tumbler-circular',
                    'social-twitter',
                    'social-twitter-circular',
                    'social-vimeo',
                    'social-vimeo-circular',
                    'sort-alphabetically',
                    'sort-alphabetically-outline',
                    'sort-numerically',
                    'sort-numerically-outline',
                    'spanner',
                    'spanner-outline',
                    'star',
                    'starburst',
                    'starburst-outline',
                    'star-outline',
                    'stopwatch',
                    'support',
                    'tabs-outline',
                    'tag',
                    'tags',
                    'thermometer',
                    'th-large',
                    'th-large-outline',
                    'th-list',
                    'th-list-outline',
                    'th-menu',
                    'th-menu-outline',
                    'th-small',
                    'th-small-outline',
                    'thumbs-down',
                    'thumbs-up',
                    'tick',
                    'ticket',
                    'tick-outline',
                    'time',
                    'times',
                    'times-outline',
                    'trash',
                    'tree',
                    'upload',
                    'upload-outline',
                    'user',
                    'user-add',
                    'user-add-outline',
                    'user-delete',
                    'user-delete-outline',
                    'user-outline',
                    'video',
                    'video-outline',
                    'volume',
                    'volume-down',
                    'volume-mute',
                    'volume-up',
                    'warning',
                    'warning-outline',
                    'watch',
                    'waves',
                    'waves-outline',
                    'weather-cloudy',
                    'weather-downpour',
                    'weather-night',
                    'weather-partly-sunny',
                    'weather-shower',
                    'weather-snow',
                    'weather-stormy',
                    'weather-sunny',
                    'weather-windy',
                    'weather-windy-cloudy',
                    'wi-fi',
                    'wi-fi-outline',
                    'wine',
                    'world',
                    'world-outline',
                    'zoom',
                    'zoom-in',
                    'zoom-in-outline',
                    'zoom-out',
                    'zoom-outline',
                    'zoom-out-outline'
                ]
            },
            {
                version: '2.0.2',
                icons: [
                    '',
                    'adjust-brightness',
                    'adjust-contrast',
                    'anchor',
                    'anchor-outline',
                    'archive',
                    'arrow-back',
                    'arrow-back-outline',
                    'arrow-down',
                    'arrow-down-outline',
                    'arrow-down-thick',
                    'arrow-forward',
                    'arrow-forward-outline',
                    'arrow-left',
                    'arrow-left-outline',
                    'arrow-left-thick',
                    'arrow-loop',
                    'arrow-loop-outline',
                    'arrow-maximise',
                    'arrow-maximise-outline',
                    'arrow-minimise',
                    'arrow-minimise-outline',
                    'arrow-move',
                    'arrow-move-outline',
                    'arrow-repeat',
                    'arrow-repeat-outline',
                    'arrow-right',
                    'arrow-right-outline',
                    'arrow-right-thick',
                    'arrow-shuffle',
                    'arrow-sync',
                    'arrow-sync-outline',
                    'arrow-up',
                    'arrow-up-outline',
                    'arrow-up-thick',
                    'at',
                    'attachment',
                    'attachment-outline',
                    'backspace',
                    'backspace-outline',
                    'battery-charge',
                    'battery-full',
                    'battery-high',
                    'battery-low',
                    'battery-mid',
                    'beaker',
                    'beer',
                    'bell',
                    'book',
                    'bookmark',
                    'briefcase',
                    'brush',
                    'business-card',
                    'calculator',
                    'calender',
                    'calender-outline',
                    'camera',
                    'camera-outline',
                    'cancel',
                    'cancel-outline',
                    'chart-area',
                    'chart-area-outline',
                    'chart-bar',
                    'chart-bar-outline',
                    'chart-line',
                    'chart-line-outline',
                    'chart-pie',
                    'chart-pie-outline',
                    'chevron-left',
                    'chevron-left-outline',
                    'chevron-right',
                    'chevron-right-outline',
                    'clipboard',
                    'cloud-storage',
                    'code',
                    'code-outline',
                    'coffee',
                    'cog',
                    'cog-outline',
                    'compass',
                    'contacts',
                    'credit-card',
                    'cross',
                    'database',
                    'delete',
                    'delete-outline',
                    'device-desktop',
                    'device-laptop',
                    'device-phone',
                    'device-tablet',
                    'directions',
                    'divide',
                    'divide-outline',
                    'document',
                    'document-add',
                    'document-delete',
                    'document-text',
                    'download',
                    'download-outline',
                    'edit',
                    'eject',
                    'eject-outline',
                    'equals',
                    'equals-outline',
                    'export',
                    'export-outline',
                    'eye',
                    'eye-outline',
                    'feather',
                    'film',
                    'flag',
                    'flag-outline',
                    'flash',
                    'flash-outline',
                    'flow-children',
                    'flow-merge',
                    'flow-parallel',
                    'flow-switch',
                    'folder',
                    'folder-add',
                    'folder-delete',
                    'gift',
                    'globe',
                    'globe-outline',
                    'group',
                    'group-outline',
                    'headphones',
                    'heart',
                    'heart-outline',
                    'home',
                    'home-outline',
                    'image',
                    'image-outline',
                    'infinity',
                    'infinity-outline',
                    'info',
                    'info-large',
                    'info-large-outline',
                    'info-outline',
                    'input-checked',
                    'input-checked-outline',
                    'key',
                    'key-outline',
                    'leaf',
                    'lightbulb',
                    'link',
                    'link-outline',
                    'location',
                    'location-arrow',
                    'location-arrow-outline',
                    'location-outline',
                    'lock-closed',
                    'lock-closed-outline',
                    'lock-open',
                    'lock-open-outline',
                    'mail',
                    'map',
                    'media-eject',
                    'media-eject-outline',
                    'media-fast-forward',
                    'media-fast-forward-outline',
                    'media-pause',
                    'media-pause-outline',
                    'media-play',
                    'media-play-outline',
                    'media-record',
                    'media-record-outline',
                    'media-rewind',
                    'media-rewind-outline',
                    'media-stop',
                    'media-stop-outline',
                    'message',
                    'messages',
                    'message-typing',
                    'microphone',
                    'microphone-outline',
                    'minus',
                    'minus-outline',
                    'news',
                    'notes',
                    'notes-outline',
                    'pen',
                    'pencil',
                    'phone',
                    'phone-outline',
                    'pi',
                    'pin',
                    'pin-outline',
                    'pi-outline',
                    'pipette',
                    'plane',
                    'plane-outline',
                    'plug',
                    'plus',
                    'plus-outline',
                    'point-of-interest',
                    'point-of-interest-outline',
                    'power',
                    'power-outline',
                    'printer',
                    'puzzle',
                    'puzzle-outline',
                    'radar',
                    'radar-outline',
                    'refresh',
                    'refresh-outline',
                    'rss',
                    'rss-outline',
                    'scissors',
                    'scissors-outline',
                    'shopping-bag',
                    'shopping-cart',
                    'social-at-circular',
                    'social-dribbble',
                    'social-dribbble-circular',
                    'social-facebook',
                    'social-facebook-circular',
                    'social-flickr',
                    'social-flickr-circular',
                    'social-github',
                    'social-github-circular',
                    'social-last-fm',
                    'social-last-fm-circular',
                    'social-linkedin',
                    'social-linkedin-circular',
                    'social-pinterest',
                    'social-pinterest-circular',
                    'social-skype',
                    'social-skype-outline',
                    'social-tumbler',
                    'social-tumbler-circular',
                    'social-twitter',
                    'social-twitter-circular',
                    'social-vimeo',
                    'social-vimeo-circular',
                    'sort-alphabetically',
                    'sort-alphabetically-outline',
                    'sort-numerically',
                    'sort-numerically-outline',
                    'spanner',
                    'spanner-outline',
                    'star',
                    'starburst',
                    'starburst-outline',
                    'star-outline',
                    'stopwatch',
                    'support',
                    'tabs-outline',
                    'tag',
                    'tags',
                    'thermometer',
                    'th-large',
                    'th-large-outline',
                    'th-list',
                    'th-list-outline',
                    'th-menu',
                    'th-menu-outline',
                    'th-small',
                    'th-small-outline',
                    'thumbs-down',
                    'thumbs-up',
                    'tick',
                    'ticket',
                    'tick-outline',
                    'time',
                    'times',
                    'times-outline',
                    'trash',
                    'tree',
                    'upload',
                    'upload-outline',
                    'user',
                    'user-add',
                    'user-add-outline',
                    'user-delete',
                    'user-delete-outline',
                    'user-outline',
                    'video',
                    'video-outline',
                    'volume',
                    'volume-down',
                    'volume-mute',
                    'volume-up',
                    'warning',
                    'warning-outline',
                    'watch',
                    'waves',
                    'waves-outline',
                    'weather-cloudy',
                    'weather-downpour',
                    'weather-night',
                    'weather-partly-sunny',
                    'weather-shower',
                    'weather-snow',
                    'weather-stormy',
                    'weather-sunny',
                    'weather-windy',
                    'weather-windy-cloudy',
                    'wi-fi',
                    'wi-fi-outline',
                    'wine',
                    'world',
                    'world-outline',
                    'zoom',
                    'zoom-in',
                    'zoom-in-outline',
                    'zoom-out',
                    'zoom-outline',
                    'zoom-out-outline'
                ]
            },
            {
                version: '2.0.3',
                icons: [
                    '',
                    'adjust-brightness',
                    'adjust-contrast',
                    'anchor',
                    'anchor-outline',
                    'archive',
                    'arrow-back',
                    'arrow-back-outline',
                    'arrow-down',
                    'arrow-down-outline',
                    'arrow-down-thick',
                    'arrow-forward',
                    'arrow-forward-outline',
                    'arrow-left',
                    'arrow-left-outline',
                    'arrow-left-thick',
                    'arrow-loop',
                    'arrow-loop-outline',
                    'arrow-maximise',
                    'arrow-maximise-outline',
                    'arrow-minimise',
                    'arrow-minimise-outline',
                    'arrow-move',
                    'arrow-move-outline',
                    'arrow-repeat',
                    'arrow-repeat-outline',
                    'arrow-right',
                    'arrow-right-outline',
                    'arrow-right-thick',
                    'arrow-shuffle',
                    'arrow-sorted-down',
                    'arrow-sorted-up',
                    'arrow-sync',
                    'arrow-sync-outline',
                    'arrow-unsorted',
                    'arrow-up',
                    'arrow-up-outline',
                    'arrow-up-thick',
                    'at',
                    'attachment',
                    'attachment-outline',
                    'backspace',
                    'backspace-outline',
                    'battery-charge',
                    'battery-full',
                    'battery-high',
                    'battery-low',
                    'battery-mid',
                    'beaker',
                    'beer',
                    'bell',
                    'book',
                    'bookmark',
                    'briefcase',
                    'brush',
                    'business-card',
                    'calculator',
                    'camera',
                    'camera-outline',
                    'cancel',
                    'cancel-outline',
                    'chart-area',
                    'chart-area-outline',
                    'chart-bar',
                    'chart-bar-outline',
                    'chart-line',
                    'chart-line-outline',
                    'chart-pie',
                    'chart-pie-outline',
                    'chevron-left',
                    'chevron-left-outline',
                    'chevron-right',
                    'chevron-right-outline',
                    'clipboard',
                    'cloud-storage',
                    'code',
                    'code-outline',
                    'coffee',
                    'cog',
                    'cog-outline',
                    'compass',
                    'contacts',
                    'credit-card',
                    'css3',
                    'database',
                    'delete',
                    'delete-outline',
                    'device-desktop',
                    'device-laptop',
                    'device-phone',
                    'device-tablet',
                    'directions',
                    'divide',
                    'divide-outline',
                    'document',
                    'document-add',
                    'document-delete',
                    'document-text',
                    'download',
                    'download-outline',
                    'dropbox',
                    'edit',
                    'eject',
                    'eject-outline',
                    'equals',
                    'equals-outline',
                    'export',
                    'export-outline',
                    'eye',
                    'eye-outline',
                    'feather',
                    'film',
                    'filter',
                    'flag',
                    'flag-outline',
                    'flash',
                    'flash-outline',
                    'flow-children',
                    'flow-merge',
                    'flow-parallel',
                    'flow-switch',
                    'folder',
                    'folder-add',
                    'folder-delete',
                    'folder-open',
                    'gift',
                    'globe',
                    'globe-outline',
                    'group',
                    'group-outline',
                    'headphones',
                    'heart',
                    'heart-full-outline',
                    'heart-half-outline',
                    'heart-outline',
                    'home',
                    'home-outline',
                    'html5',
                    'image',
                    'image-outline',
                    'infinity',
                    'infinity-outline',
                    'info',
                    'info-large',
                    'info-large-outline',
                    'info-outline',
                    'input-checked',
                    'input-checked-outline',
                    'key',
                    'key-outline',
                    'keyboard',
                    'leaf',
                    'lightbulb',
                    'link',
                    'link-outline',
                    'location',
                    'location-arrow',
                    'location-arrow-outline',
                    'location-outline',
                    'lock-closed',
                    'lock-closed-outline',
                    'lock-open',
                    'lock-open-outline',
                    'mail',
                    'map',
                    'media-eject',
                    'media-eject-outline',
                    'media-fast-forward',
                    'media-fast-forward-outline',
                    'media-pause',
                    'media-pause-outline',
                    'media-play',
                    'media-play-outline',
                    'media-play-reverse',
                    'media-play-reverse-outline',
                    'media-record',
                    'media-record-outline',
                    'media-rewind',
                    'media-rewind-outline',
                    'media-stop',
                    'media-stop-outline',
                    'message',
                    'message-typing',
                    'messages',
                    'microphone',
                    'microphone-outline',
                    'minus',
                    'minus-outline',
                    'mortar-board',
                    'news',
                    'notes',
                    'notes-outline',
                    'pen',
                    'pencil',
                    'phone',
                    'phone-outline',
                    'pi',
                    'pi-outline',
                    'pin',
                    'pin-outline',
                    'pipette',
                    'plane',
                    'plane-outline',
                    'plug',
                    'plus',
                    'plus-outline',
                    'point-of-interest',
                    'point-of-interest-outline',
                    'power',
                    'power-outline',
                    'printer',
                    'puzzle',
                    'puzzle-outline',
                    'radar',
                    'radar-outline',
                    'refresh',
                    'refresh-outline',
                    'rss',
                    'rss-outline',
                    'scissors',
                    'scissors-outline',
                    'shopping-bag',
                    'shopping-cart',
                    'social-at-circular',
                    'social-dribbble',
                    'social-dribbble-circular',
                    'social-facebook',
                    'social-facebook-circular',
                    'social-flickr',
                    'social-flickr-circular',
                    'social-github',
                    'social-github-circular',
                    'social-google-plus',
                    'social-google-plus-circular',
                    'social-instagram',
                    'social-instagram-circular',
                    'social-last-fm',
                    'social-last-fm-circular',
                    'social-linkedin',
                    'social-linkedin-circular',
                    'social-pinterest',
                    'social-pinterest-circular',
                    'social-skype',
                    'social-skype-outline',
                    'social-tumbler',
                    'social-tumbler-circular',
                    'social-twitter',
                    'social-twitter-circular',
                    'social-vimeo',
                    'social-vimeo-circular',
                    'social-youtube',
                    'social-youtube-circular',
                    'sort-alphabetically',
                    'sort-alphabetically-outline',
                    'sort-numerically',
                    'sort-numerically-outline',
                    'spanner',
                    'spanner-outline',
                    'spiral',
                    'star',
                    'star-full-outline',
                    'star-half',
                    'star-half-outline',
                    'star-outline',
                    'starburst',
                    'starburst-outline',
                    'stopwatch',
                    'support',
                    'tabs-outline',
                    'tag',
                    'tags',
                    'th-large',
                    'th-large-outline',
                    'th-list',
                    'th-list-outline',
                    'th-menu',
                    'th-menu-outline',
                    'th-small',
                    'th-small-outline',
                    'thermometer',
                    'thumbs-down',
                    'thumbs-ok',
                    'thumbs-up',
                    'tick',
                    'tick-outline',
                    'ticket',
                    'time',
                    'times',
                    'times-outline',
                    'trash',
                    'tree',
                    'upload',
                    'upload-outline',
                    'user',
                    'user-add',
                    'user-add-outline',
                    'user-delete',
                    'user-delete-outline',
                    'user-outline',
                    'vendor-android',
                    'vendor-apple',
                    'vendor-microsoft',
                    'video',
                    'video-outline',
                    'volume',
                    'volume-down',
                    'volume-mute',
                    'volume-up',
                    'warning',
                    'warning-outline',
                    'watch',
                    'waves',
                    'waves-outline',
                    'weather-cloudy',
                    'weather-downpour',
                    'weather-night',
                    'weather-partly-sunny',
                    'weather-shower',
                    'weather-snow',
                    'weather-stormy',
                    'weather-sunny',
                    'weather-windy',
                    'weather-windy-cloudy',
                    'wi-fi',
                    'wi-fi-outline',
                    'wine',
                    'world',
                    'world-outline',
                    'zoom',
                    'zoom-in',
                    'zoom-in-outline',
                    'zoom-out',
                    'zoom-out-outline',
                    'zoom-outline'
                ]
            },
            {
                version: '2.0.4',
                icons: [
                    '',
                    'adjust-brightness',
                    'adjust-contrast',
                    'anchor',
                    'anchor-outline',
                    'archive',
                    'arrow-back',
                    'arrow-back-outline',
                    'arrow-down',
                    'arrow-down-outline',
                    'arrow-down-thick',
                    'arrow-forward',
                    'arrow-forward-outline',
                    'arrow-left',
                    'arrow-left-outline',
                    'arrow-left-thick',
                    'arrow-loop',
                    'arrow-loop-outline',
                    'arrow-maximise',
                    'arrow-maximise-outline',
                    'arrow-minimise',
                    'arrow-minimise-outline',
                    'arrow-move',
                    'arrow-move-outline',
                    'arrow-repeat',
                    'arrow-repeat-outline',
                    'arrow-right',
                    'arrow-right-outline',
                    'arrow-right-thick',
                    'arrow-shuffle',
                    'arrow-sorted-down',
                    'arrow-sorted-up',
                    'arrow-sync',
                    'arrow-sync-outline',
                    'arrow-unsorted',
                    'arrow-up',
                    'arrow-up-outline',
                    'arrow-up-thick',
                    'at',
                    'attachment',
                    'attachment-outline',
                    'backspace',
                    'backspace-outline',
                    'battery-charge',
                    'battery-full',
                    'battery-high',
                    'battery-low',
                    'battery-mid',
                    'beaker',
                    'beer',
                    'bell',
                    'book',
                    'bookmark',
                    'briefcase',
                    'brush',
                    'business-card',
                    'calculator',
                    'calendar',
                    'calendar-outline',
                    'camera',
                    'camera-outline',
                    'cancel',
                    'cancel-outline',
                    'chart-area',
                    'chart-area-outline',
                    'chart-bar',
                    'chart-bar-outline',
                    'chart-line',
                    'chart-line-outline',
                    'chart-pie',
                    'chart-pie-outline',
                    'chevron-left',
                    'chevron-left-outline',
                    'chevron-right',
                    'chevron-right-outline',
                    'clipboard',
                    'cloud-storage',
                    'cloud-storage-outline',
                    'code',
                    'code-outline',
                    'coffee',
                    'cog',
                    'cog-outline',
                    'compass',
                    'contacts',
                    'credit-card',
                    'css3',
                    'database',
                    'delete',
                    'delete-outline',
                    'device-desktop',
                    'device-laptop',
                    'device-phone',
                    'device-tablet',
                    'directions',
                    'divide',
                    'divide-outline',
                    'document',
                    'document-add',
                    'document-delete',
                    'document-text',
                    'download',
                    'download-outline',
                    'dropbox',
                    'edit',
                    'eject',
                    'eject-outline',
                    'equals',
                    'equals-outline',
                    'export',
                    'export-outline',
                    'eye',
                    'eye-outline',
                    'feather',
                    'film',
                    'filter',
                    'flag',
                    'flag-outline',
                    'flash',
                    'flash-outline',
                    'flow-children',
                    'flow-merge',
                    'flow-parallel',
                    'flow-switch',
                    'folder',
                    'folder-add',
                    'folder-delete',
                    'folder-open',
                    'gift',
                    'globe',
                    'globe-outline',
                    'group',
                    'group-outline',
                    'headphones',
                    'heart',
                    'heart-full-outline',
                    'heart-half-outline',
                    'heart-outline',
                    'home',
                    'home-outline',
                    'html5',
                    'image',
                    'image-outline',
                    'infinity',
                    'infinity-outline',
                    'info',
                    'info-large',
                    'info-large-outline',
                    'info-outline',
                    'input-checked',
                    'input-checked-outline',
                    'key',
                    'key-outline',
                    'keyboard',
                    'leaf',
                    'lightbulb',
                    'link',
                    'link-outline',
                    'location',
                    'location-arrow',
                    'location-arrow-outline',
                    'location-outline',
                    'lock-closed',
                    'lock-closed-outline',
                    'lock-open',
                    'lock-open-outline',
                    'mail',
                    'map',
                    'media-eject',
                    'media-eject-outline',
                    'media-fast-forward',
                    'media-fast-forward-outline',
                    'media-pause',
                    'media-pause-outline',
                    'media-play',
                    'media-play-outline',
                    'media-play-reverse',
                    'media-play-reverse-outline',
                    'media-record',
                    'media-record-outline',
                    'media-rewind',
                    'media-rewind-outline',
                    'media-stop',
                    'media-stop-outline',
                    'message',
                    'message-typing',
                    'messages',
                    'microphone',
                    'microphone-outline',
                    'minus',
                    'minus-outline',
                    'mortar-board',
                    'news',
                    'notes',
                    'notes-outline',
                    'pen',
                    'pencil',
                    'phone',
                    'phone-outline',
                    'pi',
                    'pi-outline',
                    'pin',
                    'pin-outline',
                    'pipette',
                    'plane',
                    'plane-outline',
                    'plug',
                    'plus',
                    'plus-outline',
                    'point-of-interest',
                    'point-of-interest-outline',
                    'power',
                    'power-outline',
                    'printer',
                    'puzzle',
                    'puzzle-outline',
                    'radar',
                    'radar-outline',
                    'refresh',
                    'refresh-outline',
                    'rss',
                    'rss-outline',
                    'scissors',
                    'scissors-outline',
                    'shopping-bag',
                    'shopping-cart',
                    'social-at-circular',
                    'social-dribbble',
                    'social-dribbble-circular',
                    'social-facebook',
                    'social-facebook-circular',
                    'social-flickr',
                    'social-flickr-circular',
                    'social-github',
                    'social-github-circular',
                    'social-google-plus',
                    'social-google-plus-circular',
                    'social-instagram',
                    'social-instagram-circular',
                    'social-last-fm',
                    'social-last-fm-circular',
                    'social-linkedin',
                    'social-linkedin-circular',
                    'social-pinterest',
                    'social-pinterest-circular',
                    'social-skype',
                    'social-skype-outline',
                    'social-tumbler',
                    'social-tumbler-circular',
                    'social-twitter',
                    'social-twitter-circular',
                    'social-vimeo',
                    'social-vimeo-circular',
                    'social-youtube',
                    'social-youtube-circular',
                    'sort-alphabetically',
                    'sort-alphabetically-outline',
                    'sort-numerically',
                    'sort-numerically-outline',
                    'spanner',
                    'spanner-outline',
                    'spiral',
                    'star',
                    'star-full-outline',
                    'star-half',
                    'star-half-outline',
                    'star-outline',
                    'starburst',
                    'starburst-outline',
                    'stopwatch',
                    'support',
                    'tabs-outline',
                    'tag',
                    'tags',
                    'th-large',
                    'th-large-outline',
                    'th-list',
                    'th-list-outline',
                    'th-menu',
                    'th-menu-outline',
                    'th-small',
                    'th-small-outline',
                    'thermometer',
                    'thumbs-down',
                    'thumbs-ok',
                    'thumbs-up',
                    'tick',
                    'tick-outline',
                    'ticket',
                    'time',
                    'times',
                    'times-outline',
                    'trash',
                    'tree',
                    'upload',
                    'upload-outline',
                    'user',
                    'user-add',
                    'user-add-outline',
                    'user-delete',
                    'user-delete-outline',
                    'user-outline',
                    'vendor-android',
                    'vendor-apple',
                    'vendor-microsoft',
                    'video',
                    'video-outline',
                    'volume',
                    'volume-down',
                    'volume-mute',
                    'volume-up',
                    'warning',
                    'warning-outline',
                    'watch',
                    'waves',
                    'waves-outline',
                    'weather-cloudy',
                    'weather-downpour',
                    'weather-night',
                    'weather-partly-sunny',
                    'weather-shower',
                    'weather-snow',
                    'weather-stormy',
                    'weather-sunny',
                    'weather-windy',
                    'weather-windy-cloudy',
                    'wi-fi',
                    'wi-fi-outline',
                    'wine',
                    'world',
                    'world-outline',
                    'zoom',
                    'zoom-in',
                    'zoom-in-outline',
                    'zoom-out',
                    'zoom-out-outline',
                    'zoom-outline'
                ]
            },
            {
                version: '2.0.5',
                icons: [
                    '',
                    'adjust-brightness',
                    'adjust-contrast',
                    'anchor',
                    'anchor-outline',
                    'archive',
                    'arrow-back',
                    'arrow-back-outline',
                    'arrow-down',
                    'arrow-down-outline',
                    'arrow-down-thick',
                    'arrow-forward',
                    'arrow-forward-outline',
                    'arrow-left',
                    'arrow-left-outline',
                    'arrow-left-thick',
                    'arrow-loop',
                    'arrow-loop-outline',
                    'arrow-maximise',
                    'arrow-maximise-outline',
                    'arrow-minimise',
                    'arrow-minimise-outline',
                    'arrow-move',
                    'arrow-move-outline',
                    'arrow-repeat',
                    'arrow-repeat-outline',
                    'arrow-right',
                    'arrow-right-outline',
                    'arrow-right-thick',
                    'arrow-shuffle',
                    'arrow-sorted-down',
                    'arrow-sorted-up',
                    'arrow-sync',
                    'arrow-sync-outline',
                    'arrow-unsorted',
                    'arrow-up',
                    'arrow-up-outline',
                    'arrow-up-thick',
                    'at',
                    'attachment',
                    'attachment-outline',
                    'backspace',
                    'backspace-outline',
                    'battery-charge',
                    'battery-full',
                    'battery-high',
                    'battery-low',
                    'battery-mid',
                    'beaker',
                    'beer',
                    'bell',
                    'book',
                    'bookmark',
                    'briefcase',
                    'brush',
                    'business-card',
                    'calculator',
                    'camera',
                    'camera-outline',
                    'cancel',
                    'cancel-outline',
                    'chart-area',
                    'chart-area-outline',
                    'chart-bar',
                    'chart-bar-outline',
                    'chart-line',
                    'chart-line-outline',
                    'chart-pie',
                    'chart-pie-outline',
                    'chevron-left',
                    'chevron-left-outline',
                    'chevron-right',
                    'chevron-right-outline',
                    'clipboard',
                    'cloud-storage',
                    'code',
                    'code-outline',
                    'coffee',
                    'cog',
                    'cog-outline',
                    'compass',
                    'contacts',
                    'credit-card',
                    'css3',
                    'database',
                    'delete',
                    'delete-outline',
                    'device-desktop',
                    'device-laptop',
                    'device-phone',
                    'device-tablet',
                    'directions',
                    'divide',
                    'divide-outline',
                    'document',
                    'document-add',
                    'document-delete',
                    'document-text',
                    'download',
                    'download-outline',
                    'dropbox',
                    'edit',
                    'eject',
                    'eject-outline',
                    'equals',
                    'equals-outline',
                    'export',
                    'export-outline',
                    'eye',
                    'eye-outline',
                    'feather',
                    'film',
                    'filter',
                    'flag',
                    'flag-outline',
                    'flash',
                    'flash-outline',
                    'flow-children',
                    'flow-merge',
                    'flow-parallel',
                    'flow-switch',
                    'folder',
                    'folder-add',
                    'folder-delete',
                    'folder-open',
                    'gift',
                    'globe',
                    'globe-outline',
                    'group',
                    'group-outline',
                    'headphones',
                    'heart',
                    'heart-full-outline',
                    'heart-half-outline',
                    'heart-outline',
                    'home',
                    'home-outline',
                    'html5',
                    'image',
                    'image-outline',
                    'infinity',
                    'infinity-outline',
                    'info',
                    'info-large',
                    'info-large-outline',
                    'info-outline',
                    'input-checked',
                    'input-checked-outline',
                    'key',
                    'key-outline',
                    'keyboard',
                    'leaf',
                    'lightbulb',
                    'link',
                    'link-outline',
                    'location',
                    'location-arrow',
                    'location-arrow-outline',
                    'location-outline',
                    'lock-closed',
                    'lock-closed-outline',
                    'lock-open',
                    'lock-open-outline',
                    'mail',
                    'map',
                    'media-eject',
                    'media-eject-outline',
                    'media-fast-forward',
                    'media-fast-forward-outline',
                    'media-pause',
                    'media-pause-outline',
                    'media-play',
                    'media-play-outline',
                    'media-play-reverse',
                    'media-play-reverse-outline',
                    'media-record',
                    'media-record-outline',
                    'media-rewind',
                    'media-rewind-outline',
                    'media-stop',
                    'media-stop-outline',
                    'message',
                    'message-typing',
                    'messages',
                    'microphone',
                    'microphone-outline',
                    'minus',
                    'minus-outline',
                    'mortar-board',
                    'news',
                    'notes',
                    'notes-outline',
                    'pen',
                    'pencil',
                    'phone',
                    'phone-outline',
                    'pi',
                    'pi-outline',
                    'pin',
                    'pin-outline',
                    'pipette',
                    'plane',
                    'plane-outline',
                    'plug',
                    'plus',
                    'plus-outline',
                    'point-of-interest',
                    'point-of-interest-outline',
                    'power',
                    'power-outline',
                    'printer',
                    'puzzle',
                    'puzzle-outline',
                    'radar',
                    'radar-outline',
                    'refresh',
                    'refresh-outline',
                    'rss',
                    'rss-outline',
                    'scissors',
                    'scissors-outline',
                    'shopping-bag',
                    'shopping-cart',
                    'social-at-circular',
                    'social-dribbble',
                    'social-dribbble-circular',
                    'social-facebook',
                    'social-facebook-circular',
                    'social-flickr',
                    'social-flickr-circular',
                    'social-github',
                    'social-github-circular',
                    'social-google-plus',
                    'social-google-plus-circular',
                    'social-instagram',
                    'social-instagram-circular',
                    'social-last-fm',
                    'social-last-fm-circular',
                    'social-linkedin',
                    'social-linkedin-circular',
                    'social-pinterest',
                    'social-pinterest-circular',
                    'social-skype',
                    'social-skype-outline',
                    'social-tumbler',
                    'social-tumbler-circular',
                    'social-twitter',
                    'social-twitter-circular',
                    'social-vimeo',
                    'social-vimeo-circular',
                    'social-youtube',
                    'social-youtube-circular',
                    'sort-alphabetically',
                    'sort-alphabetically-outline',
                    'sort-numerically',
                    'sort-numerically-outline',
                    'spanner',
                    'spanner-outline',
                    'spiral',
                    'star',
                    'star-full-outline',
                    'star-half',
                    'star-half-outline',
                    'star-outline',
                    'starburst',
                    'starburst-outline',
                    'stopwatch',
                    'support',
                    'tabs-outline',
                    'tag',
                    'tags',
                    'th-large',
                    'th-large-outline',
                    'th-list',
                    'th-list-outline',
                    'th-menu',
                    'th-menu-outline',
                    'th-small',
                    'th-small-outline',
                    'thermometer',
                    'thumbs-down',
                    'thumbs-ok',
                    'thumbs-up',
                    'tick',
                    'tick-outline',
                    'ticket',
                    'time',
                    'times',
                    'times-outline',
                    'trash',
                    'tree',
                    'upload',
                    'upload-outline',
                    'user',
                    'user-add',
                    'user-add-outline',
                    'user-delete',
                    'user-delete-outline',
                    'user-outline',
                    'vendor-android',
                    'vendor-apple',
                    'vendor-microsoft',
                    'video',
                    'video-outline',
                    'volume',
                    'volume-down',
                    'volume-mute',
                    'volume-up',
                    'warning',
                    'warning-outline',
                    'watch',
                    'waves',
                    'waves-outline',
                    'weather-cloudy',
                    'weather-downpour',
                    'weather-night',
                    'weather-partly-sunny',
                    'weather-shower',
                    'weather-snow',
                    'weather-stormy',
                    'weather-sunny',
                    'weather-windy',
                    'weather-windy-cloudy',
                    'wi-fi',
                    'wi-fi-outline',
                    'wine',
                    'world',
                    'world-outline',
                    'zoom',
                    'zoom-in',
                    'zoom-in-outline',
                    'zoom-out',
                    'zoom-out-outline',
                    'zoom-outline'
                ]
            },
            {
                version: '2.0.6',
                icons: [
                    '',
                    'adjust-brightness',
                    'adjust-contrast',
                    'anchor',
                    'anchor-outline',
                    'archive',
                    'arrow-back',
                    'arrow-back-outline',
                    'arrow-down',
                    'arrow-down-outline',
                    'arrow-down-thick',
                    'arrow-forward',
                    'arrow-forward-outline',
                    'arrow-left',
                    'arrow-left-outline',
                    'arrow-left-thick',
                    'arrow-loop',
                    'arrow-loop-outline',
                    'arrow-maximise',
                    'arrow-maximise-outline',
                    'arrow-minimise',
                    'arrow-minimise-outline',
                    'arrow-move',
                    'arrow-move-outline',
                    'arrow-repeat',
                    'arrow-repeat-outline',
                    'arrow-right',
                    'arrow-right-outline',
                    'arrow-right-thick',
                    'arrow-shuffle',
                    'arrow-sorted-down',
                    'arrow-sorted-up',
                    'arrow-sync',
                    'arrow-sync-outline',
                    'arrow-unsorted',
                    'arrow-up',
                    'arrow-up-outline',
                    'arrow-up-thick',
                    'at',
                    'attachment',
                    'attachment-outline',
                    'backspace',
                    'backspace-outline',
                    'battery-charge',
                    'battery-full',
                    'battery-high',
                    'battery-low',
                    'battery-mid',
                    'beaker',
                    'beer',
                    'bell',
                    'book',
                    'bookmark',
                    'briefcase',
                    'brush',
                    'business-card',
                    'calculator',
                    'calendar',
                    'calendar-outline',
                    'camera',
                    'camera-outline',
                    'cancel',
                    'cancel-outline',
                    'chart-area',
                    'chart-area-outline',
                    'chart-bar',
                    'chart-bar-outline',
                    'chart-line',
                    'chart-line-outline',
                    'chart-pie',
                    'chart-pie-outline',
                    'chevron-left',
                    'chevron-left-outline',
                    'chevron-right',
                    'chevron-right-outline',
                    'clipboard',
                    'cloud-storage',
                    'cloud-storage-outline',
                    'code',
                    'code-outline',
                    'coffee',
                    'cog',
                    'cog-outline',
                    'compass',
                    'contacts',
                    'credit-card',
                    'css3',
                    'database',
                    'delete',
                    'delete-outline',
                    'device-desktop',
                    'device-laptop',
                    'device-phone',
                    'device-tablet',
                    'directions',
                    'divide',
                    'divide-outline',
                    'document',
                    'document-add',
                    'document-delete',
                    'document-text',
                    'download',
                    'download-outline',
                    'dropbox',
                    'edit',
                    'eject',
                    'eject-outline',
                    'equals',
                    'equals-outline',
                    'export',
                    'export-outline',
                    'eye',
                    'eye-outline',
                    'feather',
                    'film',
                    'filter',
                    'flag',
                    'flag-outline',
                    'flash',
                    'flash-outline',
                    'flow-children',
                    'flow-merge',
                    'flow-parallel',
                    'flow-switch',
                    'folder',
                    'folder-add',
                    'folder-delete',
                    'folder-open',
                    'gift',
                    'globe',
                    'globe-outline',
                    'group',
                    'group-outline',
                    'headphones',
                    'heart',
                    'heart-full-outline',
                    'heart-half-outline',
                    'heart-outline',
                    'home',
                    'home-outline',
                    'html5',
                    'image',
                    'image-outline',
                    'infinity',
                    'infinity-outline',
                    'info',
                    'info-large',
                    'info-large-outline',
                    'info-outline',
                    'input-checked',
                    'input-checked-outline',
                    'key',
                    'key-outline',
                    'keyboard',
                    'leaf',
                    'lightbulb',
                    'link',
                    'link-outline',
                    'location',
                    'location-arrow',
                    'location-arrow-outline',
                    'location-outline',
                    'lock-closed',
                    'lock-closed-outline',
                    'lock-open',
                    'lock-open-outline',
                    'mail',
                    'map',
                    'media-eject',
                    'media-eject-outline',
                    'media-fast-forward',
                    'media-fast-forward-outline',
                    'media-pause',
                    'media-pause-outline',
                    'media-play',
                    'media-play-outline',
                    'media-play-reverse',
                    'media-play-reverse-outline',
                    'media-record',
                    'media-record-outline',
                    'media-rewind',
                    'media-rewind-outline',
                    'media-stop',
                    'media-stop-outline',
                    'message',
                    'message-typing',
                    'messages',
                    'microphone',
                    'microphone-outline',
                    'minus',
                    'minus-outline',
                    'mortar-board',
                    'news',
                    'notes',
                    'notes-outline',
                    'pen',
                    'pencil',
                    'phone',
                    'phone-outline',
                    'pi',
                    'pi-outline',
                    'pin',
                    'pin-outline',
                    'pipette',
                    'plane',
                    'plane-outline',
                    'plug',
                    'plus',
                    'plus-outline',
                    'point-of-interest',
                    'point-of-interest-outline',
                    'power',
                    'power-outline',
                    'printer',
                    'puzzle',
                    'puzzle-outline',
                    'radar',
                    'radar-outline',
                    'refresh',
                    'refresh-outline',
                    'rss',
                    'rss-outline',
                    'scissors',
                    'scissors-outline',
                    'shopping-bag',
                    'shopping-cart',
                    'social-at-circular',
                    'social-dribbble',
                    'social-dribbble-circular',
                    'social-facebook',
                    'social-facebook-circular',
                    'social-flickr',
                    'social-flickr-circular',
                    'social-github',
                    'social-github-circular',
                    'social-google-plus',
                    'social-google-plus-circular',
                    'social-instagram',
                    'social-instagram-circular',
                    'social-last-fm',
                    'social-last-fm-circular',
                    'social-linkedin',
                    'social-linkedin-circular',
                    'social-pinterest',
                    'social-pinterest-circular',
                    'social-skype',
                    'social-skype-outline',
                    'social-tumbler',
                    'social-tumbler-circular',
                    'social-twitter',
                    'social-twitter-circular',
                    'social-vimeo',
                    'social-vimeo-circular',
                    'social-youtube',
                    'social-youtube-circular',
                    'sort-alphabetically',
                    'sort-alphabetically-outline',
                    'sort-numerically',
                    'sort-numerically-outline',
                    'spanner',
                    'spanner-outline',
                    'spiral',
                    'star',
                    'star-full-outline',
                    'star-half',
                    'star-half-outline',
                    'star-outline',
                    'starburst',
                    'starburst-outline',
                    'stopwatch',
                    'support',
                    'tabs-outline',
                    'tag',
                    'tags',
                    'th-large',
                    'th-large-outline',
                    'th-list',
                    'th-list-outline',
                    'th-menu',
                    'th-menu-outline',
                    'th-small',
                    'th-small-outline',
                    'thermometer',
                    'thumbs-down',
                    'thumbs-ok',
                    'thumbs-up',
                    'tick',
                    'tick-outline',
                    'ticket',
                    'time',
                    'times',
                    'times-outline',
                    'trash',
                    'tree',
                    'upload',
                    'upload-outline',
                    'user',
                    'user-add',
                    'user-add-outline',
                    'user-delete',
                    'user-delete-outline',
                    'user-outline',
                    'vendor-android',
                    'vendor-apple',
                    'vendor-microsoft',
                    'video',
                    'video-outline',
                    'volume',
                    'volume-down',
                    'volume-mute',
                    'volume-up',
                    'warning',
                    'warning-outline',
                    'watch',
                    'waves',
                    'waves-outline',
                    'weather-cloudy',
                    'weather-downpour',
                    'weather-night',
                    'weather-partly-sunny',
                    'weather-shower',
                    'weather-snow',
                    'weather-stormy',
                    'weather-sunny',
                    'weather-windy',
                    'weather-windy-cloudy',
                    'wi-fi',
                    'wi-fi-outline',
                    'wine',
                    'world',
                    'world-outline',
                    'zoom',
                    'zoom-in',
                    'zoom-in-outline',
                    'zoom-out',
                    'zoom-out-outline',
                    'zoom-outline'
                ]
            },
            {
                version: '2.0.7',
                icons: [
                    '',
                    'adjust-brightness',
                    'adjust-contrast',
                    'anchor',
                    'anchor-outline',
                    'archive',
                    'arrow-back',
                    'arrow-back-outline',
                    'arrow-down',
                    'arrow-down-outline',
                    'arrow-down-thick',
                    'arrow-forward',
                    'arrow-forward-outline',
                    'arrow-left',
                    'arrow-left-outline',
                    'arrow-left-thick',
                    'arrow-loop',
                    'arrow-loop-outline',
                    'arrow-maximise',
                    'arrow-maximise-outline',
                    'arrow-minimise',
                    'arrow-minimise-outline',
                    'arrow-move',
                    'arrow-move-outline',
                    'arrow-repeat',
                    'arrow-repeat-outline',
                    'arrow-right',
                    'arrow-right-outline',
                    'arrow-right-thick',
                    'arrow-shuffle',
                    'arrow-sorted-down',
                    'arrow-sorted-up',
                    'arrow-sync',
                    'arrow-sync-outline',
                    'arrow-unsorted',
                    'arrow-up',
                    'arrow-up-outline',
                    'arrow-up-thick',
                    'at',
                    'attachment',
                    'attachment-outline',
                    'backspace',
                    'backspace-outline',
                    'battery-charge',
                    'battery-full',
                    'battery-high',
                    'battery-low',
                    'battery-mid',
                    'beaker',
                    'beer',
                    'bell',
                    'book',
                    'bookmark',
                    'briefcase',
                    'brush',
                    'business-card',
                    'calculator',
                    'calendar',
                    'calendar-outline',
                    'camera',
                    'camera-outline',
                    'cancel',
                    'cancel-outline',
                    'chart-area',
                    'chart-area-outline',
                    'chart-bar',
                    'chart-bar-outline',
                    'chart-line',
                    'chart-line-outline',
                    'chart-pie',
                    'chart-pie-outline',
                    'chevron-left',
                    'chevron-left-outline',
                    'chevron-right',
                    'chevron-right-outline',
                    'clipboard',
                    'cloud-storage',
                    'cloud-storage-outline',
                    'code',
                    'code-outline',
                    'coffee',
                    'cog',
                    'cog-outline',
                    'compass',
                    'contacts',
                    'credit-card',
                    'css3',
                    'database',
                    'delete',
                    'delete-outline',
                    'device-desktop',
                    'device-laptop',
                    'device-phone',
                    'device-tablet',
                    'directions',
                    'divide',
                    'divide-outline',
                    'document',
                    'document-add',
                    'document-delete',
                    'document-text',
                    'download',
                    'download-outline',
                    'dropbox',
                    'edit',
                    'eject',
                    'eject-outline',
                    'equals',
                    'equals-outline',
                    'export',
                    'export-outline',
                    'eye',
                    'eye-outline',
                    'feather',
                    'film',
                    'filter',
                    'flag',
                    'flag-outline',
                    'flash',
                    'flash-outline',
                    'flow-children',
                    'flow-merge',
                    'flow-parallel',
                    'flow-switch',
                    'folder',
                    'folder-add',
                    'folder-delete',
                    'folder-open',
                    'gift',
                    'globe',
                    'globe-outline',
                    'group',
                    'group-outline',
                    'headphones',
                    'heart',
                    'heart-full-outline',
                    'heart-half-outline',
                    'heart-outline',
                    'home',
                    'home-outline',
                    'html5',
                    'image',
                    'image-outline',
                    'infinity',
                    'infinity-outline',
                    'info',
                    'info-large',
                    'info-large-outline',
                    'info-outline',
                    'input-checked',
                    'input-checked-outline',
                    'key',
                    'keyboard',
                    'key-outline',
                    'leaf',
                    'lightbulb',
                    'link',
                    'link-outline',
                    'location',
                    'location-arrow',
                    'location-arrow-outline',
                    'location-outline',
                    'lock-closed',
                    'lock-closed-outline',
                    'lock-open',
                    'lock-open-outline',
                    'mail',
                    'map',
                    'media-eject',
                    'media-eject-outline',
                    'media-fast-forward',
                    'media-fast-forward-outline',
                    'media-pause',
                    'media-pause-outline',
                    'media-play',
                    'media-play-outline',
                    'media-play-reverse',
                    'media-play-reverse-outline',
                    'media-record',
                    'media-record-outline',
                    'media-rewind',
                    'media-rewind-outline',
                    'media-stop',
                    'media-stop-outline',
                    'message',
                    'messages',
                    'message-typing',
                    'microphone',
                    'microphone-outline',
                    'minus',
                    'minus-outline',
                    'mortar-board',
                    'news',
                    'notes',
                    'notes-outline',
                    'pen',
                    'pencil',
                    'phone',
                    'phone-outline',
                    'pi',
                    'pin',
                    'pin-outline',
                    'pi-outline',
                    'pipette',
                    'plane',
                    'plane-outline',
                    'plug',
                    'plus',
                    'plus-outline',
                    'point-of-interest',
                    'point-of-interest-outline',
                    'power',
                    'power-outline',
                    'printer',
                    'puzzle',
                    'puzzle-outline',
                    'radar',
                    'radar-outline',
                    'refresh',
                    'refresh-outline',
                    'rss',
                    'rss-outline',
                    'scissors',
                    'scissors-outline',
                    'shopping-bag',
                    'shopping-cart',
                    'social-at-circular',
                    'social-dribbble',
                    'social-dribbble-circular',
                    'social-facebook',
                    'social-facebook-circular',
                    'social-flickr',
                    'social-flickr-circular',
                    'social-github',
                    'social-github-circular',
                    'social-google-plus',
                    'social-google-plus-circular',
                    'social-instagram',
                    'social-instagram-circular',
                    'social-last-fm',
                    'social-last-fm-circular',
                    'social-linkedin',
                    'social-linkedin-circular',
                    'social-pinterest',
                    'social-pinterest-circular',
                    'social-skype',
                    'social-skype-outline',
                    'social-tumbler',
                    'social-tumbler-circular',
                    'social-twitter',
                    'social-twitter-circular',
                    'social-vimeo',
                    'social-vimeo-circular',
                    'social-youtube',
                    'social-youtube-circular',
                    'sort-alphabetically',
                    'sort-alphabetically-outline',
                    'sort-numerically',
                    'sort-numerically-outline',
                    'spanner',
                    'spanner-outline',
                    'spiral',
                    'star',
                    'starburst',
                    'starburst-outline',
                    'star-full-outline',
                    'star-half',
                    'star-half-outline',
                    'star-outline',
                    'stopwatch',
                    'support',
                    'tabs-outline',
                    'tag',
                    'tags',
                    'thermometer',
                    'th-large',
                    'th-large-outline',
                    'th-list',
                    'th-list-outline',
                    'th-menu',
                    'th-menu-outline',
                    'th-small',
                    'th-small-outline',
                    'thumbs-down',
                    'thumbs-ok',
                    'thumbs-up',
                    'tick',
                    'ticket',
                    'tick-outline',
                    'time',
                    'times',
                    'times-outline',
                    'trash',
                    'tree',
                    'upload',
                    'upload-outline',
                    'user',
                    'user-add',
                    'user-add-outline',
                    'user-delete',
                    'user-delete-outline',
                    'user-outline',
                    'vendor-android',
                    'vendor-apple',
                    'vendor-microsoft',
                    'video',
                    'video-outline',
                    'volume',
                    'volume-down',
                    'volume-mute',
                    'volume-up',
                    'warning',
                    'warning-outline',
                    'watch',
                    'waves',
                    'waves-outline',
                    'weather-cloudy',
                    'weather-downpour',
                    'weather-night',
                    'weather-partly-sunny',
                    'weather-shower',
                    'weather-snow',
                    'weather-stormy',
                    'weather-sunny',
                    'weather-windy',
                    'weather-windy-cloudy',
                    'wi-fi',
                    'wi-fi-outline',
                    'wine',
                    'world',
                    'world-outline',
                    'zoom',
                    'zoom-in',
                    'zoom-in-outline',
                    'zoom-out',
                    'zoom-outline',
                    'zoom-out-outline'
                ]
            },
            {
                version: '2.0.8',
                icons: [
                    '',
                    'adjust-brightness',
                    'adjust-contrast',
                    'anchor',
                    'anchor-outline',
                    'archive',
                    'arrow-back',
                    'arrow-back-outline',
                    'arrow-down',
                    'arrow-down-outline',
                    'arrow-down-thick',
                    'arrow-forward',
                    'arrow-forward-outline',
                    'arrow-left',
                    'arrow-left-outline',
                    'arrow-left-thick',
                    'arrow-loop',
                    'arrow-loop-outline',
                    'arrow-maximise',
                    'arrow-maximise-outline',
                    'arrow-minimise',
                    'arrow-minimise-outline',
                    'arrow-move',
                    'arrow-move-outline',
                    'arrow-repeat',
                    'arrow-repeat-outline',
                    'arrow-right',
                    'arrow-right-outline',
                    'arrow-right-thick',
                    'arrow-shuffle',
                    'arrow-sorted-down',
                    'arrow-sorted-up',
                    'arrow-sync',
                    'arrow-sync-outline',
                    'arrow-unsorted',
                    'arrow-up',
                    'arrow-up-outline',
                    'arrow-up-thick',
                    'at',
                    'attachment',
                    'attachment-outline',
                    'backspace',
                    'backspace-outline',
                    'battery-charge',
                    'battery-full',
                    'battery-high',
                    'battery-low',
                    'battery-mid',
                    'beaker',
                    'beer',
                    'bell',
                    'book',
                    'bookmark',
                    'briefcase',
                    'brush',
                    'business-card',
                    'calculator',
                    'calendar',
                    'calendar-outline',
                    'camera',
                    'camera-outline',
                    'cancel',
                    'cancel-outline',
                    'chart-area',
                    'chart-area-outline',
                    'chart-bar',
                    'chart-bar-outline',
                    'chart-line',
                    'chart-line-outline',
                    'chart-pie',
                    'chart-pie-outline',
                    'chevron-left',
                    'chevron-left-outline',
                    'chevron-right',
                    'chevron-right-outline',
                    'clipboard',
                    'cloud-storage',
                    'cloud-storage-outline',
                    'code',
                    'code-outline',
                    'coffee',
                    'cog',
                    'cog-outline',
                    'compass',
                    'contacts',
                    'credit-card',
                    'css3',
                    'database',
                    'delete',
                    'delete-outline',
                    'device-desktop',
                    'device-laptop',
                    'device-phone',
                    'device-tablet',
                    'directions',
                    'divide',
                    'divide-outline',
                    'document',
                    'document-add',
                    'document-delete',
                    'document-text',
                    'download',
                    'download-outline',
                    'dropbox',
                    'edit',
                    'eject',
                    'eject-outline',
                    'equals',
                    'equals-outline',
                    'export',
                    'export-outline',
                    'eye',
                    'eye-outline',
                    'feather',
                    'film',
                    'filter',
                    'flag',
                    'flag-outline',
                    'flash',
                    'flash-outline',
                    'flow-children',
                    'flow-merge',
                    'flow-parallel',
                    'flow-switch',
                    'folder',
                    'folder-add',
                    'folder-delete',
                    'folder-open',
                    'gift',
                    'globe',
                    'globe-outline',
                    'group',
                    'group-outline',
                    'headphones',
                    'heart',
                    'heart-full-outline',
                    'heart-half-outline',
                    'heart-outline',
                    'home',
                    'home-outline',
                    'html5',
                    'image',
                    'image-outline',
                    'infinity',
                    'infinity-outline',
                    'info',
                    'info-large',
                    'info-large-outline',
                    'info-outline',
                    'input-checked',
                    'input-checked-outline',
                    'key',
                    'keyboard',
                    'key-outline',
                    'leaf',
                    'lightbulb',
                    'link',
                    'link-outline',
                    'location',
                    'location-arrow',
                    'location-arrow-outline',
                    'location-outline',
                    'lock-closed',
                    'lock-closed-outline',
                    'lock-open',
                    'lock-open-outline',
                    'mail',
                    'map',
                    'media-eject',
                    'media-eject-outline',
                    'media-fast-forward',
                    'media-fast-forward-outline',
                    'media-pause',
                    'media-pause-outline',
                    'media-play',
                    'media-play-outline',
                    'media-play-reverse',
                    'media-play-reverse-outline',
                    'media-record',
                    'media-record-outline',
                    'media-rewind',
                    'media-rewind-outline',
                    'media-stop',
                    'media-stop-outline',
                    'message',
                    'messages',
                    'message-typing',
                    'microphone',
                    'microphone-outline',
                    'minus',
                    'minus-outline',
                    'mortar-board',
                    'news',
                    'notes',
                    'notes-outline',
                    'pen',
                    'pencil',
                    'phone',
                    'phone-outline',
                    'pi',
                    'pin',
                    'pin-outline',
                    'pi-outline',
                    'pipette',
                    'plane',
                    'plane-outline',
                    'plug',
                    'plus',
                    'plus-outline',
                    'point-of-interest',
                    'point-of-interest-outline',
                    'power',
                    'power-outline',
                    'printer',
                    'puzzle',
                    'puzzle-outline',
                    'radar',
                    'radar-outline',
                    'refresh',
                    'refresh-outline',
                    'rss',
                    'rss-outline',
                    'scissors',
                    'scissors-outline',
                    'shopping-bag',
                    'shopping-cart',
                    'social-at-circular',
                    'social-dribbble',
                    'social-dribbble-circular',
                    'social-facebook',
                    'social-facebook-circular',
                    'social-flickr',
                    'social-flickr-circular',
                    'social-github',
                    'social-github-circular',
                    'social-google-plus',
                    'social-google-plus-circular',
                    'social-instagram',
                    'social-instagram-circular',
                    'social-last-fm',
                    'social-last-fm-circular',
                    'social-linkedin',
                    'social-linkedin-circular',
                    'social-pinterest',
                    'social-pinterest-circular',
                    'social-skype',
                    'social-skype-outline',
                    'social-tumbler',
                    'social-tumbler-circular',
                    'social-twitter',
                    'social-twitter-circular',
                    'social-vimeo',
                    'social-vimeo-circular',
                    'social-youtube',
                    'social-youtube-circular',
                    'sort-alphabetically',
                    'sort-alphabetically-outline',
                    'sort-numerically',
                    'sort-numerically-outline',
                    'spanner',
                    'spanner-outline',
                    'spiral',
                    'star',
                    'starburst',
                    'starburst-outline',
                    'star-full-outline',
                    'star-half',
                    'star-half-outline',
                    'star-outline',
                    'stopwatch',
                    'support',
                    'tabs-outline',
                    'tag',
                    'tags',
                    'thermometer',
                    'th-large',
                    'th-large-outline',
                    'th-list',
                    'th-list-outline',
                    'th-menu',
                    'th-menu-outline',
                    'th-small',
                    'th-small-outline',
                    'thumbs-down',
                    'thumbs-ok',
                    'thumbs-up',
                    'tick',
                    'ticket',
                    'tick-outline',
                    'time',
                    'times',
                    'times-outline',
                    'trash',
                    'tree',
                    'upload',
                    'upload-outline',
                    'user',
                    'user-add',
                    'user-add-outline',
                    'user-delete',
                    'user-delete-outline',
                    'user-outline',
                    'vendor-android',
                    'vendor-apple',
                    'vendor-microsoft',
                    'video',
                    'video-outline',
                    'volume',
                    'volume-down',
                    'volume-mute',
                    'volume-up',
                    'warning',
                    'warning-outline',
                    'watch',
                    'waves',
                    'waves-outline',
                    'weather-cloudy',
                    'weather-downpour',
                    'weather-night',
                    'weather-partly-sunny',
                    'weather-shower',
                    'weather-snow',
                    'weather-stormy',
                    'weather-sunny',
                    'weather-windy',
                    'weather-windy-cloudy',
                    'wi-fi',
                    'wi-fi-outline',
                    'wine',
                    'world',
                    'world-outline',
                    'zoom',
                    'zoom-in',
                    'zoom-in-outline',
                    'zoom-out',
                    'zoom-outline',
                    'zoom-out-outline'
                ]
            },
            {
                version: '2.0.9',
                icons: [
                    '',
                    'adjust-brightness',
                    'adjust-contrast',
                    'anchor',
                    'anchor-outline',
                    'archive',
                    'arrow-back',
                    'arrow-back-outline',
                    'arrow-down',
                    'arrow-down-outline',
                    'arrow-down-thick',
                    'arrow-forward',
                    'arrow-forward-outline',
                    'arrow-left',
                    'arrow-left-outline',
                    'arrow-left-thick',
                    'arrow-loop',
                    'arrow-loop-outline',
                    'arrow-maximise',
                    'arrow-maximise-outline',
                    'arrow-minimise',
                    'arrow-minimise-outline',
                    'arrow-move',
                    'arrow-move-outline',
                    'arrow-repeat',
                    'arrow-repeat-outline',
                    'arrow-right',
                    'arrow-right-outline',
                    'arrow-right-thick',
                    'arrow-shuffle',
                    'arrow-sorted-down',
                    'arrow-sorted-up',
                    'arrow-sync',
                    'arrow-sync-outline',
                    'arrow-unsorted',
                    'arrow-up',
                    'arrow-up-outline',
                    'arrow-up-thick',
                    'at',
                    'attachment',
                    'attachment-outline',
                    'backspace',
                    'backspace-outline',
                    'battery-charge',
                    'battery-full',
                    'battery-high',
                    'battery-low',
                    'battery-mid',
                    'beaker',
                    'beer',
                    'bell',
                    'book',
                    'bookmark',
                    'briefcase',
                    'brush',
                    'business-card',
                    'calculator',
                    'calendar',
                    'calendar-outline',
                    'camera',
                    'camera-outline',
                    'cancel',
                    'cancel-outline',
                    'chart-area',
                    'chart-area-outline',
                    'chart-bar',
                    'chart-bar-outline',
                    'chart-line',
                    'chart-line-outline',
                    'chart-pie',
                    'chart-pie-outline',
                    'chevron-left',
                    'chevron-left-outline',
                    'chevron-right',
                    'chevron-right-outline',
                    'clipboard',
                    'cloud-storage',
                    'cloud-storage-outline',
                    'code',
                    'code-outline',
                    'coffee',
                    'cog',
                    'cog-outline',
                    'compass',
                    'contacts',
                    'credit-card',
                    'css3',
                    'database',
                    'delete',
                    'delete-outline',
                    'device-desktop',
                    'device-laptop',
                    'device-phone',
                    'device-tablet',
                    'directions',
                    'divide',
                    'divide-outline',
                    'document',
                    'document-add',
                    'document-delete',
                    'document-text',
                    'download',
                    'download-outline',
                    'dropbox',
                    'edit',
                    'eject',
                    'eject-outline',
                    'equals',
                    'equals-outline',
                    'export',
                    'export-outline',
                    'eye',
                    'eye-outline',
                    'feather',
                    'film',
                    'filter',
                    'flag',
                    'flag-outline',
                    'flash',
                    'flash-outline',
                    'flow-children',
                    'flow-merge',
                    'flow-parallel',
                    'flow-switch',
                    'folder',
                    'folder-add',
                    'folder-delete',
                    'folder-open',
                    'gift',
                    'globe',
                    'globe-outline',
                    'group',
                    'group-outline',
                    'headphones',
                    'heart',
                    'heart-full-outline',
                    'heart-half-outline',
                    'heart-outline',
                    'home',
                    'home-outline',
                    'html5',
                    'image',
                    'image-outline',
                    'infinity',
                    'infinity-outline',
                    'info',
                    'info-large',
                    'info-large-outline',
                    'info-outline',
                    'input-checked',
                    'input-checked-outline',
                    'key',
                    'keyboard',
                    'key-outline',
                    'leaf',
                    'lightbulb',
                    'link',
                    'link-outline',
                    'location',
                    'location-arrow',
                    'location-arrow-outline',
                    'location-outline',
                    'lock-closed',
                    'lock-closed-outline',
                    'lock-open',
                    'lock-open-outline',
                    'mail',
                    'map',
                    'media-eject',
                    'media-eject-outline',
                    'media-fast-forward',
                    'media-fast-forward-outline',
                    'media-pause',
                    'media-pause-outline',
                    'media-play',
                    'media-play-outline',
                    'media-play-reverse',
                    'media-play-reverse-outline',
                    'media-record',
                    'media-record-outline',
                    'media-rewind',
                    'media-rewind-outline',
                    'media-stop',
                    'media-stop-outline',
                    'message',
                    'messages',
                    'message-typing',
                    'microphone',
                    'microphone-outline',
                    'minus',
                    'minus-outline',
                    'mortar-board',
                    'news',
                    'notes',
                    'notes-outline',
                    'pen',
                    'pencil',
                    'phone',
                    'phone-outline',
                    'pi',
                    'pin',
                    'pin-outline',
                    'pi-outline',
                    'pipette',
                    'plane',
                    'plane-outline',
                    'plug',
                    'plus',
                    'plus-outline',
                    'point-of-interest',
                    'point-of-interest-outline',
                    'power',
                    'power-outline',
                    'printer',
                    'puzzle',
                    'puzzle-outline',
                    'radar',
                    'radar-outline',
                    'refresh',
                    'refresh-outline',
                    'rss',
                    'rss-outline',
                    'scissors',
                    'scissors-outline',
                    'shopping-bag',
                    'shopping-cart',
                    'social-at-circular',
                    'social-dribbble',
                    'social-dribbble-circular',
                    'social-facebook',
                    'social-facebook-circular',
                    'social-flickr',
                    'social-flickr-circular',
                    'social-github',
                    'social-github-circular',
                    'social-google-plus',
                    'social-google-plus-circular',
                    'social-instagram',
                    'social-instagram-circular',
                    'social-last-fm',
                    'social-last-fm-circular',
                    'social-linkedin',
                    'social-linkedin-circular',
                    'social-pinterest',
                    'social-pinterest-circular',
                    'social-skype',
                    'social-skype-outline',
                    'social-tumbler',
                    'social-tumbler-circular',
                    'social-twitter',
                    'social-twitter-circular',
                    'social-vimeo',
                    'social-vimeo-circular',
                    'social-youtube',
                    'social-youtube-circular',
                    'sort-alphabetically',
                    'sort-alphabetically-outline',
                    'sort-numerically',
                    'sort-numerically-outline',
                    'spanner',
                    'spanner-outline',
                    'spiral',
                    'star',
                    'starburst',
                    'starburst-outline',
                    'star-full-outline',
                    'star-half',
                    'star-half-outline',
                    'star-outline',
                    'stopwatch',
                    'support',
                    'tabs-outline',
                    'tag',
                    'tags',
                    'thermometer',
                    'th-large',
                    'th-large-outline',
                    'th-list',
                    'th-list-outline',
                    'th-menu',
                    'th-menu-outline',
                    'th-small',
                    'th-small-outline',
                    'thumbs-down',
                    'thumbs-ok',
                    'thumbs-up',
                    'tick',
                    'ticket',
                    'tick-outline',
                    'time',
                    'times',
                    'times-outline',
                    'trash',
                    'tree',
                    'upload',
                    'upload-outline',
                    'user',
                    'user-add',
                    'user-add-outline',
                    'user-delete',
                    'user-delete-outline',
                    'user-outline',
                    'vendor-android',
                    'vendor-apple',
                    'vendor-microsoft',
                    'video',
                    'video-outline',
                    'volume',
                    'volume-down',
                    'volume-mute',
                    'volume-up',
                    'warning',
                    'warning-outline',
                    'watch',
                    'waves',
                    'waves-outline',
                    'weather-cloudy',
                    'weather-downpour',
                    'weather-night',
                    'weather-partly-sunny',
                    'weather-shower',
                    'weather-snow',
                    'weather-stormy',
                    'weather-sunny',
                    'weather-windy',
                    'weather-windy-cloudy',
                    'wi-fi',
                    'wi-fi-outline',
                    'wine',
                    'world',
                    'world-outline',
                    'zoom',
                    'zoom-in',
                    'zoom-in-outline',
                    'zoom-out',
                    'zoom-outline',
                    'zoom-out-outline'
                ]
            }
        ]
    };

    var l = data.allVersions.length;
    data.icons = data.allVersions[l-1].icons;

    $.iconset_typicon = data;

})(jQuery);
